/// <reference types="jquery" />
import { ModalItem } from "./modal.meta";
import { ComponentFactory, ViewContainerRef } from "@angular/core";
import { HttpOptionsArgs } from "./http.meta";
import { DataAndLabel } from "./common.meta";
import { ProvinceCityArea } from "./province-city-area.meta";
import { HttpResponse } from "@angular/common/http";
/**
 * 动态组件创建
 */
export interface DynamicComponentFactoryProvider {
    /**
     * 主模块提供字符串selector和component factory映射级
     */
    getComponentFactoryMap(): {
        [index: string]: ComponentFactory<any>;
    };
}
/**
 * 全局事件
 */
export interface GlobalEventsProvider {
    /**
     * 全局点击任何对象时如果匹配数组中的selector则触发windowResize事件
     */
    getClickWindowResizeSelector(): string[];
}
/**
 * http
 */
export interface HttpProvider {
    showStackInformation(): boolean;
    getBaseUrl(): string;
    getDownloadUserToken(): string;
    requestIntercept(options: HttpOptionsArgs): boolean;
    successIntercept(data: any, response: HttpResponse<any>, options: HttpOptionsArgs): boolean;
    errorIntercept(response: HttpResponse<any>, options: HttpOptionsArgs): boolean;
}
/**
 * 模态框
 */
export interface ModalProvider {
    openModal(modalItem: ModalItem): void;
    closeModal(modalItem: ModalItem): void;
    getLastCanCloseModal(): ModalItem;
}
/**
 * 文件上传
 */
export interface FileUploadProvider {
    getFileServerBaseUrl(): string;
    getFileServerUserToken(): string;
}
/**
 * 下拉框数据
 */
export interface EnumProvider {
    getEnumData(id: string): DataAndLabel[];
}
/**
 * 右键菜单
 */
export interface RightClickMenuProvider {
    getRightMenuContainer(): ViewContainerRef;
}
/**
 * 波纹效果
 */
export interface RippleProvider {
    getRippleTarget(target: JQuery): JQuery;
    prepareRipple(rippleTarget: JQuery, ripple: JQuery): void;
}
/**
 * 表格
 */
export interface TableBoxProvider {
    getTableRows(): number;
    setTableRows(rows: number): void;
    getTableWidthMap(): {
        [index: string]: number;
    };
}
/**
 * 省市区
 */
export interface ProvinceCityAreaProvider {
    getProvinceCityAreaData(): ProvinceCityArea[];
}
/**
 * rem
 */
export interface RemProvider {
    getZoom(): number;
}
export interface CoreProvider {
    dynamicComponentFactoryProvider?: DynamicComponentFactoryProvider;
    globalEventsProvider?: GlobalEventsProvider;
    httpProvider?: HttpProvider;
    modalProvider?: ModalProvider;
    fileUploadProvider?: FileUploadProvider;
    enumProvider?: EnumProvider;
    rightClickMenuProvider?: RightClickMenuProvider;
    rippleProvider?: RippleProvider;
    tableBoxProvider?: TableBoxProvider;
    provinceCityAreaProvider?: ProvinceCityAreaProvider;
    remProvider?: RemProvider;
}
