import { Injectable, Component, ElementRef, HostListener, ComponentFactoryResolver, Input, Output, ViewContainerRef, EventEmitter, Directive, ViewChild, Pipe, CUSTOM_ELEMENTS_SCHEMA, NgModule } from '@angular/core';
import { isArray, isUndefined, isDate, isFunction, isString, isObject, isNumber } from 'util';
import { animate, state, style, transition, trigger } from '@angular/animations';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou\@jianyi.tech on 2017/1/1.
 */
let rem = 28;
/**
 * 一秒
 */
const second = 1000;
/**
 * 一分钟
 */
const minute = second * 60;
/**
 * 一小时
 */
const hour = minute * 60;
/**
 * 一天
 */
const day = hour * 24;
/**
 * 下拉框数据
 * @record
 */

class Icon {
}
Icon.loading = "loading";
Icon.success = "success";
Icon.error = "error";
Icon.question = "question";
Icon.warning = "warning";
Icon.info = "info";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 核心工具类 所有独立的小方法都在这里
 */
class ToolsService {
    constructor() {
        this.randomMap = {};
    }
    /**
     * @return {?}
     */
    get span() {
        if (!this._span) {
            /**
                   * 创建一个span用来计算字符宽度
                   */
            this._span = $("<span></span>");
            this._span.css("visibility", "hidden");
            this._span.css("whiteSpace", "nowrap");
            $(document.body).append(this._span);
        }
        return this._span;
    }
    /**
     * @return {?}
     */
    get textarea() {
        if (!this._textarea) {
            /**
                   * 创建一个textarea用来复制到剪切板
                   */
            this._textarea = $("<textarea readonly></textarea>");
            this._textarea.css({
                "position": "fixed",
                "top": "-1000px",
                "left": "-1000px",
                "opacity": "0",
                "z-index": "0",
                "width": "1px",
                "height": "1px"
            });
            $(document.body).append(this._textarea);
        }
        return this._textarea;
    }
    /**
     * @return {?}
     */
    focusOut() {
        this.textarea.focus();
    }
    /**
     * @param {?} text
     * @return {?}
     */
    copy(text) {
        this.textarea.val(text);
        this.textarea.select();
        document.execCommand("Copy");
    }
    /**
     * 获取字符串长度
     * @param {?} value
     * @param {?=} fontSize
     * @return {?}
     */
    getStringWidth(value, fontSize = 12) {
        this.span.html(value);
        this.span.css("font-size", fontSize / rem + "rem");
        return this.span[0].offsetWidth;
    }
    /**
     * 限定宽度后的最大长度
     * @param {?} value
     * @param {?} maxWidth
     * @param {?=} fontSize
     * @return {?}
     */
    getMaxWidthLimit(value, maxWidth, fontSize = 12) {
        let /** @type {?} */ limit = value.length;
        while (value && this.getStringWidth(value, fontSize) > maxWidth) {
            limit--;
            value = value.substring(0, limit);
        }
        return limit;
    }
    /**
     * 获取px单位的number值
     * @param {?} value
     * @return {?}
     */
    getPxNumber(value) {
        return value ? this.parseFloat(value.replace("px", "")) : 0;
    }
    /**
     * 把box浮层根据位置大小计算浮动在input周围
     * @param {?} fixedBox
     * @param {?} target
     * @param {?=} position
     * @return {?}
     */
    positionFixedBoxInput(fixedBox, target, position = "bottom") {
        if (!fixedBox) {
            return null;
        }
        let /** @type {?} */ boxWidth = fixedBox.outerWidth();
        let /** @type {?} */ boxHeight = fixedBox.outerHeight();
        let /** @type {?} */ left = target.offset().left;
        let /** @type {?} */ offsetLeft = left + boxWidth + 20 - window.innerWidth;
        if (offsetLeft > 0) {
            left -= offsetLeft;
        }
        fixedBox.css("left", left);
        let /** @type {?} */ targetHeight = target.outerHeight();
        let /** @type {?} */ top = target.offset().top + targetHeight;
        if (position === "top" || target.offset().top + boxHeight + targetHeight > window.innerHeight) {
            let /** @type {?} */ top2 = target.offset().top - boxHeight;
            if (top2 > 40) {
                top = top2;
            }
        }
        fixedBox.css("top", top);
    }
    /**
     * 获取随机数
     * @return {?}
     */
    getRandomId() {
        let /** @type {?} */ randomId = Math.random().toString().replace(".", "");
        if (this.randomMap[randomId]) {
            return this.getRandomId();
        }
        this.randomMap[randomId] = true;
        return randomId;
    }
    ;
    /**
     * 判断是否为空
     * @param {?} value
     * @return {?}
     */
    isNull(value) {
        return value === null || isUndefined(value) || value.toString().trim().length === 0;
    }
    /**
     * 判断是否不为空
     * @param {?} value
     * @return {?}
     */
    isNotNull(value) {
        return !this.isNull(value);
    }
    /**
     * 转int
     * @param {?} s
     * @param {?=} radix
     * @return {?}
     */
    parseInt(s, radix) {
        try {
            let /** @type {?} */ value = parseInt(s, radix);
            return isNaN(value) ? null : value;
        }
        catch (/** @type {?} */ e) {
        }
        return null;
    }
    /**
     * 转float
     * @param {?} s
     * @return {?}
     */
    parseFloat(s) {
        try {
            let /** @type {?} */ value = parseFloat(s);
            return isNaN(value) ? null : value;
        }
        catch (/** @type {?} */ e) {
        }
        return null;
    }
    /**
     * @param {?} element
     * @param {?} parent
     * @return {?}
     */
    _positionFocus(element, parent) {
        parent = parent.parent();
        if (parent == null || parent[0] === document.body.parentElement) {
            setTimeout(() => {
                element.focus();
            });
            return;
        }
        let /** @type {?} */ overflowY = parent.css("overflow-y");
        if (overflowY !== "auto" && overflowY !== "show" && overflowY !== "overlay") {
            this._positionFocus(element, parent);
            return;
        }
        let /** @type {?} */ positionTop = element.offset().top - parent.offset().top - parent.scrollTop();
        if (positionTop < 0) {
            parent.scrollTop(parent.scrollTop() + positionTop);
        }
        else if (positionTop + element.height() > parent.height()) {
            parent.scrollTop(parent.scrollTop() + positionTop + element.height() - parent.height());
        }
        setTimeout(() => {
            element.focus();
        });
    }
    /**
     * 定位焦点
     * @param {?} element
     * @return {?}
     */
    positionFocus(element) {
        if (!element) {
            return null;
        }
        this._positionFocus(element, element);
    }
    /**
     * 获取字符串
     * @param {?} value
     * @return {?}
     */
    getString(value) {
        if (this.isNull(value)) {
            return "";
        }
        return value + "";
    }
    /**
     * 在滚动时隐藏日期控件弹出层
     * @param {?} element
     * @return {?}
     */
    scrollDispatchClickEvent(element) {
        if (!element) {
            return;
        }
        let /** @type {?} */ timer = null;
        element.scroll(() => {
            if (timer == null) {
                document.dispatchEvent(new Event("click"));
            }
            clearTimeout(timer);
            timer = setTimeout(() => {
                document.dispatchEvent(new Event("click"));
                timer = null;
            }, 50);
        });
    }
    /**
     * @param {?} element
     * @param {?} nodeNames
     * @param {?} callBack
     * @return {?}
     */
    addDomShowChangeListener(element, nodeNames, callBack) {
        if (!element) {
            return;
        }
        let /** @type {?} */ mutationObserver = new MutationObserver((mutations, observer) => {
            let /** @type {?} */ changeFlag = false;
            for (let /** @type {?} */ mutation of mutations) {
                if (mutation && mutation.target && mutation.target.nodeName && (nodeNames == null || nodeNames.indexOf(mutation.target.nodeName.toLocaleLowerCase()) > -1)) {
                    changeFlag = true;
                    break;
                }
            }
            if (!changeFlag) {
                return;
            }
            callBack();
        });
        mutationObserver.observe(element, { attributes: true, childList: true, subtree: true });
    }
    ;
    /**
     * 判断jquery对象是否为空 如果没有长度则为空
     * @param {?} value
     * @return {?}
     */
    jqNotNull(value) {
        if (value && value.length === 0) {
            return null;
        }
        return value;
    }
    /**
     * 替换{0}{1}参数
     * @param {?} originalValue
     * @param {?} args
     * @return {?}
     */
    replaceArgs(originalValue, args) {
        let /** @type {?} */ argArray;
        if (isArray(args)) {
            argArray = /** @type {?} */ (args);
        }
        else {
            argArray = [/** @type {?} */ (args)];
        }
        argArray.forEach((value, index) => {
            originalValue = this.replaceAll(originalValue, "{" + index + "}", value);
        });
        return originalValue;
    }
    /**
     * @param {?} originalValue
     * @param {?} value1
     * @param {?} value2
     * @return {?}
     */
    replaceAll(originalValue, value1, value2) {
        while (originalValue.indexOf(value1) > -1) {
            originalValue = originalValue.replace(value1, value2);
        }
        return originalValue;
    }
    /**
     * @param {?} box
     * @param {?} boxHeight
     * @param {?} lineHeight
     * @param {?} index
     * @return {?}
     */
    correctScrollBar(box, boxHeight, lineHeight, index) {
        let /** @type {?} */ begin = index * lineHeight;
        let /** @type {?} */ end = begin + lineHeight;
        let /** @type {?} */ boxBegin = box.scrollTop();
        let /** @type {?} */ boxEnd = boxBegin + boxHeight;
        if (begin < boxBegin) {
            box.scrollTop(begin - boxHeight);
        }
        else if (end > boxEnd) {
            box.scrollTop(end - boxHeight);
        }
    }
    /**
     * @param {?} baseUrl
     * @param {?} url
     * @return {?}
     */
    getFullUrl(baseUrl, url) {
        baseUrl = baseUrl.trim();
        url = url.trim();
        if (!url.toLocaleLowerCase().startsWith("http")) {
            if (baseUrl.charAt(baseUrl.length - 1) !== "/") {
                baseUrl += "/";
            }
            if (url.charAt(0) === "/") {
                url = url.substring(1, url.length);
            }
            url = baseUrl + url;
        }
        return url;
    }
}
ToolsService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ToolsService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 定时器
 */
class TimerService {
    constructor() {
    }
    /**
     * 定义定时器
     * @param {?} endDate 结束时间
     * @param {?} process 间隔调用
     * @param {?} end 结束调用
     * @param {?=} intervalTime 间隔时间
     * @return {?}
     */
    addTimer(endDate, process, end, intervalTime = 1000) {
        let /** @type {?} */ date;
        if (isDate(endDate)) {
            date = /** @type {?} */ (endDate);
        }
        else {
            date = new Date(/** @type {?} */ (endDate));
        }
        let /** @type {?} */ newDate = new Date();
        let /** @type {?} */ surplus = Math.ceil((date.getTime() - newDate.getTime()) / intervalTime);
        if (surplus <= 0) {
            end();
            return;
        }
        process(newDate, surplus);
        let /** @type {?} */ timer;
        let /** @type {?} */ task = () => {
            if (--surplus > 0) {
                process(newDate, surplus);
                setTimeout(task, intervalTime);
            }
            else {
                end();
            }
        };
        timer = setTimeout(task, intervalTime);
        return timer;
    }
}
TimerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TimerService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 禁用
 */
class DisabledService {
    /**
     * @param {?} toolsService
     * @param {?} timerService
     */
    constructor(toolsService, timerService) {
        this.toolsService = toolsService;
        this.timerService = timerService;
        this.DISABLED = "DISABLED_";
    }
    /**
     * @param {?} value
     * @param {?=} defaultMessage
     * @param {?=} alwaysMessage
     * @return {?}
     */
    disabled(value, defaultMessage = undefined, alwaysMessage = undefined) {
        let /** @type {?} */ disabledArray = this.getDisabledItemArray(value);
        for (let /** @type {?} */ disabled of disabledArray) {
            ((_disabled) => {
                let /** @type {?} */ element = $(_disabled.element);
                let /** @type {?} */ oldHtml = element.html();
                // message undefined 为不设值  null为不改变值
                if (alwaysMessage !== undefined) {
                    if (alwaysMessage !== null) {
                        element.html(alwaysMessage);
                    }
                }
                else if (_disabled.message !== undefined) {
                    if (_disabled.message !== null) {
                        element.html(_disabled.message);
                    }
                }
                else if (defaultMessage !== undefined) {
                    if (defaultMessage !== null) {
                        element.html(defaultMessage);
                    }
                }
                element.attr("disabled", "disabled");
                _disabled.callback = () => {
                    if (_disabled.message !== null) {
                        element.html(oldHtml);
                    }
                    element.removeAttr("disabled");
                };
            })(disabled);
        }
        return {
            reset: () => {
                for (let /** @type {?} */ disabled of disabledArray) {
                    disabled.callback();
                }
            }
        };
    }
    /**
     * @param {?} id
     * @param {?} target
     * @param {?} callback
     * @return {?}
     */
    activateTimerDisabled(id, target, callback) {
        let /** @type {?} */ disabledMap = this.getLocalStorageObject(this.DISABLED + id);
        if (!disabledMap) {
            return;
        }
        let /** @type {?} */ $target = $(target);
        let /** @type {?} */ oldHtml = $target.html();
        $target.attr("disabled", "disabled");
        this.timerService.addTimer(disabledMap.date, (date, surplus) => {
            $target.html(disabledMap.text.replace("$s", surplus.toString()));
        }, () => {
            this.clearLocalStorage(this.DISABLED + id);
            $target.html(oldHtml);
            $target.removeAttr("disabled");
            callback();
        });
    }
    /**
     * @param {?} id
     * @param {?} target
     * @param {?} time
     * @param {?} text
     * @param {?} callback
     * @return {?}
     */
    timerDisabled(id, target, time, text, callback) {
        this.setLocalStorageObject(this.DISABLED + id, {
            date: new Date().getTime() + time * 1000,
            text: text
        });
        this.activateTimerDisabled(id, target, callback);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    getDisabledItemArray(value) {
        let /** @type {?} */ disabledItemArray = [];
        if (this.toolsService.isNull(value)) {
            return disabledItemArray;
        }
        if (isArray(value)) {
            let /** @type {?} */ itemArray = /** @type {?} */ (value);
            for (let /** @type {?} */ item of itemArray) {
                if (item.hasOwnProperty("element") && item.hasOwnProperty("message")) {
                    disabledItemArray.push(item);
                }
                else {
                    disabledItemArray.push({
                        element: item
                    });
                }
            }
        }
        else {
            if (value.hasOwnProperty("element") && value.hasOwnProperty("message")) {
                disabledItemArray.push(/** @type {?} */ (value));
            }
            else {
                disabledItemArray.push({
                    element: /** @type {?} */ (value)
                });
            }
        }
        return disabledItemArray;
    }
    /**
     * 避免循环依赖 所以这边复制了一部分storage的方法 这些方法不对外提供
     * @param {?} id
     * @return {?}
     */
    getLocalStorage(id) {
        this.validateId(id);
        if (localStorage) {
            return localStorage.getItem(id);
        }
        return null;
    }
    ;
    /**
     * @param {?} id
     * @param {?=} defaultValue
     * @return {?}
     */
    getLocalStorageObject(id, defaultValue = null) {
        let /** @type {?} */ value = this.getLocalStorage(id);
        if (this.toolsService.isNotNull(value)) {
            return JSON.parse(value);
        }
        else {
            return this.toolsService.isNotNull(defaultValue) ? defaultValue : null;
        }
    }
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setLocalStorage(id, value) {
        this.validateId(id);
        if (localStorage) {
            localStorage.setItem(id, value);
        }
    }
    ;
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setLocalStorageObject(id, value) {
        if (value) {
            value = JSON.stringify(value);
        }
        this.setLocalStorage(id, value);
    }
    ;
    /**
     * @param {?} id
     * @return {?}
     */
    clearLocalStorage(id) {
        this.validateId(id);
        if (localStorage) {
            localStorage.removeItem(id);
        }
    }
    ;
    /**
     * @param {?} id
     * @return {?}
     */
    validateId(id) {
        if (!id) {
            throw new Error("storage id is Invalid");
        }
    }
}
DisabledService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DisabledService.ctorParameters = () => [
    { type: ToolsService, },
    { type: TimerService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 透明变化的显示隐藏 如果两个标签是互斥显示 存在布局影响 会造成视觉问题 应该使用\@fadeOnlyShow
 */
const fadeShow = trigger("fadeShow", [
    state("hide, void", style({ opacity: "0", display: "none" })),
    state("show", style({ opacity: "1" })),
    transition("hide <=> show", [animate(200)])
]);
/**
 * 透明变化的显示 直接隐藏
 */
const fadeOnlyShow = trigger("fadeOnlyShow", [
    state("hide, void", style({ opacity: "0", display: "none" })),
    state("show", style({ opacity: "1" })),
    transition("hide => show", [animate(200)]),
    transition("void => show", [animate(200)])
]);
const slideInUp = trigger("slideInUp", [
    state("up, void", style({ transform: "translate3d(0, -100%, 0)" })),
    state("down", style({ transform: "translate3d(0, 0, 0)" })),
    transition("up <=> down", [animate(200)]),
    transition("void => down", [animate(200)])
]);
/**
 * 上下拉 透明变化和高度变化
 */
const slideUpDown = trigger("slideUpDown", [
    state("up, void", style({ opacity: "0", height: "0", display: "none" })),
    state("down", style({ opacity: "1", height: "*" })),
    transition("up <=> down", [animate(200)])
]);
/**
 * 箭头开关
 */
const arrowsSwitch = trigger("arrowsSwitch", [
    state("down, void", style({ transform: "rotate(0deg)" })),
    state("left", style({ transform: "rotate(90deg)" })),
    transition("down <=> left", [animate(200)])
]);
/**
 * 箭头开关
 */
const upDownSwitch = trigger("upDownSwitch", [
    state("up, void", style({ transform: "rotate(0deg)" })),
    state("down", style({ transform: "rotate(180deg)" })),
    transition("up <=> down", [animate(200)])
]);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 提示框
 */
class AlertComponent {
    constructor() {
        this.show = false;
        this.alertParams = null;
        this.mode = "ok";
        this.endFlag = false;
    }
    /**
     * @param {?} alertParams
     * @return {?}
     */
    setTransmitData(alertParams) {
        alertParams.escClose = () => {
            return false;
        };
        if (alertParams.yesClick || alertParams.noClick) {
            this.mode = "yesOrNo";
        }
        let { okLabel = "知道了", yesLabel = "确定", noLabel = "取消", } = alertParams;
        if (!alertParams.iconType) {
            alertParams.iconType = this.mode === "ok" ? Icon.info : Icon.question;
        }
        if (!alertParams.title) {
            if (alertParams.iconType === Icon.success) {
                alertParams.title = "成功";
            }
            else if (alertParams.iconType === Icon.error) {
                alertParams.title = "错误";
            }
            else if (alertParams.iconType === Icon.question) {
                alertParams.title = "确认";
            }
            else if (alertParams.iconType === Icon.warning) {
                alertParams.title = "警告";
            }
            else if (alertParams.iconType === Icon.info) {
                alertParams.title = "提示";
            }
        }
        alertParams.okLabel = okLabel;
        alertParams.yesLabel = yesLabel;
        alertParams.noLabel = noLabel;
        this.alertParams = alertParams;
    }
    /**
     * @return {?}
     */
    okClick() {
        if (this.endFlag) {
            return;
        }
        if (this.alertParams.okClick) {
            this.alertParams.okClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    yesClick() {
        if (this.endFlag) {
            return;
        }
        if (this.alertParams.yesClick) {
            this.alertParams.yesClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    noClick() {
        if (this.endFlag) {
            return;
        }
        if (this.alertParams.noClick) {
            this.alertParams.noClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    close() {
        this.endFlag = true;
        this.show = false;
        this.alertParams.preClose();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    closed(event) {
        if (event.toState === "hide" && event.totalTime > 0) {
            this.alertParams.close();
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.show = true;
        });
    }
}
AlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-alert',
                template: `<div class="modal" [@fadeShow]="show ? 'show':'hide'" (@fadeShow.done)="closed($event)"></div>
<div class='alert-box' *ngIf="alertParams != null" [@slideInUp]="show ? 'down':'up'"
     [@fadeShow]="show ? 'show':'hide'">
  <div class="alert-head">
    <span [ngClass]="{
          'icon-ok-circle-solid': alertParams.iconType === 'success',
          'icon-cancel-circle-solid': alertParams.iconType === 'error',
          'icon-warning-circle-solid': alertParams.iconType === 'warning',
          'icon-info-circle-solid': alertParams.iconType === 'info',
          'icon-question-circle-solid': alertParams.iconType === 'question'
      }"></span>
    <span class="alert-title">{{alertParams.title}}</span>
  </div>
  <div class="alert-content">
    {{alertParams.content}}
  </div>
  <div class="alert-button-group">
    <div *ngIf="mode === 'ok'">
      <button class="btn btn-primary" (click)="okClick()" jyFocus>
        {{alertParams.okLabel}}
      </button>
    </div>
    <div *ngIf="mode === 'yesOrNo'">
      <button class="btn btn-default" (click)="noClick()">
        {{alertParams.noLabel}}
      </button>
      <button class="btn btn-primary" (click)="yesClick()" jyFocus>
        {{alertParams.yesLabel}}
      </button>
    </div>
  </div>
</div>
`,
                styles: [`.alert-box{width:14.28571429rem;background:#fff;position:fixed;top:30%;left:50%;margin-left:-7.14285714rem;border-radius:.21428571rem;-webkit-box-shadow:0 .17857143rem .53571429rem rgba(0,0,0,.5);box-shadow:0 .17857143rem .53571429rem rgba(0,0,0,.5);padding:.71428571rem}.alert-box .alert-head{display:-webkit-box;display:-ms-flexbox;display:flex}.alert-box .alert-head .alert-title{font-size:.57142857rem;padding-left:.35714286rem;margin-top:.46428571rem;font-weight:bolder;float:left}.alert-box .alert-head [class*=" icon-"],.alert-box .alert-head [class^=icon-]{font-size:1.28571429rem;float:left}.alert-box .alert-head .icon-ok-circle-solid{color:#1ec434}.alert-box .alert-head .icon-info-circle-solid{color:#00b6f3}.alert-box .alert-head .icon-question-circle-solid{color:#ffb201}.alert-box .alert-head .icon-cancel-circle-solid{color:#ff5e5e}.alert-box .alert-head .icon-warning-circle-solid{color:#ff8e35}.alert-box .alert-content{padding:0 .35714286rem .35714286rem 1.67857143rem}.alert-box .alert-button-group{padding-right:.71428571rem;text-align:right}`],
                animations: [fadeShow, slideInUp]
            },] },
];
/** @nocollapse */
AlertComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * rem控制
 */
class RemService {
    /**
     * @param {?} toolsService
     */
    constructor(toolsService) {
        this.toolsService = toolsService;
        this.zoom = 1;
    }
    /**
     * @return {?}
     */
    init() {
        document.documentElement.style.fontSize = ((window.screen.width / 1920) * rem) * this.zoom + "px";
    }
    /**
     * @param {?} remProvider
     * @return {?}
     */
    setProvider(remProvider) {
        if (!remProvider) {
            return;
        }
        this.setZoom(remProvider.getZoom());
    }
    /**
     * @param {?} zoom
     * @return {?}
     */
    setZoom(zoom) {
        if (zoom === null || isUndefined(zoom)) {
            return;
        }
        this.zoom = zoom;
        document.documentElement.style.fontSize = ((window.screen.width / 1920) * rem) * this.zoom + "px";
    }
    /**
     * rem转px
     * @param {?} px
     * @return {?}
     */
    realPx(px) {
        if (this.toolsService.isNull(px)) {
            return 0;
        }
        let /** @type {?} */ htmlPx = this.toolsService.parseFloat(document.documentElement.style.fontSize.toLocaleLowerCase().replace("px", ""));
        return px / rem * htmlPx;
    }
    /**
     * px转rem
     * @param {?} px
     * @return {?}
     */
    pxConvertToRem(px) {
        if (this.toolsService.isNull(px)) {
            return 0;
        }
        let /** @type {?} */ htmlPx = this.toolsService.parseFloat(document.documentElement.style.fontSize.toLocaleLowerCase().replace("px", ""));
        return px / htmlPx;
    }
    /**
     * @param {?} remPx
     * @return {?}
     */
    remPxConvertToPx(remPx) {
        if (this.toolsService.isNull(remPx)) {
            return 0;
        }
        let /** @type {?} */ htmlPx = this.toolsService.parseFloat(document.documentElement.style.fontSize.toLocaleLowerCase().replace("px", ""));
        return remPx * (rem / htmlPx);
    }
}
RemService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
RemService.ctorParameters = () => [
    { type: ToolsService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 模态窗口
 */
class ModalComponent {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     * @param {?} remService
     */
    constructor(elementRef, toolsService, remService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.remService = remService;
        this.show = false;
        this.endFlag = false;
        this.modalParams = null;
        this.close = null;
        this.width = 800 / rem + "rem";
        this.minWidth = "0";
        this.maxWidth = 99999 / rem + "rem";
        this.host = null;
        this.modalDialog = null;
        this.modalContent = null;
        this.modalPage = null;
        this.modalHeader = null;
        this.modalBody = null;
        this.modalFooter = null;
        this.verticalCenter = false;
        this.host = $(elementRef.nativeElement);
        this.toolsService.focusOut();
    }
    /**
     * @param {?} modalParams
     * @return {?}
     */
    setTransmitData(modalParams) {
        this.modalParams = modalParams;
        this.close = modalParams.close;
        this.modalParams.close = () => {
            this.endFlag = true;
            this.show = false;
            setTimeout(() => {
                this.close();
            }, 500);
        };
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.show = true;
            this.modalDialog = this.host.find(".modal-dialog");
            this.modalContent = this.host.find(".modal-content");
            this.modalPage = this.host.find(".modal-page");
            this.modalHeader = this.toolsService.jqNotNull(this.host.find(".modal-header"));
            this.modalBody = this.host.find(".modal-body");
            this.modalFooter = this.toolsService.jqNotNull(this.host.find(".modal-footer"));
            this.toolsService.scrollDispatchClickEvent(this.modalBody);
            if (this.modalPage.css("width").indexOf("px") > -1) {
                this.width = (this.toolsService.getPxNumber(this.modalPage.css("width")) / rem).toString() + "rem";
            }
            else if (this.modalPage.css("width").indexOf("%") > -1) {
                this.width = this.modalPage.css("width");
            }
            if (this.modalPage.css("minWidth").indexOf("px") > -1) {
                this.minWidth = (this.toolsService.getPxNumber(this.modalPage.css("minWidth")) / rem).toString() + "rem";
            }
            if (this.modalPage.css("maxWidth").indexOf("px") > -1) {
                this.maxWidth = (this.toolsService.getPxNumber(this.modalPage.css("maxWidth")) / rem).toString() + "rem";
            }
            this.modalPage.css("width", "inherit");
            this.modalPage.css("min-width", "inherit");
            this.modalPage.css("max-width", "inherit");
            this.verticalCenter = this.modalPage.hasClass("modal-vertical-center");
            this.onResize();
            setTimeout(() => {
                this.onResize();
            });
        });
    }
    /**
     * @return {?}
     */
    onResize() {
        if (!this.modalBody) {
            return;
        }
        let /** @type {?} */ maxHeight = window.innerHeight - this.remService.realPx(23);
        if (this.modalHeader != null) {
            maxHeight -= this.modalHeader.outerHeight();
        }
        if (this.modalFooter != null) {
            maxHeight -= this.modalFooter.outerHeight();
        }
        this.modalBody.css("maxHeight", maxHeight);
        if (this.verticalCenter) {
            this.modalDialog.css("margin-top", (window.innerHeight - this.modalContent.outerHeight()) / 2);
        }
    }
}
ModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-modal',
                template: `<div class="modal" [@fadeShow]="show ? 'show':'hide'"></div>
<div class="modal-box" *ngIf="modalParams != null" [@slideInUp]="show ? 'down':'up'"
     [@fadeShow]="show ? 'show':'hide'">
  <div class="modal-dialog" [ngStyle]="{width:width,'min-width':minWidth,'max-width':maxWidth}">
    <div class="modal-content">
      <jy-dynamic-component [componentSelector]="modalParams.component"
                            [transmitData]="modalParams" (onComponentRefInit)="modalParams.componentRef = $event"></jy-dynamic-component>
    </div>
  </div>
</div>
`,
                styles: [``],
                animations: [fadeShow, slideInUp]
            },] },
];
/** @nocollapse */
ModalComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
    { type: RemService, },
];
ModalComponent.propDecorators = {
    "onResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SubmitRemarkModalComponent {
    constructor() {
        this.remark = "";
    }
    /**
     * @param {?} button
     * @return {?}
     */
    submit(button) {
        this.validatorControl.validate({
            success: () => {
                this.transmitData.submit(button, this.remark, this.transmitData.close.bind(this));
            }
        });
    }
    /**
     * @return {?}
     */
    close() {
        if (this.transmitData.closeBefore) {
            this.transmitData.closeBefore(this.transmitData.close.bind(this), this.remark);
        }
        else {
            this.transmitData.close();
        }
    }
    /**
     * @param {?} transmitData
     * @return {?}
     */
    setTransmitData(transmitData) {
        this.transmitData = transmitData;
        this.remark = this.transmitData.remark;
    }
    /**
     * @param {?} modalParams
     * @return {?}
     */
    static createParams(modalParams) {
        modalParams.component = SubmitRemarkModalComponent;
        return modalParams;
    }
}
SubmitRemarkModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-bill-medical-issue-submit',
                template: `<div class="modal-page modal-vertical-center" style="width: 700px;">
  <div class="modal-header">
    <button type="button" class="close" (click)="close()">
      ×
    </button>
    <h4 class="modal-title">
      {{transmitData.title}}
    </h4>
  </div>
  <div class="modal-body" style="overflow: visible;">
    <div class="form" style="padding: 0;" jyValidator (validatorControlInit)="validatorControl = $event">
      <div class="form-box" style="margin: 0;">
        <div class="col-12">
          <div class="col-2"><label class="form-label">{{transmitData.label}}：</label></div>
          <div class="col-10">
            <textarea class="form-control inline-form-control" name="remark" rows="4"
                      [(ngModel)]="remark" [jyMaxlength]="transmitData.maxLength"
                      [jyRequired]="transmitData.required" jyFocus></textarea>
          </div>
        </div>
      </div>
    </div>
  </div>
  <div class="modal-footer">
    <button type="button" class="btn btn-primary" (click)="submit($event.currentTarget)">提交</button>
  </div>
</div>
`,
            },] },
];
/** @nocollapse */
SubmitRemarkModalComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 模态框
 */
class ModalService {
    constructor() {
        $(document.body).keyup((event) => {
            if (event.keyCode === 27) {
                let /** @type {?} */ modalItem = this.modalProvider.getLastCanCloseModal();
                if (modalItem && modalItem.transmitData.escClose() !== false) {
                    try {
                        if (isFunction(modalItem.transmitData.componentRef.instance.close)) {
                            modalItem.transmitData.componentRef.instance.close();
                        }
                    }
                    catch (/** @type {?} */ e) {
                        try {
                            if (isFunction(modalItem.componentRef.instance.close)) {
                                modalItem.componentRef.instance.close();
                            }
                        }
                        catch (/** @type {?} */ e) {
                            modalItem.transmitData.close();
                        }
                    }
                }
            }
        });
    }
    /**
     * @param {?} modalProvider
     * @return {?}
     */
    setProvider(modalProvider) {
        if (!modalProvider) {
            return;
        }
        this.modalProvider = modalProvider;
    }
    /**
     * @param {?} transmitData
     * @param {?=} selector
     * @param {?=} viewPrevent
     * @return {?}
     */
    open(transmitData, selector = ModalComponent, viewPrevent = true) {
        let /** @type {?} */ modalItem = {
            modalTop: transmitData.modalTop,
            selector: selector,
            transmitData: transmitData,
            viewPrevent: viewPrevent
        };
        transmitData.preClose = () => {
            modalItem.viewPrevent = true;
        };
        transmitData.close = () => {
            this.modalProvider.closeModal(modalItem);
        };
        transmitData.escClose = () => {
            return true;
        };
        this.modalProvider.openModal(modalItem);
    }
    /**
     * @param {?} modalParams
     * @return {?}
     */
    openSubmitRemark(modalParams) {
        this.open(SubmitRemarkModalComponent.createParams(modalParams));
    }
}
ModalService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ModalService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * alert提示框
 */
class AlertService {
    /**
     * @param {?} modalService
     */
    constructor(modalService) {
        this.modalService = modalService;
    }
    /**
     * @param {?} alertParams
     * @return {?}
     */
    open(alertParams) {
        if (isString(alertParams)) {
            alertParams = /** @type {?} */ ({ content: alertParams });
        }
        this.modalService.open(/** @type {?} */ (alertParams), AlertComponent);
    }
}
AlertService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
AlertService.ctorParameters = () => [
    { type: ModalService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class HttpService {
    /**
     * @param {?} httpClient
     * @param {?} toolsService
     * @param {?} disabledService
     * @param {?} alertService
     */
    constructor(httpClient, toolsService, disabledService, alertService) {
        this.httpClient = httpClient;
        this.toolsService = toolsService;
        this.disabledService = disabledService;
        this.alertService = alertService;
        this.preventRepetitionParamsRecord = {};
        this.preventRepetitionRandomId = {};
        this.defaultRequestOptionsArgs = {
            headers: new Headers({
                "Content-Type": "application/json; charset=UTF-8",
                "X-Requested-With": "XMLHttpRequest"
            }),
            httpResponseType: "json"
        };
    }
    /**
     * @param {?} httpProvider
     * @return {?}
     */
    setProvider(httpProvider) {
        if (!httpProvider) {
            return;
        }
        this.httpProvider = httpProvider;
        // 获取服务器地址 处理拼接时的斜杠
        this.baseUrl = httpProvider.getBaseUrl();
        if (this.baseUrl.endsWith("/")) {
            this.baseUrl = this.baseUrl.substring(0, this.baseUrl.length - 1);
        }
    }
    /**
     * @param {?} options
     * @return {?}
     */
    get(options) {
        options.method = "get";
        this.request(options);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    post(options) {
        options.method = "post";
        this.request(options);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    del(options) {
        options.method = "delete";
        this.request(options);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    put(options) {
        options.method = "put";
        this.request(options);
    }
    /**
     * @param {?} url
     * @param {?=} data
     * @return {?}
     */
    download(url, data = {}) {
        data["user-token"] = this.httpProvider.getDownloadUserToken();
        window.location.href = this.toolsService.getFullUrl(this.baseUrl, url) + '?' + this.urlParamsTranslate(data);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    request(options) {
        if (this.httpProvider.requestIntercept(options)) {
            return;
        }
        this.removeUndefined(options.body);
        this.removeUndefined(options.params);
        options.observe = "response";
        if (options.preventRepetition || options.preventRepetitionId) {
            options.preventRepetitionId = options.preventRepetitionId ? options.preventRepetitionId : options.url;
            let /** @type {?} */ lastParamsJson = this.preventRepetitionParamsRecord[options.preventRepetitionId];
            let /** @type {?} */ paramsJson = "";
            if (options.body) {
                paramsJson += JSON.stringify(options.body);
            }
            if (options.params) {
                paramsJson += JSON.stringify(options.params);
            }
            if (lastParamsJson && lastParamsJson === paramsJson) {
                return;
            }
            this.preventRepetitionParamsRecord[options.preventRepetitionId] = paramsJson;
            options.preventRepetitionRandomId = this.toolsService.getRandomId();
            this.preventRepetitionRandomId[options.preventRepetitionId] = options.preventRepetitionRandomId;
        }
        // 当路由跳转后 之前如果存在有还没回调的请求则忽略所有的回调 不管成功还是失败
        this.setDefaultOptions(options);
        let /** @type {?} */ disabledRest = this.disabledService.disabled(options.disabled, "请求中");
        this.httpClient.request(options.method, options.url, options).subscribe((httpResponse) => {
            if (options.preventRepetitionId) {
                if (this.preventRepetitionRandomId[options.preventRepetitionId] !== options.preventRepetitionRandomId) {
                    return;
                }
                else {
                    delete this.preventRepetitionParamsRecord[options.preventRepetitionId];
                    delete this.preventRepetitionRandomId[options.preventRepetitionId];
                }
            }
            /**
                     * 成功
                     */
            disabledRest.reset();
            if (options.alwaysDisabled) {
                this.disabledService.disabled(options.disabled, null, null);
            }
            this.success(httpResponse, options);
        }, (httpResponse) => {
            if (options.preventRepetitionId) {
                if (this.preventRepetitionRandomId[options.preventRepetitionId] !== options.preventRepetitionRandomId) {
                    return;
                }
                else {
                    delete this.preventRepetitionParamsRecord[options.preventRepetitionId];
                    delete this.preventRepetitionRandomId[options.preventRepetitionId];
                }
            }
            /**
                     * 失败
                     */
            disabledRest.reset();
            this.error(httpResponse, options);
        });
    }
    /**
     * @param {?} data
     * @return {?}
     */
    removeUndefined(data) {
        if (!data) {
            return;
        }
        if (isArray(data)) {
            for (let /** @type {?} */ item of data) {
                this.removeUndefined(item);
            }
        }
        else if (isObject(data)) {
            for (let /** @type {?} */ key in data) {
                if (key) {
                    if (isUndefined(data[key])) {
                        delete data[key];
                    }
                    else {
                        this.removeUndefined(data[key]);
                    }
                }
            }
        }
    }
    /**
     * @param {?} options
     * @return {?}
     */
    setDefaultOptions(options) {
        for (let /** @type {?} */ key in this.defaultRequestOptionsArgs) {
            if (key && this.toolsService.isNull((/** @type {?} */ (options))[key])) {
                (/** @type {?} */ (options))[key] = (/** @type {?} */ (this.defaultRequestOptionsArgs))[key];
            }
        }
        options.url = this.toolsService.getFullUrl(this.baseUrl, options.url);
    }
    /**
     * @param {?} httpResponse
     * @param {?} options
     * @return {?}
     */
    success(httpResponse, options) {
        let /** @type {?} */ data = httpResponse.body;
        if (this.httpProvider.successIntercept(data, httpResponse, options)) {
            return;
        }
        if (options.success) {
            options.success(data, httpResponse, options);
        }
    }
    /**
     * @param {?} httpResponse
     * @param {?} options
     * @return {?}
     */
    error(httpResponse, options) {
        // 错误拦截之前 单个请求自己控制是否需要被拦截 或者在拦截之前do something 返回true则不继续往下走
        if (options.beforeErrorIntercept && options.beforeErrorIntercept(httpResponse, options)) {
            return;
        }
        // 错误拦截 各个业务系统可以根据自己的业务拦截统一的异常 返回true则不继续往下走
        if (this.httpProvider.errorIntercept(httpResponse, options)) {
            return;
        }
        if (options.error && options.error(httpResponse, options)) {
            return;
        }
        let /** @type {?} */ message = "网络异常，请稍后再试！";
        let /** @type {?} */ stackInformation = null;
        let /** @type {?} */ errorCodeFlag = false;
        if (httpResponse.status === 500) {
            let /** @type {?} */ data = httpResponse["error"];
            let /** @type {?} */ code = httpResponse.status.toString();
            if (data && !isString(data)) {
                if (data.type === "BUSINESS") {
                    code = data.code;
                    message = data.message;
                    if (options.errorCode) {
                        if (isFunction(options.errorCode)) {
                            (/** @type {?} */ (options.errorCode))(code, message, data.code, httpResponse, options);
                            errorCodeFlag = true;
                        }
                        else if ((/** @type {?} */ (options.errorCode))[code]) {
                            (/** @type {?} */ (options.errorCode))[code](message, data.code, httpResponse, options);
                            errorCodeFlag = true;
                        }
                    }
                }
                else if (this.httpProvider.showStackInformation() && data.type === "ERROR") {
                    stackInformation = data.message;
                }
            }
        }
        if (!errorCodeFlag && options.errorAlert !== false) {
            if (stackInformation) {
                this.alertService.open({
                    iconType: Icon.error,
                    content: message,
                    yesLabel: "知道了",
                    noLabel: "复制堆栈信息",
                    noClick: () => {
                        this.toolsService.copy(stackInformation);
                    }
                });
            }
            else {
                this.alertService.open({
                    iconType: Icon.error,
                    content: message
                });
            }
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    urlParamsEncode(value) {
        if (value === null || value === undefined || value === "") {
            return "";
        }
        if (isDate(value)) {
            value = /** @type {?} */ (value.getTime());
        }
        value = (value + '').toString();
        return encodeURIComponent(value).replace(/!/g, '%21').replace(/'/g, '%27').replace(/\(/g, '%28').replace(/\)/g, '%29').replace(/\*/g, '%2A').replace(/%20/g, '+');
    }
    /**
     * @param {?} params
     * @return {?}
     */
    urlParamsTranslate(params) {
        let /** @type {?} */ str = '';
        for (let /** @type {?} */ i in params) {
            if (i) {
                str += i + '=' + this.urlParamsEncode(params[i]) + '&';
            }
        }
        if (str) {
            str = str.substr(0, str.length - 1);
        }
        return str;
    }
}
HttpService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
HttpService.ctorParameters = () => [
    { type: HttpClient, },
    { type: ToolsService, },
    { type: DisabledService, },
    { type: AlertService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * date操作
 */
class DateService {
    constructor() {
        this.YYYYMMDDHHMMSSSSS = "YYYY-MM-DD HH:mm:ss:SSS";
        this.YYYYMMDDHHMMSS = "YYYY-MM-DD HH:mm:ss";
        this.YYYYMMDDHHMM = "YYYY-MM-DD HH:mm";
        this.YYYYMMDDHH = "YYYY-MM-DD HH";
        this.YYYYMMDD = "YYYY-MM-DD";
        this.YYYYMM = "YYYY-MM";
        this.MMDD = "MM-DD";
        this.HHMMSS = "HH:mm:ss";
        this.HHMM = "HH:mm";
        this.YYYY = "YYYY";
        this.MM = "MM";
        this.DD = "DD";
        this.token = /d{1,4}|M{1,4}|YY(?:YY)?|S{1,3}|Do|ZZ|([HhMsDm])\1?|[aA]|"[^"]*"|'[^']*'/g;
        this.dayNames = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
        this.monthNames = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
        this.amPm = ['am', 'pm'];
        this.twoDigits = /\d\d?/;
        this.threeDigits = /\d{3}/;
        this.fourDigits = /\d{4}/;
        this.word = /[0-9]*['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+|[\u0600-\u06FF\/]+(\s*?[\u0600-\u06FF]+){1,2}/i;
        this.dayNamesShort = [];
        this.monthNamesShort = [];
        this.parseFlags = {
            D: [this.twoDigits, (d, v) => {
                    d.day = v;
                }],
            Do: null,
            DD: null,
            M: [this.twoDigits, (d, v) => {
                    d.month = v - 1;
                }],
            MM: null,
            YY: [this.twoDigits, (d, v) => {
                    let /** @type {?} */ da = new Date(), /** @type {?} */ cent = +('' + da.getFullYear()).substr(0, 2);
                    d.year = '' + (v > 68 ? cent - 1 : cent) + v;
                }],
            h: [this.twoDigits, (d, v) => {
                    d.hour = v;
                }],
            hh: null,
            H: null,
            HH: null,
            m: [this.twoDigits, (d, v) => {
                    d.minute = v;
                }],
            mm: null,
            s: [this.twoDigits, (d, v) => {
                    d.second = v;
                }],
            ss: null,
            YYYY: [this.fourDigits, (d, v) => {
                    d.year = v;
                }],
            S: [/\d/, (d, v) => {
                    d.millisecond = v * 100;
                }],
            SS: [/\d{2}/, (d, v) => {
                    d.millisecond = v * 10;
                }],
            SSS: [this.threeDigits, (d, v) => {
                    d.millisecond = v;
                }],
            d: [this.twoDigits, this.noop],
            dd: null,
            ddd: [this.word, this.noop],
            dddd: null,
            MMM: [this.word, this.monthUpdate('monthNamesShort')],
            MMMM: [this.word, this.monthUpdate('monthNames')],
            a: [this.word, (d, v) => {
                    let /** @type {?} */ val = v.toLowerCase();
                    if (val === this.amPm[0]) {
                        d.isPm = false;
                    }
                    else if (val === this.amPm[1]) {
                        d.isPm = true;
                    }
                }],
            A: null,
            ZZ: [/[\+\-]\d\d:?\d\d/, (d, v) => {
                    let /** @type {?} */ parts = (v + '').match(/([\+\-]|\d\d)/gi), /** @type {?} */ minutes;
                    if (parts) {
                        minutes = +(parseInt(parts[1]) * 60) + parseInt(parts[2], 10);
                        d.timezoneOffset = parts[0] === '+' ? minutes : -minutes;
                    }
                }]
        };
        this.i18n = {
            dayNamesShort: this.dayNamesShort,
            dayNames: this.dayNames,
            monthNamesShort: this.monthNamesShort,
            monthNames: this.monthNames,
            amPm: this.amPm,
            doFn: this.doFn
        };
        this.masks = {
            'default': 'ddd MMM DD YYYY HH:mm:ss',
            shortDate: 'M/D/YY',
            mediumDate: 'MMM D, YYYY',
            longDate: 'MMMM D, YYYY',
            fullDate: 'dddd, MMMM D, YYYY',
            shortTime: 'HH:mm',
            mediumTime: 'HH:mm:ss',
            longTime: 'HH:mm:ss.SSS'
        };
        this.parseFlags.dd = this.parseFlags.d;
        this.parseFlags.dddd = this.parseFlags.ddd;
        this.parseFlags.Do = this.parseFlags.DD = this.parseFlags.D;
        this.parseFlags.mm = this.parseFlags.m;
        this.parseFlags.hh = this.parseFlags.H = this.parseFlags.HH = this.parseFlags.h;
        this.parseFlags.MM = this.parseFlags.M;
        this.parseFlags.ss = this.parseFlags.s;
        this.parseFlags.A = this.parseFlags.a;
        this.shorten(this.monthNames, this.monthNamesShort, 3);
        this.shorten(this.dayNames, this.dayNamesShort, 3);
    }
    /**
     * @return {?}
     */
    noop() {
    }
    ;
    /**
     * @param {?} arrName
     * @return {?}
     */
    monthUpdate(arrName) {
        return (d, v) => {
            let /** @type {?} */ index = this.i18n[arrName].indexOf(v.charAt(0).toUpperCase() + v.substr(1).toLowerCase());
            if (~index) {
                d.month = index;
            }
        };
    }
    /**
     * @param {?} val
     * @param {?=} len
     * @return {?}
     */
    pad(val, len = 2) {
        val = String(val);
        while (val.length < len) {
            val = '0' + val;
        }
        return val;
    }
    /**
     * @param {?} arr
     * @param {?} newArr
     * @param {?} sLen
     * @return {?}
     */
    shorten(arr, newArr, sLen) {
        for (let /** @type {?} */ i = 0, /** @type {?} */ len = arr.length; i < len; i++) {
            newArr.push(arr[i].substr(0, sLen));
        }
    }
    /**
     * @param {?} d
     * @return {?}
     */
    doFn(d) {
        return d + ['th', 'st', 'nd', 'rd'][d % 10 > 3 ? 0 : d % 10];
    }
    /**
     * @param {?} date
     * @param {?} mask
     * @return {?}
     */
    format(date, mask) {
        let /** @type {?} */ _date = this.getDate(date);
        if (!_date) {
            return "";
        }
        mask = this.masks[mask] || mask || this.masks['default'];
        let /** @type {?} */ D = _date.getDate(), /** @type {?} */
        d = _date.getDay(), /** @type {?} */
        M = _date.getMonth(), /** @type {?} */
        y = _date.getFullYear(), /** @type {?} */
        H = _date.getHours(), /** @type {?} */
        m = _date.getMinutes(), /** @type {?} */
        s = _date.getSeconds(), /** @type {?} */
        S = _date.getMilliseconds(), /** @type {?} */
        o = _date.getTimezoneOffset(), /** @type {?} */
        flags = {
            D: D,
            DD: this.pad(D),
            Do: this.i18n.doFn(D),
            d: d,
            dd: this.pad(d),
            ddd: this.i18n.dayNamesShort[d],
            dddd: this.i18n.dayNames[d],
            M: M + 1,
            MM: this.pad(M + 1),
            MMM: this.i18n.monthNamesShort[M],
            MMMM: this.i18n.monthNames[M],
            YY: String(y).slice(2),
            YYYY: y,
            h: H % 12 || 12,
            hh: this.pad(H % 12 || 12),
            H: H,
            HH: this.pad(H),
            m: m,
            mm: this.pad(m),
            s: s,
            ss: this.pad(s),
            S: Math.round(S / 100),
            SS: this.pad(Math.round(S / 10), 2),
            SSS: this.pad(S, 3),
            a: H < 12 ? this.i18n.amPm[0] : this.i18n.amPm[1],
            A: H < 12 ? this.i18n.amPm[0].toUpperCase() : this.i18n.amPm[1].toUpperCase(),
            ZZ: (o > 0 ? '-' : '+') + this.pad(Math.floor(Math.abs(o) / 60) * 100 + Math.abs(o) % 60, 4)
        };
        return mask.replace(this.token, ($0) => {
            return $0 in flags ? flags[$0] : $0.slice(1, $0.length - 1);
        });
    }
    ;
    /**
     * @param {?} dateString
     * @param {?} format
     * @return {?}
     */
    parse(dateString, format) {
        if (!dateString) {
            return null;
        }
        let /** @type {?} */ today, /** @type {?} */ date, /** @type {?} */ info, /** @type {?} */ index;
        let /** @type {?} */ isValid = true;
        let /** @type {?} */ dateInfo = {};
        if (typeof format !== 'string') {
            throw new Error('Invalid format in fecha.parse');
        }
        format = this.masks[format] || format;
        format.replace(this.token, ($0) => {
            if (this.parseFlags[$0]) {
                info = this.parseFlags[$0];
                index = dateString.search(info[0]);
                if (!~index) {
                    isValid = false;
                }
                else {
                    dateString.replace(info[0], (result) => {
                        info[1](dateInfo, result);
                        dateString = dateString.substr(index + result.length);
                        return result;
                    });
                }
            }
            return this.parseFlags[$0] ? '' : $0.slice(1, $0.length - 1);
        });
        if (!isValid) {
            return null;
        }
        today = new Date();
        if (dateInfo.isPm === true && dateInfo.hour != null && +dateInfo.hour !== 12) {
            dateInfo.hour = +dateInfo.hour + 12;
        }
        else if (dateInfo.isPm === false && +dateInfo.hour === 12) {
            dateInfo.hour = 0;
        }
        if (dateInfo.timezoneOffset != null) {
            dateInfo.minute = +(dateInfo.minute || 0) - +dateInfo.timezoneOffset;
            date = new Date(Date.UTC(dateInfo.year || today.getFullYear(), dateInfo.month || 0, dateInfo.day || 1, dateInfo.hour || 0, dateInfo.minute || 0, dateInfo.second || 0, dateInfo.millisecond || 0));
        }
        else {
            date = new Date(dateInfo.year || today.getFullYear(), dateInfo.month || 0, dateInfo.day || 1, dateInfo.hour || 0, dateInfo.minute || 0, dateInfo.second || 0, dateInfo.millisecond || 0);
        }
        return date;
    }
    ;
    /**
     * @param {?} dateString
     * @param {?} format
     * @return {?}
     */
    parseTime(dateString, format) {
        let /** @type {?} */ newDate = this.parse(dateString, format);
        return newDate ? newDate.getTime() : null;
    }
    /**
     * @param {?} date
     * @param {?} format
     * @return {?}
     */
    reduce(date, format) {
        return this.parse(this.format(date, format), format);
    }
    /**
     * @param {?} date
     * @param {?} format
     * @return {?}
     */
    reduceTime(date, format) {
        let /** @type {?} */ newDate = this.reduce(date, format);
        return newDate ? newDate.getTime() : null;
    }
    /**
     * @param {?=} date
     * @return {?}
     */
    getMaxDays(date = new Date()) {
        let /** @type {?} */ maxDays = new Date(date.getTime());
        maxDays.setMonth(maxDays.getMonth() + 1);
        maxDays.setDate(1);
        maxDays.setTime(maxDays.getTime() - 1000 * 60 * 60 * 24);
        return maxDays.getDate();
    }
    /**
     * @param {?} date
     * @return {?}
     */
    getDate(date) {
        if (date === null || isUndefined(date)) {
            return null;
        }
        if (isDate(date)) {
            return /** @type {?} */ (date);
        }
        return new Date(/** @type {?} */ (date));
    }
    /**
     * @param {?} date
     * @return {?}
     */
    getTime(date) {
        if (date === null || isUndefined(date)) {
            return null;
        }
        if (isDate(date)) {
            return (/** @type {?} */ (date)).getTime();
        }
        return /** @type {?} */ (date);
    }
}
DateService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DateService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 浏览器
 */
class BrowserService {
    constructor() {
        this._browser = {
            ie: false,
            ie11Compat: false,
            ie10Compat: false,
            ie9Compat: false,
            ie9above: false,
            ie9below: false,
            ie8: false,
            ie8Compat: false,
            ie7Compat: false,
            ie6Compat: false,
            opera: false,
            webkit: false,
            mac: false,
            quirks: false,
            gecko: false,
            firefox: false,
            chrome: false,
            safari: false,
            version: 0,
            webkitVersion: 0
        };
        let /** @type {?} */ agent = navigator.userAgent.toLowerCase();
        let /** @type {?} */ opera = window["opera"];
        this._browser.ie = /(msie\s|trident.*rv:)([\w.]+)/.test(agent);
        this._browser.opera = !!opera && opera.version;
        this._browser.firefox = agent.indexOf('firefox') > -1;
        this._browser.webkit = agent.indexOf(' applewebkit/') > -1;
        this._browser.quirks = document.compatMode === 'BackCompat';
        this._browser.gecko = navigator.product === 'Gecko' && !this._browser.webkit && !this._browser.opera && !this._browser.ie;
        // Internet Explorer 6.0+
        if (this._browser.ie) {
            let /** @type {?} */ v1 = agent.match(/(?:msie\s([\w.]+))/);
            let /** @type {?} */ v2 = agent.match(/(?:trident.*rv:([\w.]+))/);
            if (v1 && v2 && v1[1] && v2[1]) {
                this._browser.version = Math.max(parseInt(v1[1]), parseInt(v2[1]));
            }
            else if (v1 && v1[1]) {
                this._browser.version = parseInt(v1[1]);
            }
            else if (v2 && v2[1]) {
                this._browser.version = parseInt(v2[1]);
            }
            else {
                this._browser.version = 0;
            }
            // 检测浏览器模式是否为 IE11 兼容模式
            this._browser.ie11Compat = document["documentMode"] === 11;
            // 检测浏览器模式是否为 IE10 兼容模式
            this._browser.ie10Compat = document["documentMode"] === 10;
            // 检测浏览器模式是否为 IE9 兼容模式
            this._browser.ie9Compat = document["documentMode"] === 9;
            this._browser.ie9above = this._browser.version > 8;
            this._browser.ie9below = this._browser.version < 9;
            // 检测浏览器是否是IE8浏览器
            this._browser.ie8 = !!document["documentMode"];
            // 检测浏览器模式是否为 IE8 兼容模式
            this._browser.ie8Compat = document["documentMode"] === 8;
            // 检测浏览器模式是否为 IE7 兼容模式
            this._browser.ie7Compat = ((this._browser.version === 7 && !document["documentMode"]) || document["documentMode"] === 7);
            // 检测浏览器模式是否为 IE6 模式 或者怪异模式
            this._browser.ie6Compat = (this._browser.version < 7 || this._browser.quirks);
        }
        // Gecko.
        if (this._browser.gecko) {
            let /** @type {?} */ geckoRelease = agent.match(/rv:([\d\.]+)/);
            if (geckoRelease) {
                geckoRelease = geckoRelease[1].split('.');
                this._browser.version = parseInt(geckoRelease[0]) * 10000 + (parseInt(geckoRelease[1]) || 0) * 100 + (parseInt(geckoRelease[2]) || 0);
            }
        }
        // 检测当前浏览器是否为Chrome, 如果是，则返回Chrome的大版本号
        if (/chrome\/(\d+\.\d)/i.test(agent)) {
            this._browser.chrome = +RegExp['\x241'];
        }
        // 检测当前浏览器是否为Safari, 如果是，则返回Safari的大版本号
        if (/(\d+\.\d)?(?:\.\d)?\s+safari\/?(\d+\.\d+)?/i.test(agent) && !/chrome/i.test(agent)) {
            this._browser.safari = +(RegExp['\x241'] || RegExp['\x242']);
        }
        // Opera 9.50+
        if (this._browser.opera) {
            this._browser.version = parseFloat(opera.version());
        }
        // WebKit 522+ (Safari 3+)
        if (this._browser.webkit) {
            this._browser.webkitVersion = parseFloat(agent.match(/ applewebkit\/(\d+)/)[1]);
        }
    }
    /**
     * @return {?}
     */
    get browser() {
        return this._browser;
    }
    /**
     * @return {?}
     */
    get isFirefox() {
        return this._browser.firefox;
    }
}
BrowserService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
BrowserService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * MD5
 */
class Md5Service {
    /**
     * @param {?} x
     * @param {?} y
     * @return {?}
     */
    safe_add(x, y) {
        let /** @type {?} */ lsw = (x & 0xFFFF) + (y & 0xFFFF), /** @type {?} */
        msw = (x >> 16) + (y >> 16) + (lsw >> 16);
        return (msw << 16) | (lsw & 0xFFFF);
    }
    /**
     * @param {?} num
     * @param {?} cnt
     * @return {?}
     */
    bit_rol(num, cnt) {
        return (num << cnt) | (num >>> (32 - cnt));
    }
    /**
     * @param {?} q
     * @param {?} a
     * @param {?} b
     * @param {?} x
     * @param {?} s
     * @param {?} t
     * @return {?}
     */
    md5_cmn(q, a, b, x, s, t) {
        return this.safe_add(this.bit_rol(this.safe_add(this.safe_add(a, q), this.safe_add(x, t)), s), b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @param {?} c
     * @param {?} d
     * @param {?} x
     * @param {?} s
     * @param {?} t
     * @return {?}
     */
    md5_ff(a, b, c, d, x, s, t) {
        return this.md5_cmn((b & c) | ((~b) & d), a, b, x, s, t);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @param {?} c
     * @param {?} d
     * @param {?} x
     * @param {?} s
     * @param {?} t
     * @return {?}
     */
    md5_gg(a, b, c, d, x, s, t) {
        return this.md5_cmn((b & d) | (c & (~d)), a, b, x, s, t);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @param {?} c
     * @param {?} d
     * @param {?} x
     * @param {?} s
     * @param {?} t
     * @return {?}
     */
    md5_hh(a, b, c, d, x, s, t) {
        return this.md5_cmn(b ^ c ^ d, a, b, x, s, t);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @param {?} c
     * @param {?} d
     * @param {?} x
     * @param {?} s
     * @param {?} t
     * @return {?}
     */
    md5_ii(a, b, c, d, x, s, t) {
        return this.md5_cmn(c ^ (b | (~d)), a, b, x, s, t);
    }
    /**
     * @param {?} x
     * @param {?} len
     * @return {?}
     */
    binl_md5(x, len) {
        /* append padding */
        x[len >> 5] |= 0x80 << ((len) % 32);
        x[(((len + 64) >>> 9) << 4) + 14] = len;
        let /** @type {?} */ i, /** @type {?} */ olda, /** @type {?} */ oldb, /** @type {?} */ oldc, /** @type {?} */ oldd, /** @type {?} */
        a = 1732584193, /** @type {?} */
        b = -271733879, /** @type {?} */
        c = -1732584194, /** @type {?} */
        d = 271733878;
        for (i = 0; i < x.length; i += 16) {
            olda = a;
            oldb = b;
            oldc = c;
            oldd = d;
            a = this.md5_ff(a, b, c, d, x[i], 7, -680876936);
            d = this.md5_ff(d, a, b, c, x[i + 1], 12, -389564586);
            c = this.md5_ff(c, d, a, b, x[i + 2], 17, 606105819);
            b = this.md5_ff(b, c, d, a, x[i + 3], 22, -1044525330);
            a = this.md5_ff(a, b, c, d, x[i + 4], 7, -176418897);
            d = this.md5_ff(d, a, b, c, x[i + 5], 12, 1200080426);
            c = this.md5_ff(c, d, a, b, x[i + 6], 17, -1473231341);
            b = this.md5_ff(b, c, d, a, x[i + 7], 22, -45705983);
            a = this.md5_ff(a, b, c, d, x[i + 8], 7, 1770035416);
            d = this.md5_ff(d, a, b, c, x[i + 9], 12, -1958414417);
            c = this.md5_ff(c, d, a, b, x[i + 10], 17, -42063);
            b = this.md5_ff(b, c, d, a, x[i + 11], 22, -1990404162);
            a = this.md5_ff(a, b, c, d, x[i + 12], 7, 1804603682);
            d = this.md5_ff(d, a, b, c, x[i + 13], 12, -40341101);
            c = this.md5_ff(c, d, a, b, x[i + 14], 17, -1502002290);
            b = this.md5_ff(b, c, d, a, x[i + 15], 22, 1236535329);
            a = this.md5_gg(a, b, c, d, x[i + 1], 5, -165796510);
            d = this.md5_gg(d, a, b, c, x[i + 6], 9, -1069501632);
            c = this.md5_gg(c, d, a, b, x[i + 11], 14, 643717713);
            b = this.md5_gg(b, c, d, a, x[i], 20, -373897302);
            a = this.md5_gg(a, b, c, d, x[i + 5], 5, -701558691);
            d = this.md5_gg(d, a, b, c, x[i + 10], 9, 38016083);
            c = this.md5_gg(c, d, a, b, x[i + 15], 14, -660478335);
            b = this.md5_gg(b, c, d, a, x[i + 4], 20, -405537848);
            a = this.md5_gg(a, b, c, d, x[i + 9], 5, 568446438);
            d = this.md5_gg(d, a, b, c, x[i + 14], 9, -1019803690);
            c = this.md5_gg(c, d, a, b, x[i + 3], 14, -187363961);
            b = this.md5_gg(b, c, d, a, x[i + 8], 20, 1163531501);
            a = this.md5_gg(a, b, c, d, x[i + 13], 5, -1444681467);
            d = this.md5_gg(d, a, b, c, x[i + 2], 9, -51403784);
            c = this.md5_gg(c, d, a, b, x[i + 7], 14, 1735328473);
            b = this.md5_gg(b, c, d, a, x[i + 12], 20, -1926607734);
            a = this.md5_hh(a, b, c, d, x[i + 5], 4, -378558);
            d = this.md5_hh(d, a, b, c, x[i + 8], 11, -2022574463);
            c = this.md5_hh(c, d, a, b, x[i + 11], 16, 1839030562);
            b = this.md5_hh(b, c, d, a, x[i + 14], 23, -35309556);
            a = this.md5_hh(a, b, c, d, x[i + 1], 4, -1530992060);
            d = this.md5_hh(d, a, b, c, x[i + 4], 11, 1272893353);
            c = this.md5_hh(c, d, a, b, x[i + 7], 16, -155497632);
            b = this.md5_hh(b, c, d, a, x[i + 10], 23, -1094730640);
            a = this.md5_hh(a, b, c, d, x[i + 13], 4, 681279174);
            d = this.md5_hh(d, a, b, c, x[i], 11, -358537222);
            c = this.md5_hh(c, d, a, b, x[i + 3], 16, -722521979);
            b = this.md5_hh(b, c, d, a, x[i + 6], 23, 76029189);
            a = this.md5_hh(a, b, c, d, x[i + 9], 4, -640364487);
            d = this.md5_hh(d, a, b, c, x[i + 12], 11, -421815835);
            c = this.md5_hh(c, d, a, b, x[i + 15], 16, 530742520);
            b = this.md5_hh(b, c, d, a, x[i + 2], 23, -995338651);
            a = this.md5_ii(a, b, c, d, x[i], 6, -198630844);
            d = this.md5_ii(d, a, b, c, x[i + 7], 10, 1126891415);
            c = this.md5_ii(c, d, a, b, x[i + 14], 15, -1416354905);
            b = this.md5_ii(b, c, d, a, x[i + 5], 21, -57434055);
            a = this.md5_ii(a, b, c, d, x[i + 12], 6, 1700485571);
            d = this.md5_ii(d, a, b, c, x[i + 3], 10, -1894986606);
            c = this.md5_ii(c, d, a, b, x[i + 10], 15, -1051523);
            b = this.md5_ii(b, c, d, a, x[i + 1], 21, -2054922799);
            a = this.md5_ii(a, b, c, d, x[i + 8], 6, 1873313359);
            d = this.md5_ii(d, a, b, c, x[i + 15], 10, -30611744);
            c = this.md5_ii(c, d, a, b, x[i + 6], 15, -1560198380);
            b = this.md5_ii(b, c, d, a, x[i + 13], 21, 1309151649);
            a = this.md5_ii(a, b, c, d, x[i + 4], 6, -145523070);
            d = this.md5_ii(d, a, b, c, x[i + 11], 10, -1120210379);
            c = this.md5_ii(c, d, a, b, x[i + 2], 15, 718787259);
            b = this.md5_ii(b, c, d, a, x[i + 9], 21, -343485551);
            a = this.safe_add(a, olda);
            b = this.safe_add(b, oldb);
            c = this.safe_add(c, oldc);
            d = this.safe_add(d, oldd);
        }
        return [a, b, c, d];
    }
    /**
     * @param {?} input
     * @return {?}
     */
    binl2rstr(input) {
        let /** @type {?} */ i, /** @type {?} */
        output = '';
        for (i = 0; i < input.length * 32; i += 8) {
            output += String.fromCharCode((input[i >> 5] >>> (i % 32)) & 0xFF);
        }
        return output;
    }
    /**
     * @param {?} input
     * @return {?}
     */
    rstr2binl(input) {
        let /** @type {?} */ i, /** @type {?} */
        output = [];
        output[(input.length >> 2) - 1] = undefined;
        for (i = 0; i < output.length; i += 1) {
            output[i] = 0;
        }
        for (i = 0; i < input.length * 8; i += 8) {
            output[i >> 5] |= (input.charCodeAt(i / 8) & 0xFF) << (i % 32);
        }
        return output;
    }
    /**
     * @param {?} s
     * @return {?}
     */
    rstr_md5(s) {
        return this.binl2rstr(this.binl_md5(this.rstr2binl(s), s.length * 8));
    }
    /**
     * @param {?} key
     * @param {?} data
     * @return {?}
     */
    rstr_hmac_md5(key, data) {
        let /** @type {?} */ i, /** @type {?} */
        bkey = this.rstr2binl(key), /** @type {?} */
        ipad = [], /** @type {?} */
        opad = [], /** @type {?} */
        hash;
        ipad[15] = opad[15] = undefined;
        if (bkey.length > 16) {
            bkey = this.binl_md5(bkey, key.length * 8);
        }
        for (i = 0; i < 16; i += 1) {
            ipad[i] = bkey[i] ^ 0x36363636;
            opad[i] = bkey[i] ^ 0x5C5C5C5C;
        }
        hash = this.binl_md5(ipad.concat(this.rstr2binl(data)), 512 + data.length * 8);
        return this.binl2rstr(this.binl_md5(opad.concat(hash), 512 + 128));
    }
    /**
     * @param {?} input
     * @return {?}
     */
    rstr2hex(input) {
        let /** @type {?} */ hex_tab = '0123456789abcdef', /** @type {?} */
        output = '', /** @type {?} */
        x, /** @type {?} */
        i;
        for (i = 0; i < input.length; i += 1) {
            x = input.charCodeAt(i);
            output += hex_tab.charAt((x >>> 4) & 0x0F) +
                hex_tab.charAt(x & 0x0F);
        }
        return output;
    }
    /**
     * @param {?} input
     * @return {?}
     */
    str2rstr_utf8(input) {
        return encodeURI(encodeURIComponent(input));
    }
    /**
     * @param {?} s
     * @return {?}
     */
    raw_md5(s) {
        return this.rstr_md5(this.str2rstr_utf8(s));
    }
    /**
     * @param {?} s
     * @return {?}
     */
    hex_md5(s) {
        return this.rstr2hex(this.raw_md5(s));
    }
    /**
     * @param {?} k
     * @param {?} d
     * @return {?}
     */
    raw_hmac_md5(k, d) {
        return this.rstr_hmac_md5(this.str2rstr_utf8(k), this.str2rstr_utf8(d));
    }
    /**
     * @param {?} k
     * @param {?} d
     * @return {?}
     */
    hex_hmac_md5(k, d) {
        return this.rstr2hex(this.raw_hmac_md5(k, d));
    }
    /**
     * @param {?} value
     * @param {?=} raw
     * @return {?}
     */
    create(value, raw = false) {
        if (!raw) {
            return this.hex_md5(value);
        }
        else {
            return this.raw_md5(value);
        }
    }
    ;
    /**
     * @param {?} key
     * @param {?} value
     * @param {?=} raw
     * @return {?}
     */
    match(key, value, raw = false) {
        if (!raw) {
            return this.hex_hmac_md5(key, value);
        }
        else {
            return this.raw_hmac_md5(key, value);
        }
    }
}
Md5Service.decorators = [
    { type: Injectable },
];
/** @nocollapse */
Md5Service.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @record
 */

/** @enum {number} */
const TooltipLevel = {
    ERROR: 0,
    INFO: 1,
};
TooltipLevel[TooltipLevel.ERROR] = "ERROR";
TooltipLevel[TooltipLevel.INFO] = "INFO";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 定位提示框
 */
class TooltipService {
    /**
     * @param {?} toolsService
     */
    constructor(toolsService) {
        this.toolsService = toolsService;
        this.TOOLTIP_ID = "tooltip-id";
        this.openMap = {};
    }
    /**
     * @param {?} tooltipParams
     * @return {?}
     */
    open(tooltipParams) {
        let /** @type {?} */ host = $(tooltipParams.host);
        let /** @type {?} */ tooltipId = host.attr(this.TOOLTIP_ID);
        if (this.toolsService.isNull(tooltipParams.content)) {
            if (this.openMap[tooltipId]) {
                this.openMap[tooltipId].close();
            }
            return;
        }
        if (isUndefined(tooltipParams.time)) {
            tooltipParams.time = 5000;
        }
        if (isUndefined(tooltipParams.direction)) {
            tooltipParams.direction = "right";
        }
        if (isUndefined(tooltipParams.level)) {
            tooltipParams.level = TooltipLevel.ERROR;
        }
        let /** @type {?} */ tooltipComponent;
        if (tooltipId) {
            tooltipComponent = this.openMap[tooltipId];
        }
        else {
            tooltipComponent = new TooltipComponent(host, this.toolsService);
            tooltipId = this.toolsService.getRandomId();
            host.attr(this.TOOLTIP_ID, tooltipId);
            this.openMap[tooltipId] = tooltipComponent;
        }
        tooltipComponent.onClose = () => {
            host.attr(this.TOOLTIP_ID, "");
            delete this.openMap[tooltipId];
        };
        tooltipComponent.open(tooltipParams);
        return {
            close: () => {
                tooltipComponent.close();
            }
        };
    }
}
TooltipService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TooltipService.ctorParameters = () => [
    { type: ToolsService, },
];
class TooltipComponent {
    /**
     * @param {?} host
     * @param {?} toolsService
     */
    constructor(host, toolsService) {
        this.host = host;
        this.toolsService = toolsService;
        this.tooltip = $("<div></div>");
        this.arrow = $("<div></div>");
        this.content = $("<div></div>");
        this.tooltip.click(() => {
            this.close();
        });
        this.tooltip.append(this.arrow);
        this.tooltip.append(this.content);
        this.host.parent().append(this.tooltip);
    }
    /**
     * @param {?} tooltipParams
     * @return {?}
     */
    open(tooltipParams) {
        clearTimeout(this.closeTimer);
        clearTimeout(this.closeAnimateTimer);
        this.tooltip.removeClass();
        this.content.html(tooltipParams.content);
        if (tooltipParams.direction === "top") {
            this.direction = "top";
        }
        else if (tooltipParams.direction === "right") {
            this.direction = "right";
        }
        else if (tooltipParams.direction === "bottom") {
            this.direction = "bottom";
        }
        else if (tooltipParams.direction === "left") {
            this.direction = "left";
        }
        this.tooltip.addClass("animated small-fade-in-" + this.direction);
        if (tooltipParams.level === TooltipLevel.ERROR) {
            this.level = "error";
        }
        else if (tooltipParams.level === TooltipLevel.INFO) {
            this.level = "info";
        }
        this.tooltip.addClass("tooltip tooltip-" + this.level);
        this.arrow.removeClass();
        this.arrow.addClass("arrow" + " arrow-" + this.direction + " arrow-" + this.direction + "-" + this.level);
        this.tooltip.width(this.toolsService.getStringWidth(tooltipParams.content) + 2);
        let /** @type {?} */ width = this.tooltip.outerWidth();
        let /** @type {?} */ top = this.host[0].offsetTop;
        let /** @type {?} */ left = this.host[0].offsetLeft;
        let /** @type {?} */ hostWidth = this.host.outerWidth();
        let /** @type {?} */ hostHeight = this.host.outerHeight();
        let /** @type {?} */ tooltipHeight = this.tooltip.outerHeight();
        let /** @type {?} */ arrowSize = this.arrow.outerHeight() / 2;
        if (tooltipParams.direction === "top") {
            this.tooltip.css({
                "top": (top - (tooltipHeight + arrowSize)) + "px",
                "left": (left - ((width - hostWidth) / 2)) + "px"
            });
        }
        else if (tooltipParams.direction === "right") {
            this.tooltip.css({
                "top": top - ((tooltipHeight - hostHeight) / 2) + "px",
                "left": left + hostWidth + arrowSize + "px"
            });
        }
        else if (tooltipParams.direction === "bottom") {
            this.tooltip.css({
                "top": top + hostHeight + arrowSize + "px",
                "left": left - ((width - hostWidth) / 2) + "px"
            });
        }
        else if (tooltipParams.direction === "left") {
            this.tooltip.css({
                "top": top - ((tooltipHeight - hostHeight) / 2) + "px",
                "left": left - width - arrowSize + "px"
            });
        }
        if (tooltipParams.time <= 0) {
            return;
        }
        this.closeTimer = setTimeout(() => {
            this.close();
        }, tooltipParams.time);
    }
    /**
     * @return {?}
     */
    close() {
        clearTimeout(this.closeTimer);
        clearTimeout(this.closeAnimateTimer);
        this.tooltip.removeClass("animated small-fade-in-" + this.direction);
        this.tooltip.addClass("animated small-fade-out-" + this.direction);
        this.closeAnimateTimer = setTimeout(() => {
            this.tooltip.remove();
            this.onClose();
        }, 500);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 身份证
 */
class IdCardService {
    /**
     * @param {?} dateService
     */
    constructor(dateService) {
        this.dateService = dateService;
    }
    /**
     * @param {?} year
     * @param {?} month
     * @param {?} day
     * @return {?}
     */
    isDay(year, month, day) {
        if (year < 1700 || year > 2500) {
            return false;
        }
        if (month < 1 || month > 12) {
            return false;
        }
        let /** @type {?} */ monthDays = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
        if (((year % 4 === 0) && (year % 100 !== 0)) || (year % 400 === 0)) {
            monthDays[1] = 29;
        }
        return !(day < 1 || day > monthDays[month]);
    }
    /**
     * @param {?} date
     * @return {?}
     */
    isDate6(date) {
        if (!/^[0-9]{6}$/.test(date)) {
            return false;
        }
        let /** @type {?} */ year = 19 + parseInt(date.substring(0, 2));
        let /** @type {?} */ month = parseInt(date.substring(2, 4));
        let /** @type {?} */ day = parseInt(date.substring(4, 6));
        return this.isDay(year, month, day);
    }
    ;
    /**
     * @param {?} date
     * @return {?}
     */
    isDate8(date) {
        if (!/^[0-9]{8}$/.test(date)) {
            return false;
        }
        let /** @type {?} */ year = +parseInt(date.substring(0, 4));
        let /** @type {?} */ month = parseInt(date.substring(4, 6));
        let /** @type {?} */ day = parseInt(date.substring(6, 8));
        return this.isDay(year, month, day);
    }
    ;
    /**
     * @param {?} value
     * @return {?}
     */
    validate(value) {
        if (!value) {
            return false;
        }
        value = value.toUpperCase();
        let /** @type {?} */ factorArr = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2, 1];
        let /** @type {?} */ parityBit = ["1", "0", "X", "9", "8", "7", "6", "5", "4", "3", "2"];
        let /** @type {?} */ varArray = [];
        if ((value.length !== 15) && (value.length !== 18)) {
            return false;
        }
        for (let /** @type {?} */ i = 0; i < value.length; i++) {
            varArray[i] = value.charAt(i);
            if (i < 17) {
                varArray[i] = parseInt(varArray[i]) * factorArr[i];
            }
        }
        if (value.length === 18) {
            if (!this.isDate8(value.substring(6, 14))) {
                return false;
            }
            let /** @type {?} */ lngProduct = 0;
            for (let /** @type {?} */ i = 0; i < 17; i++) {
                lngProduct = lngProduct + parseInt(varArray[i]);
            }
            if (varArray[17] !== parityBit[lngProduct % 11]) {
                return false;
            }
        }
        else {
            if (!this.isDate6(value.substring(6, 12))) {
                return false;
            }
        }
        return true;
    }
    ;
    /**
     * @param {?} value
     * @return {?}
     */
    getBirthday(value) {
        if (!value) {
            return;
        }
        value = value + "";
        if (value.length === 15) {
            return this.dateService.parse("19" + value.substring(6, 12), "YYYYMMDD");
        }
        else if (value.length === 18) {
            return this.dateService.parse(value.substring(6, 14), "YYYYMMDD");
        }
    }
    ;
    /**
     * @param {?} value
     * @return {?}
     */
    getGender(value) {
        if (!value) {
            return;
        }
        value = value + "";
        if (value.length === 15) {
            return value.charAt(value.length - 1) % 2 === 0 ? "FEMALE" : "MALE";
        }
        if (value.length === 18) {
            return value.charAt(value.length - 2) % 2 === 0 ? "FEMALE" : "MALE";
        }
        return "MALE";
    }
    ;
}
IdCardService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
IdCardService.ctorParameters = () => [
    { type: DateService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const VALIDATOR_CHANGE_EVENT_NAME = "validatorChange";
/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/** @enum {number} */
const HandlerType = {
    hide: 0,
    // 直接隐藏
    reValidate: 1,
};
HandlerType[HandlerType.hide] = "hide";
HandlerType[HandlerType.reValidate] = "reValidate";
/**
 * @record
 */

/**
 * @record
 */

/**
 * 验证表单控件的node类型
 */
const INPUT = "input";
const SELECT = "select";
const TEXTAREA = "textarea";
const CUSTOM_VALIDATOR = ".custom-validator";
const JY_CUSTOM_VALIDATOR_VALUE = "jy-custom-validator-value";
const CUSTOM_VALIDATOR_VALUE_CHANGE = "customValidatorValueChange";
const VALIDATOR_SELECTOR_ARRAY = [INPUT, SELECT, TEXTAREA, CUSTOM_VALIDATOR];
const JY_VALIDATE = "jy-validate"; // 是否开验证器 true false 不设置属性和设置属性都默认true
const JY_VALIDATE_TYPE = "jy-validate-type";
/**
 * 数字类型验证时可以设置minnumber maxnumber来验证数据大小
 */
const VALIDATE_TYPE_INTEGER = "integer"; // 验证类型值 只能输入整数
const VALIDATE_TYPE_DOUBLE = "double"; // 验证类型值 只能输入整数和浮点数
const VALIDATE_TYPE_MOBILE = "mobile"; // 验证类型值 只能输入中国大陆手机号
const VALIDATE_TYPE_EMAIL = "email"; // 验证类型值 只能输入邮箱
const VALIDATE_TYPE_ID_CARD = "idCard"; // 验证类型值 只能输入中国大陆身份证号 支持15和18位
const JY_REQUIRED = "jy-required"; // 必填项 true false 不设置默认false 设置默认true
const JY_REQUIRED_MESSAGE = "jy-required-message"; // 必填项的错误提示 默认 必填项
const JY_PATTERN = "jy-pattern"; // 自定义正则 一定要传message参数 否则不提示
const JY_PATTERN_MESSAGE = "jy-pattern-message"; // 正则错误的提示信息
const JY_EQUALSLENGTH = "jy-equalslength"; // 相等的长度
const JY_MINLENGTH = "jy-minlength"; // 最小长度
const JY_MAXLENGTH = "jy-maxlength"; // 最大长度
const JY_MINNUMBER = "jy-minnumber"; // 最小值
const JY_MAXNUMBER = "jy-maxnumber"; // 最大值
const JY_TOOLTIP_DIRECTION = "jy-tooltip-direction";
/**
 * 验证器的类型
 */
const VALIDATE = "validate";
const VALIDATE_TYPE = "validate-type";
const CUSTOM = "custom";
const LENGTH = "length";
const REQUIRED = "required";
const PATTERN = "pattern";
const NUMBER_SIZE = "number-size";
/**
 * 错误信息
 */
const CHECK_IN = "校验中";
const ERROR_MESSAGE_REQUIRED = "必填项";
const ERROR_MESSAGE_EQUALSLENGTH = "长度必须为{0}";
const ERROR_MESSAGE_MINLENGTH = "最小长度为{0}";
const ERROR_MESSAGE_MAXLENGTH = "最大长度为{0}";
const ERROR_MESSAGE_MINNUMBER = "最小值为{0}";
const ERROR_MESSAGE_MAXNUMBER = "最大值为{0}";
const ERROR_MESSAGE_ONLY_INTEGER = "只能是整数";
const ERROR_MESSAGE_INTEGER_OR_DECIMAL = "只能是整数或小数";
const ERROR_MESSAGE_EMAIL = "邮箱格式不正确";
const ERROR_MESSAGE_ID_CARD = "身份证号验证错误";
const ERROR_MESSAGE_MOBILE = "手机号码不正确";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器
 */
class ValidatorService {
    /**
     * @param {?} toolsService
     * @param {?} idCardService
     * @param {?} tooltipService
     */
    constructor(toolsService, idCardService, tooltipService) {
        this.toolsService = toolsService;
        this.idCardService = idCardService;
        this.tooltipService = tooltipService;
        this.integerReg = /^[0-9]*$/;
        this.doubleReg = /^\d+(\.\d+)?$/;
        this.mobileReg = /^1\d{10}$/;
        this.email = /^[A-Za-z0-9\u4e00-\u9fa5]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$/;
    }
    /**
     * @param {?} text
     * @return {?}
     */
    isInteger(text) {
        return this.integerReg.test(text);
    }
    /**
     * @param {?} text
     * @return {?}
     */
    isDouble(text) {
        return this.doubleReg.test(text);
    }
    /**
     * @param {?} text
     * @return {?}
     */
    isMobile(text) {
        return this.mobileReg.test(text);
    }
    /**
     * @param {?} text
     * @return {?}
     */
    isEmail(text) {
        return this.email.test(text);
    }
    /**
     * @param {?} text
     * @return {?}
     */
    isIdCard(text) {
        return this.idCardService.validate(text);
    }
    /**
     * @param {?} elementControl
     * @param {?} elementControlArray
     * @return {?}
     */
    destroy(elementControl, elementControlArray) {
        this.removeHandler(elementControl);
        this.tooltipMessage(elementControl, null);
        elementControlArray.splice(elementControlArray.indexOf(elementControl), 1);
    }
    ;
    /**
     * @param {?} form
     * @param {?=} elementControlArray
     * @param {?=} selector
     * @param {?=} refresh
     * @return {?}
     */
    initNodeData(form, elementControlArray = [], selector, refresh) {
        let /** @type {?} */ deleteArray = [];
        if (refresh) {
            elementControlArray.forEach((elementControl) => {
                if (elementControl.selector === selector) {
                    deleteArray.push(elementControl);
                }
            });
        }
        let /** @type {?} */ formControls = form.find(selector);
        formControls.each((index, element) => {
            let /** @type {?} */ $element = $(element);
            let /** @type {?} */ name = $element.attr("name");
            if (!name) {
                return;
            }
            let /** @type {?} */ oldElementControl = elementControlArray.find(elementControl => elementControl.element.is($element));
            if (refresh) {
                if (oldElementControl && deleteArray.indexOf(oldElementControl) > -1) {
                    deleteArray.splice(deleteArray.indexOf(oldElementControl), 1);
                }
            }
            if (oldElementControl) {
                if (!refresh) {
                    throw new Error("ValidatorService name repetition:" + name);
                }
                else {
                    if (!oldElementControl.element.is($element)) {
                        this.destroy(oldElementControl, elementControlArray);
                    }
                    else {
                        return;
                    }
                }
            }
            elementControlArray.push({
                name: name,
                element: $element,
                selector: selector
            });
        });
        if (refresh) {
            deleteArray.forEach((elementControl) => {
                this.destroy(elementControl, elementControlArray);
            });
        }
    }
    /**
     * @param {?} elementControl
     * @param {?} errorMessage
     * @return {?}
     */
    tooltipMessage(elementControl, errorMessage) {
        if (!elementControl || elementControl.lockTooltip) {
            return;
        }
        elementControl.errorMessage = errorMessage && errorMessage.message ? errorMessage : null;
        elementControl.tooltipControl = this.tooltipService.open({
            host: elementControl.element,
            content: errorMessage ? errorMessage.message : "",
            time: 0,
            direction: elementControl.element.attr(JY_TOOLTIP_DIRECTION) ? /** @type {?} */ (elementControl.element.attr(JY_TOOLTIP_DIRECTION)) : "right",
            closeHandler: () => {
                elementControl.errorMessage = null;
                elementControl.tooltipControl = null;
            }
        });
    }
    /**
     * @param {?} elementControl
     * @param {?} customEventArray
     * @return {?}
     */
    initHandler(elementControl, customEventArray) {
        if (elementControl.event) {
            return;
        }
        let /** @type {?} */ element = elementControl.element;
        let /** @type {?} */ nodeName = element[0].nodeName.toLocaleLowerCase();
        let /** @type {?} */ getValue = undefined;
        if (nodeName === INPUT) {
            getValue = () => {
                return element.val();
            };
        }
        else if (nodeName === TEXTAREA) {
            getValue = () => {
                return element.val();
            };
        }
        else if (nodeName === SELECT) {
            getValue = () => {
                return element.val();
            };
        }
        else if (element.is(CUSTOM_VALIDATOR)) {
            getValue = () => {
                return element.attr(JY_CUSTOM_VALIDATOR_VALUE);
            };
        }
        elementControl.event = {
            keyup: () => {
                let /** @type {?} */ value = getValue();
                if (element.attr(JY_VALIDATE) === "false") {
                    return null;
                }
                if (element.attr(JY_REQUIRED)) {
                    if (this.toolsService.isNull(value)) {
                        return {
                            message: element.attr(JY_REQUIRED_MESSAGE) ? element.attr(JY_REQUIRED_MESSAGE) : ERROR_MESSAGE_REQUIRED,
                            type: REQUIRED
                        };
                    }
                }
                if (this.toolsService.isNull(value)) {
                    return null;
                }
                let /** @type {?} */ maxlength = this.toolsService.parseInt(element.attr(JY_MAXLENGTH));
                if (this.toolsService.isNotNull(maxlength) && value.length > maxlength) {
                    return {
                        message: this.toolsService.replaceArgs(ERROR_MESSAGE_MAXLENGTH, maxlength.toString()),
                        type: LENGTH
                    };
                }
                let /** @type {?} */ validateType = element.attr(JY_VALIDATE_TYPE);
                if (validateType) {
                    if (validateType === VALIDATE_TYPE_INTEGER) {
                        if (!this.isInteger(value)) {
                            return {
                                message: ERROR_MESSAGE_ONLY_INTEGER,
                                type: VALIDATE_TYPE
                            };
                        }
                    }
                    else if (validateType === VALIDATE_TYPE_DOUBLE) {
                        if (!this.isDouble(value)) {
                            return {
                                message: ERROR_MESSAGE_INTEGER_OR_DECIMAL,
                                type: VALIDATE_TYPE
                            };
                        }
                    }
                    if (validateType === VALIDATE_TYPE_INTEGER || validateType === VALIDATE_TYPE_DOUBLE) {
                        let /** @type {?} */ maxnumber = this.toolsService.parseInt(element.attr(JY_MAXNUMBER));
                        if (this.toolsService.isNotNull(maxnumber) && parseInt(value) > maxnumber) {
                            return {
                                message: this.toolsService.replaceArgs(ERROR_MESSAGE_MAXNUMBER, maxnumber.toString()),
                                type: VALIDATE_TYPE + "|" + NUMBER_SIZE
                            };
                        }
                    }
                }
                if (customEventArray) {
                    let /** @type {?} */ customEvent = customEventArray.find(item => item.name === elementControl.name);
                    if (customEvent && customEvent.keyup) {
                        let /** @type {?} */ response = customEvent.keyup(value);
                        if (response) {
                            return {
                                message: response,
                                type: CUSTOM
                            };
                        }
                    }
                }
                return null;
            },
            keyupHandler: (event) => {
                if (event.keyCode === 9) {
                    // tab不做处理
                    return;
                }
                this.tooltipMessage(elementControl, elementControl.event.keyup());
            },
            blur: (callback) => {
                if (element.attr(JY_VALIDATE) === "false") {
                    callback(null);
                    return;
                }
                let /** @type {?} */ firstStepMessage = elementControl.event.keyup();
                if (firstStepMessage) {
                    callback(firstStepMessage);
                    return;
                }
                let /** @type {?} */ value = getValue();
                if (this.toolsService.isNull(value)) {
                    callback(null);
                    return;
                }
                let /** @type {?} */ equalslength = this.toolsService.parseInt(element.attr(JY_EQUALSLENGTH));
                if (this.toolsService.isNotNull(equalslength) && equalslength !== value.length) {
                    callback({
                        message: this.toolsService.replaceArgs(ERROR_MESSAGE_EQUALSLENGTH, equalslength.toString()),
                        type: LENGTH
                    });
                    return;
                }
                let /** @type {?} */ minlength = this.toolsService.parseInt(element.attr(JY_MINLENGTH));
                if (this.toolsService.isNotNull(minlength) && value.length < minlength) {
                    callback({
                        message: this.toolsService.replaceArgs(ERROR_MESSAGE_MINLENGTH, minlength.toString()),
                        type: LENGTH
                    });
                    return;
                }
                let /** @type {?} */ pattern = element.attr(JY_PATTERN);
                if (pattern && !((new RegExp(pattern)).test(value))) {
                    callback({
                        message: element.attr(JY_PATTERN_MESSAGE),
                        type: PATTERN
                    });
                    return;
                }
                let /** @type {?} */ validateType = element.attr(JY_VALIDATE_TYPE);
                if (validateType) {
                    if (validateType === VALIDATE_TYPE_EMAIL) {
                        if (!this.isEmail(value)) {
                            callback({
                                message: ERROR_MESSAGE_EMAIL,
                                type: VALIDATE_TYPE
                            });
                            return;
                        }
                    }
                    else if (validateType === VALIDATE_TYPE_ID_CARD) {
                        if (!this.isIdCard(value)) {
                            callback({
                                message: ERROR_MESSAGE_ID_CARD,
                                type: VALIDATE_TYPE
                            });
                            return;
                        }
                    }
                    else if (validateType === VALIDATE_TYPE_MOBILE) {
                        if (!this.isMobile(value)) {
                            callback({
                                message: ERROR_MESSAGE_MOBILE,
                                type: VALIDATE_TYPE
                            });
                            return;
                        }
                    }
                    else if (validateType === VALIDATE_TYPE_INTEGER || validateType === VALIDATE_TYPE_DOUBLE) {
                        let /** @type {?} */ minnumber = this.toolsService.parseInt(element.attr(JY_MINNUMBER));
                        if (this.toolsService.isNotNull(minnumber) && parseInt(value) < minnumber) {
                            callback({
                                message: this.toolsService.replaceArgs(ERROR_MESSAGE_MINNUMBER, minnumber.toString()),
                                type: VALIDATE_TYPE + "|" + NUMBER_SIZE
                            });
                            return;
                        }
                    }
                }
                if (customEventArray) {
                    let /** @type {?} */ customEvent = customEventArray.find(item => item.name === elementControl.name);
                    if (customEvent && customEvent.blur) {
                        let /** @type {?} */ response = customEvent.blur(value);
                        if (response) {
                            if (isString(response)) {
                                callback({
                                    message: response,
                                    type: CUSTOM
                                });
                            }
                            else {
                                let /** @type {?} */ resetDisabled;
                                if (!element.attr("disabled")) {
                                    element.attr("disabled", "disabled");
                                    let /** @type {?} */ oldTitle = element.attr("title");
                                    element.attr("title", CHECK_IN);
                                    resetDisabled = () => {
                                        element.removeAttr("disabled");
                                        if (oldTitle) {
                                            element.attr("title", oldTitle);
                                        }
                                        else {
                                            element.removeAttr("title");
                                        }
                                    };
                                } /** @type {?} */
                                (response.then((message) => {
                                    if (message) {
                                        callback({
                                            message: message,
                                            type: CUSTOM
                                        });
                                    }
                                    else {
                                        callback(null);
                                    }
                                    if (resetDisabled !== null) {
                                        resetDisabled();
                                    }
                                }));
                            }
                            return;
                        }
                    }
                }
                callback(null);
            },
            blurHandler: () => {
                elementControl.event.blur((errorMessage) => {
                    this.tooltipMessage(elementControl, errorMessage);
                });
            },
            validatorChangeHandler: (event, validatorChange) => {
                if (elementControl.errorMessage) {
                    let /** @type {?} */ match = false;
                    for (let /** @type {?} */ value of validatorChange.validateType.split("|")) {
                        if (elementControl.errorMessage.type === value || value === "validate") {
                            match = true;
                        }
                    }
                    if (!match) {
                        return;
                    }
                }
                if (validatorChange.handlerType === HandlerType.hide) {
                    this.tooltipMessage(elementControl, null);
                }
                else if (validatorChange.handlerType === HandlerType.reValidate) {
                    elementControl.event.blurHandler();
                }
            }
        };
        if (nodeName === INPUT || nodeName === TEXTAREA) {
            element.on("keyup", elementControl.event.keyupHandler);
            element.on("blur", elementControl.event.blurHandler);
        }
        else if (nodeName === SELECT) {
            element.on("blur", elementControl.event.blurHandler);
            element.on("change", elementControl.event.blurHandler);
        }
        else if (element.is(CUSTOM_VALIDATOR)) {
            element.on(CUSTOM_VALIDATOR_VALUE_CHANGE, elementControl.event.blurHandler);
        }
        element.on(VALIDATOR_CHANGE_EVENT_NAME, elementControl.event.validatorChangeHandler);
    }
    /**
     * @param {?} elementControl
     * @return {?}
     */
    removeHandler(elementControl) {
        if (elementControl.selector === INPUT || elementControl.selector === TEXTAREA) {
            elementControl.element.off("keyup", elementControl.event.keyupHandler);
            elementControl.element.off("blur", elementControl.event.blurHandler);
        }
        else if (elementControl.selector === SELECT) {
            elementControl.element.off("change", elementControl.event.blurHandler);
            elementControl.element.off("blur", elementControl.event.blurHandler);
        }
        else if (elementControl.element.is(CUSTOM_VALIDATOR)) {
            elementControl.element.off(CUSTOM_VALIDATOR_VALUE_CHANGE, elementControl.event.blurHandler);
        }
        elementControl.element.off(VALIDATOR_CHANGE_EVENT_NAME, elementControl.event.validatorChangeHandler);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    getValidatorDisabled(value) {
        let /** @type {?} */ validatorDisabledArray = [];
        if (this.toolsService.isNull(value)) {
            return validatorDisabledArray;
        }
        if (isArray(value)) {
            let /** @type {?} */ itemArray = /** @type {?} */ (value);
            for (let /** @type {?} */ item of itemArray) {
                if (item.hasOwnProperty("element")) {
                    validatorDisabledArray.push(item);
                }
                else {
                    validatorDisabledArray.push({
                        element: item
                    });
                }
            }
        }
        else {
            validatorDisabledArray.push({
                element: /** @type {?} */ (value)
            });
        }
        return validatorDisabledArray;
    }
    /**
     * @param {?} form
     * @param {?=} async
     * @param {?=} customEvent
     * @return {?}
     */
    init(form, async = false, customEvent) {
        let /** @type {?} */ $form = $(form);
        let /** @type {?} */ elementControlArray = [];
        let /** @type {?} */ customEventArray;
        if (customEvent) {
            if (isArray(customEvent)) {
                customEventArray = /** @type {?} */ (customEvent);
            }
            else {
                customEventArray = [/** @type {?} */ (customEvent)];
            }
        }
        let /** @type {?} */ destroy = false;
        let /** @type {?} */ loadView = (refresh) => {
            VALIDATOR_SELECTOR_ARRAY.forEach((selector) => {
                this.initNodeData($form, elementControlArray, selector, refresh);
            });
            elementControlArray.forEach((elementControl) => {
                this.initHandler(elementControl, customEventArray);
            });
        };
        if (!async) {
            loadView(false);
        }
        else {
            setTimeout(() => {
                loadView(false);
            });
        }
        elementControlArray.forEach(item => {
            item.lockTooltip = true;
        });
        setTimeout(() => {
            elementControlArray.forEach(item => {
                item.lockTooltip = false;
            });
        }, 1000);
        return {
            validate: (validatorParams) => {
                if (isFunction(validatorParams)) {
                    (/** @type {?} */ (validatorParams)).success = /** @type {?} */ (validatorParams);
                }
                if (destroy) {
                    throw new Error("Validator is destroyed");
                }
                if (elementControlArray.length === 0) {
                    (/** @type {?} */ (validatorParams)).success();
                    return;
                }
                let /** @type {?} */ disabledArray = this.getValidatorDisabled((/** @type {?} */ (validatorParams)).disabled);
                for (let /** @type {?} */ disabled of disabledArray) {
                    ((_disabled) => {
                        let /** @type {?} */ element = $(_disabled.element);
                        let /** @type {?} */ oldHtml = element.html();
                        if (_disabled.message !== null) {
                            element.html(_disabled.message ? _disabled.message : CHECK_IN);
                        }
                        element.attr("disabled", "disabled");
                        _disabled.callback = () => {
                            if (_disabled.message !== null) {
                                element.html(oldHtml);
                            }
                            element.removeAttr("disabled");
                        };
                    })(disabled);
                }
                let /** @type {?} */ resetDisabled = () => {
                    for (let /** @type {?} */ disabled of disabledArray) {
                        disabled.callback();
                    }
                };
                let /** @type {?} */ validateLength = 0;
                let /** @type {?} */ success = true;
                let /** @type {?} */ errorPositionFlag = (/** @type {?} */ (validatorParams)).dontPositionErrorInput;
                elementControlArray.forEach((elementControl) => {
                    elementControl.event.blur((errorMessage) => {
                        this.tooltipMessage(elementControl, errorMessage);
                        if (errorMessage) {
                            success = false;
                            if (!errorPositionFlag) {
                                errorPositionFlag = true;
                                this.toolsService.positionFocus(elementControl.element);
                            }
                        }
                        if (++validateLength === elementControlArray.length) {
                            if (success) {
                                let /** @type {?} */ endFlag = (/** @type {?} */ (validatorParams)).success(resetDisabled);
                                if (endFlag !== false) {
                                    resetDisabled();
                                }
                            }
                            else {
                                if ((/** @type {?} */ (validatorParams)).error) {
                                    (/** @type {?} */ (validatorParams)).error();
                                }
                                resetDisabled();
                            }
                        }
                    });
                });
            },
            destroy: () => {
                if (destroy) {
                    return;
                }
                elementControlArray.forEach((elementControl) => {
                    this.destroy(elementControl, elementControlArray);
                });
                destroy = true;
            },
            tooltip: (name, message) => {
                this.tooltipMessage(elementControlArray.find(elementControl => elementControl.name === name), {
                    type: CUSTOM,
                    message: message
                });
            },
            closeAllTooltip: () => {
                elementControlArray.forEach(item => {
                    item.lockTooltip = true;
                    if (item.tooltipControl) {
                        item.tooltipControl.close();
                    }
                });
                setTimeout(() => {
                    elementControlArray.forEach(item => {
                        item.lockTooltip = false;
                    });
                }, 100);
            },
            refresh: (_async = true) => {
                if (!_async) {
                    loadView(true);
                }
                else {
                    setTimeout(() => {
                        loadView(true);
                    });
                }
            }
        };
    }
}
ValidatorService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ValidatorService.ctorParameters = () => [
    { type: ToolsService, },
    { type: IdCardService, },
    { type: TooltipService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 缓存
 */
class StorageService {
    /**
     * @param {?} toolsService
     * @param {?} httpService
     */
    constructor(toolsService, httpService) {
        this.toolsService = toolsService;
        this.httpService = httpService;
        this.DISABLED = "COMMON_DISABLED_";
        this.INTERVAL_TIME = "_INTERVAL_TIME";
    }
    /**
     * @param {?} id
     * @return {?}
     */
    getSessionStorage(id) {
        this.validateId(id);
        if (sessionStorage) {
            return sessionStorage.getItem(id);
        }
        return null;
    }
    /**
     * @param {?} id
     * @param {?=} defaultValue
     * @return {?}
     */
    getSessionStorageObject(id, defaultValue = null) {
        let /** @type {?} */ value = this.getSessionStorage(id);
        if (this.toolsService.isNotNull(value)) {
            return JSON.parse(value);
        }
        else {
            return this.toolsService.isNotNull(defaultValue) ? defaultValue : null;
        }
    }
    /**
     * @param {?} id
     * @param {?} resolve
     * @param {?} callback
     * @param {?=} intervalTime
     * @return {?}
     */
    getSessionStorageOrOtherObject(id, resolve, callback, intervalTime = null) {
        let /** @type {?} */ data = this.getSessionStorageObject(id);
        let /** @type {?} */ execute = () => {
            new Promise(_resolve => {
                resolve(_resolve);
            }).then((promiseData) => {
                this.setSessionStorageObject(id, promiseData);
                if (intervalTime) {
                    this.setSessionStorage(id + this.INTERVAL_TIME, new Date(new Date().getTime() + intervalTime).getTime());
                }
                callback(promiseData);
            });
        };
        if (data == null) {
            execute();
        }
        else {
            callback(data);
            let /** @type {?} */ nextIntervalTime = this.getSessionStorage(id + this.INTERVAL_TIME);
            if (!intervalTime || !nextIntervalTime || new Date().getTime() > nextIntervalTime) {
                execute();
            }
        }
    }
    ;
    /**
     * @param {?} getHttpData
     * @return {?}
     */
    getSessionStorageOrHttpData(getHttpData) {
        if (getHttpData.method !== "post") {
            getHttpData.method = "get";
        }
        this.getSessionStorageOrOtherObject(getHttpData.id, (resolve) => {
            this.httpService.request({
                url: getHttpData.url,
                method: getHttpData.method,
                params: getHttpData.params,
                body: getHttpData.body,
                success: (data) => {
                    resolve(data);
                }
            });
        }, (data) => {
            getHttpData.callback(data);
        }, getHttpData.intervalTime);
    }
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setSessionStorage(id, value) {
        this.validateId(id);
        if (sessionStorage) {
            if (this.toolsService.isNotNull(value)) {
                sessionStorage.removeItem(id);
                sessionStorage.setItem(id, value);
            }
            else {
                this.clearSessionStorage(id);
            }
        }
    }
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setSessionStorageObject(id, value) {
        if (this.toolsService.isNotNull(value)) {
            this.setSessionStorage(id, JSON.stringify(value));
        }
        else {
            this.clearSessionStorage(id);
        }
    }
    /**
     * @param {?} id
     * @return {?}
     */
    clearSessionStorage(id) {
        this.validateId(id);
        if (sessionStorage) {
            sessionStorage.removeItem(id);
        }
    }
    ;
    /**
     * @param {?} id
     * @return {?}
     */
    getLocalStorage(id) {
        this.validateId(id);
        if (localStorage) {
            return localStorage.getItem(id);
        }
        return null;
    }
    ;
    /**
     * @param {?} id
     * @param {?=} defaultValue
     * @return {?}
     */
    getLocalStorageObject(id, defaultValue = null) {
        let /** @type {?} */ value = this.getLocalStorage(id);
        if (this.toolsService.isNotNull(value)) {
            return JSON.parse(value);
        }
        else {
            return this.toolsService.isNotNull(defaultValue) ? defaultValue : null;
        }
    }
    /**
     * @param {?} id
     * @param {?} resolve
     * @param {?} callback
     * @param {?=} intervalTime
     * @return {?}
     */
    getLocalStorageOrOtherObject(id, resolve, callback, intervalTime = null) {
        let /** @type {?} */ data = this.getLocalStorageObject(id);
        let /** @type {?} */ execute = () => {
            new Promise(_resolve => {
                resolve(_resolve);
            }).then((promiseData) => {
                this.setLocalStorageObject(id, promiseData);
                if (intervalTime) {
                    this.setLocalStorage(id + this.INTERVAL_TIME, new Date(new Date().getTime() + intervalTime).getTime());
                }
                callback(promiseData);
            });
        };
        if (data == null) {
            execute();
        }
        else {
            callback(data);
            let /** @type {?} */ nextIntervalTime = this.getLocalStorage(id + this.INTERVAL_TIME);
            if (!intervalTime || !nextIntervalTime || new Date().getTime() > nextIntervalTime) {
                execute();
            }
        }
    }
    ;
    /**
     * @param {?} getHttpData
     * @return {?}
     */
    getLocalStorageOrHttpData(getHttpData) {
        if (getHttpData.method !== "post") {
            getHttpData.method = "get";
        }
        this.getLocalStorageOrOtherObject(getHttpData.id, (resolve) => {
            this.httpService.request({
                url: getHttpData.url,
                method: getHttpData.method,
                params: getHttpData.params,
                body: getHttpData.body,
                success: (data) => {
                    resolve(data);
                }
            });
        }, (data) => {
            getHttpData.callback(data);
        }, getHttpData.intervalTime);
    }
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setLocalStorage(id, value) {
        this.validateId(id);
        if (localStorage) {
            if (this.toolsService.isNotNull(value)) {
                localStorage.removeItem(id);
                localStorage.setItem(id, value);
            }
            else {
                this.clearLocalStorage(id);
            }
        }
    }
    ;
    /**
     * @param {?} id
     * @param {?} value
     * @return {?}
     */
    setLocalStorageObject(id, value) {
        if (this.toolsService.isNotNull(value)) {
            this.setLocalStorage(id, JSON.stringify(value));
        }
        else {
            this.clearLocalStorage(id);
        }
    }
    ;
    /**
     * @param {?} id
     * @return {?}
     */
    clearLocalStorage(id) {
        this.validateId(id);
        if (localStorage) {
            localStorage.removeItem(id);
        }
    }
    ;
    /**
     * @param {?} id
     * @return {?}
     */
    validateId(id) {
        if (!id) {
            throw new Error("storage id is Invalid");
        }
    }
}
StorageService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
StorageService.ctorParameters = () => [
    { type: ToolsService, },
    { type: HttpService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * windowResize
 */
class GlobalEventsService {
    /**
     * @param {?} toolsService
     */
    constructor(toolsService) {
        this.toolsService = toolsService;
        this.clickWindowResizeSelector = [];
        this.$window = $(window);
        this.$body = $(document.body);
        this.addBodyClick((event) => {
            let /** @type {?} */ target = $(event.target);
            for (let /** @type {?} */ selector of this.clickWindowResizeSelector) {
                if (target.is(selector)) {
                    this.windowResize();
                    break;
                }
            }
        });
    }
    /**
     * @param {?} clickWindowResizeSelector
     * @return {?}
     */
    addClickWindowResizeSelector(clickWindowResizeSelector) {
        for (let /** @type {?} */ selector of clickWindowResizeSelector) {
            this.clickWindowResizeSelector.push(selector);
        }
    }
    /**
     * @param {?} globalEventsProvider
     * @return {?}
     */
    setProvider(globalEventsProvider) {
        if (!globalEventsProvider) {
            return;
        }
        this.addClickWindowResizeSelector(globalEventsProvider.getClickWindowResizeSelector());
    }
    /**
     * @param {?} handler
     * @param {?=} id
     * @return {?}
     */
    addWindowResize(handler, id = null) {
        if (id === null) {
            id = this.toolsService.getRandomId();
        }
        this.$window.on("resize." + id, handler);
        return () => {
            this.$window.off("resize." + id);
        };
    }
    /**
     * @param {?} handler
     * @param {?=} id
     * @return {?}
     */
    addBodyClick(handler, id = null) {
        if (id === null) {
            id = this.toolsService.getRandomId();
        }
        this.$body.on("click." + id, handler);
        return () => {
            this.$body.off("click." + id);
        };
    }
    /**
     * @return {?}
     */
    windowResize() {
        if (this.windowResizeTimer) {
            return;
        }
        this.$window.resize();
        setTimeout(() => {
            this.$window.resize();
        });
        this.windowResizeTimer = setTimeout(() => {
            clearTimeout(this.windowResizeTimer);
            this.windowResizeTimer = null;
            this.$window.resize();
        }, 100);
    }
}
GlobalEventsService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
GlobalEventsService.ctorParameters = () => [
    { type: ToolsService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FileUploadService {
    /**
     * @param {?} alertService
     * @param {?} toolsService
     * @param {?} httpService
     */
    constructor(alertService, toolsService, httpService) {
        this.alertService = alertService;
        this.toolsService = toolsService;
        this.httpService = httpService;
        this.defaultFileIcon = "icon-file";
        this.filePostfixMap = {
            "icon-file-text": ["txt"],
            "icon-file-pdf": ["pdf"],
            "icon-file-word": ["doc", "docx"],
            "icon-file-excel": ["xls", "xlsx"],
            "icon-file-ppt": ["ppt", "pptx"],
            "icon-file-image": ["bmp", "jpg", "jpeg", "png", "gif"],
            "icon-file-zip": ["rar", "tar", "zip", "gzip", "7z", "iso", "jar"],
            "icon-file-sound": ["cd", "ogg", "mp3", "flac"],
            "icon-file-video": ["avi", "rmvb", "rm", "mpg", "mpeg", "mpe", "wmv", "mp4", "mkv", "vob"]
        };
    }
    /**
     * @param {?} fileUploadProvider
     * @return {?}
     */
    setProvider(fileUploadProvider) {
        if (!fileUploadProvider) {
            return;
        }
        this.fileUploadProvider = fileUploadProvider;
        this.fileServerBaseUrl = fileUploadProvider.getFileServerBaseUrl();
        this.uploadUrl = this.toolsService.getFullUrl(this.fileServerBaseUrl, "upload.do");
        this.getUrl = this.toolsService.getFullUrl(this.fileServerBaseUrl, "get.do");
        this.getInfoUrl = this.toolsService.getFullUrl(this.fileServerBaseUrl, "getInfo.do");
    }
    /**
     * @param {?} fileId
     * @return {?}
     */
    getFileUrl(fileId) {
        return this.getUrl + "?fileId=" + fileId;
    }
    /**
     * @param {?} fileId
     * @param {?} callback
     * @return {?}
     */
    getFileInfo(fileId, callback) {
        this.httpService.get({
            url: this.getInfoUrl + "?fileId=" + fileId,
            success: (fileInfo) => {
                callback(fileInfo);
            }
        });
    }
    /**
     * @param {?} fileSize
     * @return {?}
     */
    formatFileSize(fileSize) {
        if (fileSize / 1024 < 1) {
            return fileSize.toFixed(2) + "B";
        }
        fileSize = fileSize / 1024;
        if (fileSize / 1024 < 1) {
            return fileSize.toFixed(2) + "KB";
        }
        fileSize = fileSize / 1024;
        if (fileSize / 1024 < 1) {
            return fileSize.toFixed(2) + "MB";
        }
        fileSize = fileSize / 1024;
        return fileSize.toFixed(2) + "GB";
    }
    ;
    /**
     * @param {?} params
     * @return {?}
     */
    upload(params) {
        let /** @type {?} */ file = params.file;
        let /** @type {?} */ formData = new FormData();
        formData.append(params.name ? params.name : "file", file);
        if (params.body) {
            for (let /** @type {?} */ key in params.body) {
                if (key) {
                    formData.append(key, params.body[key]);
                }
            }
        }
        let /** @type {?} */ loaded1 = 0;
        let /** @type {?} */ loaded2 = 0;
        let /** @type {?} */ currentSpeed = "";
        let /** @type {?} */ timer;
        let /** @type {?} */ calculateSpeed = () => {
            currentSpeed = this.formatFileSize(loaded1 - loaded2) + "/S";
            loaded2 = loaded1;
            return true;
        };
        let /** @type {?} */ speedPerSecond = () => {
            calculateSpeed();
            timer = setInterval(calculateSpeed, 1000);
        };
        let /** @type {?} */ httpRequest = new XMLHttpRequest();
        httpRequest.upload.addEventListener("progress", (event) => {
            loaded1 = event.loaded;
            if (loaded2 === 0) {
                calculateSpeed();
            }
            let /** @type {?} */ percent = Math.round(event.loaded * 100 / event.total);
            if (percent === 100) {
                clearInterval(timer);
            }
            if (params.progress) {
                params.progress(event, {
                    percent: percent,
                    currentSpeed: currentSpeed,
                    loaded: this.formatFileSize(event.loaded < file.size ? event.loaded : file.size)
                });
            }
        }, false);
        httpRequest.addEventListener("load", (event) => {
            let /** @type {?} */ status = event.target["status"];
            let /** @type {?} */ response = event.target["response"];
            let /** @type {?} */ data = null;
            let /** @type {?} */ parseData = () => {
                if (response) {
                    try {
                        data = JSON.parse(response);
                    }
                    catch (/** @type {?} */ e) {
                        this.alertService.open({
                            iconType: Icon.error,
                            content: "网络异常，请稍后再试！"
                        });
                        clearInterval(timer);
                        if (params.error) {
                            params.error(event, response);
                        }
                    }
                }
            };
            if (status > 500) {
                this.alertService.open({
                    iconType: Icon.error,
                    content: "网络异常，请稍后再试！"
                });
            }
            else if (status === 500) {
                parseData();
                if (data && (!params.error || params.alwaysPrompt || params.alwaysPrompt == null)) {
                    this.alertService.open({ content: data.message });
                }
                clearInterval(timer);
                if (params.error) {
                    params.error(event, data);
                }
            }
            else {
                parseData();
                if (params.success) {
                    params.success(event, data);
                }
            }
        }, false);
        httpRequest.addEventListener("error", (event) => {
            clearInterval(timer);
            let /** @type {?} */ response = event.target["response"];
            if (response) {
                try {
                    if (params.error) {
                        params.error(event, JSON.parse(response));
                    }
                }
                catch (/** @type {?} */ e) {
                    this.alertService.open({
                        iconType: Icon.error,
                        content: "网络异常，请稍后再试！"
                    });
                }
            }
        }, false);
        httpRequest.addEventListener("abort", (event) => {
            clearInterval(timer);
            if (params.cancel) {
                params.cancel(event);
            }
        }, false);
        httpRequest.open("POST", params.url ? this.toolsService.getFullUrl(this.fileServerBaseUrl, params.url) : this.uploadUrl);
        httpRequest.setRequestHeader("Accept", "application/json");
        httpRequest.setRequestHeader("X-Requested-With", "XMLHttpRequest");
        httpRequest.setRequestHeader("User-Token", this.fileUploadProvider.getFileServerUserToken());
        if (params.init) {
            let /** @type {?} */ postfix = "";
            if (file.name != null && file.name.indexOf(".") > -1) {
                let /** @type {?} */ postfixArray = file.name.split(".");
                postfix = postfixArray[postfixArray.length - 1];
            }
            params.init({
                name: file.name,
                size: file.size,
                formatSize: this.formatFileSize(file.size),
                type: file.type,
                postfix: postfix,
                start: () => {
                    httpRequest.send(formData);
                    speedPerSecond();
                },
                cancel: () => {
                    httpRequest.abort();
                }
            });
        }
        else {
            httpRequest.send(formData);
            speedPerSecond();
        }
    }
    /**
     * @param {?} postfix
     * @return {?}
     */
    getFileIcon(postfix) {
        if (postfix) {
            postfix = postfix.trim();
        }
        if (!postfix) {
            return this.defaultFileIcon;
        }
        let /** @type {?} */ fileIcon = null;
        for (let /** @type {?} */ key of postfix.split(",")) {
            key = key.substring(key.lastIndexOf(".") + 1, key.length);
            for (let /** @type {?} */ icon in this.filePostfixMap) {
                if (icon && this.filePostfixMap[icon].indexOf(key) > -1) {
                    if (fileIcon && fileIcon !== icon) {
                        return this.defaultFileIcon;
                    }
                    fileIcon = icon;
                }
            }
        }
        return fileIcon ? fileIcon : this.defaultFileIcon;
    }
}
FileUploadService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
FileUploadService.ctorParameters = () => [
    { type: AlertService, },
    { type: ToolsService, },
    { type: HttpService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 动态创建组件
 */
class DynamicComponentService {
    /**
     * @param {?} componentFactoryResolver
     */
    constructor(componentFactoryResolver) {
        this.componentFactoryResolver = componentFactoryResolver;
    }
    /**
     * @param {?} dynamicComponentFactoryProvider
     * @return {?}
     */
    setProvider(dynamicComponentFactoryProvider) {
        if (!dynamicComponentFactoryProvider) {
            return;
        }
        this.dynamicComponentFactoryProvider = dynamicComponentFactoryProvider;
    }
    /**
     * @param {?} dynamicComponent
     * @param {?} component
     * @param {?=} transmitData
     * @return {?}
     */
    createBySelector(dynamicComponent, component, transmitData = null) {
        console.log("DynamicComponent:" + component);
        return this.createByComponentFactory(dynamicComponent, this.dynamicComponentFactoryProvider.getComponentFactoryMap()[component], transmitData);
    }
    /**
     * @template T
     * @param {?} dynamicComponent
     * @param {?} component
     * @param {?=} transmitData
     * @return {?}
     */
    createByComponent(dynamicComponent, component, transmitData = null) {
        let /** @type {?} */ componentFactory = this.componentFactoryResolver.resolveComponentFactory(component);
        return this.createByComponentFactory(dynamicComponent, componentFactory, transmitData);
    }
    /**
     * @template T
     * @param {?} dynamicComponent
     * @param {?} componentFactory
     * @param {?=} transmitData
     * @return {?}
     */
    createByComponentFactory(dynamicComponent, componentFactory, transmitData = null) {
        let /** @type {?} */ componentRef = dynamicComponent.createComponent(componentFactory, null, dynamicComponent.parentInjector);
        $(dynamicComponent.element.nativeElement).append($(componentRef.location.nativeElement));
        let /** @type {?} */ instance = componentRef.instance;
        if (transmitData && instance["setTransmitData"]) {
            (/** @type {?} */ (instance)).setTransmitData(transmitData);
        }
        return componentRef;
    }
}
DynamicComponentService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DynamicComponentService.ctorParameters = () => [
    { type: ComponentFactoryResolver, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 组件内部使用
 */
class RightClickMenuComponent {
    constructor() {
        this.show = false;
        this.dataList = null;
        this.itemClickHandler = null;
        this.position = { x: 0, y: 0 };
    }
    /**
     * @param {?} event
     * @param {?} item
     * @return {?}
     */
    itemClick(event, item) {
        if (!this.show) {
            return;
        }
        event.preventDefault();
        if (this.itemClickHandler) {
            this.itemClickHandler(item);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.show = true;
        });
    }
}
RightClickMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-right-click-menu',
                template: `<div class="right-click-menu" [ngStyle]="{'left.px': position.x,'top.px': position.y}"
     [@fadeOnlyShow]="show ? 'show':'hide'">
  <ul>
    <li *ngFor="let item of dataList" (click)="itemClick($event,item)">{{item.label}}</li>
  </ul>
</div>
`,
                styles: [`@charset "utf-8";.right-click-menu{color:rgba(0,0,0,.8);border-radius:.17857143rem;position:fixed;z-index:99999;outline:0;background-color:#fff;border:.03571429rem solid #ccc;-webkit-box-shadow:0 .17857143rem .35714286rem rgba(0,0,0,.2);box-shadow:0 .17857143rem .35714286rem rgba(0,0,0,.2)}.right-click-menu ul li{padding:.25rem .71428571rem;cursor:pointer}.right-click-menu ul li:hover{background-color:#e6e6e6}`],
                animations: [fadeOnlyShow]
            },] },
];
/** @nocollapse */
RightClickMenuComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 框架层使用 无需关心
 */
const RIGHT_CLICK_MENU = ".right-click-menu";
/**
 * 组件内部使用
 * @record
 */

/**
 * 菜单类型 暂不支持多级菜单有需要联系我
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 组件内部使用
 */
class RightClickMenuService {
    /**
     * @param {?} componentFactoryResolver
     * @param {?} toolsService
     */
    constructor(componentFactoryResolver, toolsService) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.toolsService = toolsService;
        this._currentOpenComponentId = null;
        // 禁用鼠标右键
        document.oncontextmenu = (event) => {
            if (this.toolsService.jqNotNull($(event.target).closest(RIGHT_CLICK_MENU))) {
                event.preventDefault();
            }
        };
    }
    /**
     * @param {?} rightClickMenuProvider
     * @return {?}
     */
    setProvider(rightClickMenuProvider) {
        if (!rightClickMenuProvider) {
            return;
        }
        this.rightClickMenuProvider = rightClickMenuProvider;
    }
    /**
     * @param {?} id
     * @return {?}
     */
    createComponent(id) {
        if (this.isOpen(id)) {
            return this._currentOpenComponentRef;
        }
        this.closeCurrentComponent();
        this._currentOpenComponentRef = this.rightClickMenuProvider.getRightMenuContainer().createComponent(this.componentFactoryResolver.resolveComponentFactory(RightClickMenuComponent));
        this._currentOpenComponentId = id;
        return this._currentOpenComponentRef;
    }
    /**
     * @return {?}
     */
    closeCurrentComponent() {
        if (this._currentOpenComponentRef) {
            this._currentOpenComponentRef.destroy();
            this._currentOpenComponentRef = null;
            this._currentOpenComponentId = null;
        }
    }
    /**
     * @param {?} id
     * @return {?}
     */
    closeComponent(id) {
        if (this.isOpen(id)) {
            this.closeCurrentComponent();
        }
    }
    /**
     * @param {?} id
     * @return {?}
     */
    isOpen(id) {
        return this._currentOpenComponentId === id;
    }
}
RightClickMenuService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
RightClickMenuService.ctorParameters = () => [
    { type: ComponentFactoryResolver, },
    { type: ToolsService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DatetimePickerService {
    /**
     * @param {?} dateService
     */
    constructor(dateService) {
        this.dateService = dateService;
        this.yearList = [];
        this.monthList = [];
        this.hoursList = [];
        this.minutesList = [];
        this.secondsList = [];
        this.minDate = null;
        this.maxDate = null;
        for (let /** @type {?} */ i = 1900; i <= 2099; i++) {
            this.yearList.push({ disabled: false, value: i, label: i.toString() });
        }
        for (let /** @type {?} */ i = 1; i <= 12; i++) {
            this.monthList.push({ disabled: false, value: i, label: (i < 10 ? "0" : "") + i.toString() });
        }
        for (let /** @type {?} */ i = 0; i <= 23; i++) {
            this.hoursList.push({ disabled: false, value: i, label: (i < 10 ? "0" : "") + i.toString() });
        }
        for (let /** @type {?} */ i = 0; i <= 59; i++) {
            this.minutesList.push({ disabled: false, value: i, label: (i < 10 ? "0" : "") + i.toString() });
        }
        for (let /** @type {?} */ i = 0; i <= 59; i++) {
            this.secondsList.push({ disabled: false, value: i, label: (i < 10 ? "0" : "") + i.toString() });
        }
        this.minDate = dateService.parse("1900-01-01 00:00:00:000", dateService.YYYYMMDDHHMMSSSSS);
        this.maxDate = dateService.parse("2099-12-31 23:59:59:999", dateService.YYYYMMDDHHMMSSSSS);
    }
    /**
     * @return {?}
     */
    getYearList() {
        return JSON.parse(JSON.stringify(this.yearList));
    }
    /**
     * @return {?}
     */
    getMonthList() {
        return JSON.parse(JSON.stringify(this.monthList));
    }
    /**
     * @return {?}
     */
    getHoursList() {
        return JSON.parse(JSON.stringify(this.hoursList));
    }
    /**
     * @return {?}
     */
    getMinutesList() {
        return JSON.parse(JSON.stringify(this.minutesList));
    }
    /**
     * @return {?}
     */
    getSecondsListt() {
        return JSON.parse(JSON.stringify(this.secondsList));
    }
    /**
     * @return {?}
     */
    getMinDate() {
        return new Date(this.minDate.getTime());
    }
    /**
     * @return {?}
     */
    getMaxDate() {
        return new Date(this.maxDate.getTime());
    }
}
DatetimePickerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DatetimePickerService.ctorParameters = () => [
    { type: DateService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/7/19.
 */
/**
 * toast
 */
class ToastComponent {
    constructor() {
        this.openList = [];
    }
    /**
     * @param {?} toastModalParams
     * @return {?}
     */
    setTransmitData(toastModalParams) {
        toastModalParams.init({
            add: (insideToastParams) => {
                if (insideToastParams.timer === null || isUndefined(insideToastParams.timer)) {
                    insideToastParams.timer = 3000;
                }
                if (!insideToastParams.iconType) {
                    insideToastParams.iconType = Icon.success;
                }
                insideToastParams.preClose = () => {
                    insideToastParams.closeFlag = true;
                };
                insideToastParams.change = (iconType, content) => {
                    insideToastParams.iconType = iconType;
                    insideToastParams.content = content;
                };
                insideToastParams.close = () => {
                    if (this.openList.indexOf(insideToastParams) < 0) {
                        return;
                    }
                    this.openList.splice(this.openList.indexOf(insideToastParams), 1);
                    if (insideToastParams.closeHandler) {
                        insideToastParams.closeHandler();
                    }
                };
                if (insideToastParams.timer && insideToastParams.timer > 0) {
                    setTimeout(() => {
                        insideToastParams.closeFlag = true;
                    }, insideToastParams.timer);
                }
                this.openList.push(insideToastParams);
                if (this.openList.length > 5) {
                    for (let /** @type {?} */ i = 0; i < this.openList.length - 5; i++) {
                        this.openList[i].closeFlag = true;
                    }
                }
            }
        });
    }
    /**
     * @param {?} event
     * @param {?} insideToastParams
     * @return {?}
     */
    closed(event, insideToastParams) {
        if (event.toState === "hide" && event.totalTime > 0) {
            insideToastParams.close();
        }
    }
    /**
     * @return {?}
     */
    close() {
    }
}
ToastComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-toast',
                template: `<div class="toast">
  <div class="toast-box" *ngFor="let item of openList">
    <div class="toast-item" (click)="item.preClose()" [@fadeShow]="item.closeFlag ? 'hide':'show'"
         [@slideInUp]="item.closeFlag ? 'up':'down'" (@fadeShow.done)="closed($event,item)">
      <span [ngClass]="{
      'icon-spinner': item.iconType === 'loading',
      'animation-icon-spin': item.iconType === 'loading',
      'icon-ok-circle-solid': item.iconType === 'success',
      'icon-cancel-circle-solid': item.iconType === 'error',
      'icon-warning-circle-solid': item.iconType === 'warning',
      'icon-info-circle-solid': item.iconType === 'info',
      'icon-question-circle-solid': item.iconType === 'question'
      }"></span>
      <span class="toast-content">{{item.content}}</span>
    </div>
  </div>
</div>
`,
                styles: [`.toast{position:fixed;width:100%;top:.57142857rem;left:0;pointer-events:none}.toast .toast-box{text-align:center;width:100%;margin-top:.17857143rem}.toast .toast-box .toast-item{padding:.28571429rem .57142857rem;border-radius:.14285714rem;-webkit-box-shadow:0 .07142857rem .28571429rem rgba(0,0,0,.2);box-shadow:0 .07142857rem .28571429rem rgba(0,0,0,.2);background:#fff;display:inline-block;pointer-events:all;cursor:pointer}.toast .toast-box .toast-item [class*=" icon-"],.toast .toast-box .toast-item [class^=icon-]{font-size:.57142857rem;float:left}.toast .toast-box .toast-item .icon-spinner{color:gray}.toast .toast-box .toast-item .icon-ok-circle-solid{color:#1ec434}.toast .toast-box .toast-item .icon-info-circle-solid{color:#00b6f3}.toast .toast-box .toast-item .icon-question-circle-solid{color:#ffb201}.toast .toast-box .toast-item .icon-cancel-circle-solid{color:#ff5e5e}.toast .toast-box .toast-item .icon-warning-circle-solid{color:#ff8e35}.toast .toast-box .toast-item .toast-content{float:left;margin-left:.28571429rem;padding-top:.07142857rem}`],
                animations: [fadeShow, slideInUp]
            },] },
];
/** @nocollapse */
ToastComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/6/28.
 */
/**
 * toast提示框
 */
class ToastService {
    /**
     * @param {?} modalService
     */
    constructor(modalService) {
        this.modalService = modalService;
    }
    /**
     * @param {?} toastParams
     * @return {?}
     */
    open(toastParams) {
        if (isString(toastParams)) {
            toastParams = /** @type {?} */ ({ content: toastParams });
        }
        let /** @type {?} */ insideToastParams = {
            content: (/** @type {?} */ (toastParams)).content,
            iconType: (/** @type {?} */ (toastParams)).iconType,
            timer: (/** @type {?} */ (toastParams)).timer,
            closeHandler: (/** @type {?} */ (toastParams)).closeHandler
        };
        this.totalToastControl.add(insideToastParams);
        return {
            close: () => {
                insideToastParams.preClose();
            },
            change: (iconType, content) => {
                insideToastParams.change(iconType, content);
            }
        };
    }
    /**
     * @return {?}
     */
    init() {
        let /** @type {?} */ toastModalParams = {
            modalTop: true,
            init: (totalToastControl) => {
                this.totalToastControl = totalToastControl;
            }
        };
        this.modalService.open(toastModalParams, ToastComponent);
    }
}
ToastService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ToastService.ctorParameters = () => [
    { type: ModalService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 动态组件
 */
class DynamicComponentComponent {
    /**
     * @param {?} viewContainerRef
     * @param {?} dynamicComponentService
     */
    constructor(viewContainerRef, dynamicComponentService) {
        this.viewContainerRef = viewContainerRef;
        this.dynamicComponentService = dynamicComponentService;
        this.onComponentRefInit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            if (isString(this.componentSelector)) {
                this.onComponentRefInit.emit(this.dynamicComponentService.createBySelector(this.viewContainerRef, this.componentSelector, this.transmitData));
            }
            else {
                this.onComponentRefInit.emit(this.dynamicComponentService.createByComponent(this.viewContainerRef, this.componentSelector, this.transmitData));
            }
        });
    }
}
DynamicComponentComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-dynamic-component',
                template: `<div></div>
`
            },] },
];
/** @nocollapse */
DynamicComponentComponent.ctorParameters = () => [
    { type: ViewContainerRef, },
    { type: DynamicComponentService, },
];
DynamicComponentComponent.propDecorators = {
    "componentSelector": [{ type: Input },],
    "transmitData": [{ type: Input },],
    "onComponentRefInit": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 右键菜单指令
 * [jyRightClickMenu] = [{label:"菜单1",value:1}]
 * (onMenuClick) = onMenuClick($event) $event = {label:"菜单1",value:1}
 */
class RightClickMenuDirective {
    /**
     * @param {?} elementRef
     * @param {?} rightClickMenuService
     */
    constructor(elementRef, rightClickMenuService) {
        this.elementRef = elementRef;
        this.rightClickMenuService = rightClickMenuService;
        this.dataList = null;
        this.onMenuClick = new EventEmitter();
        this.id = Symbol();
        this.componentRef = null;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        $(this.elementRef.nativeElement).addClass(RIGHT_CLICK_MENU.replace(".", ""));
    }
    /**
     * @param {?} dataList
     * @return {?}
     */
    set jyRightClickMenu(dataList) {
        this.dataList = dataList;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onmousedown(event) {
        if (event.button !== 2 || !this.dataList) {
            return;
        }
        this.componentRef = this.rightClickMenuService.createComponent(this.id);
        this.componentRef.instance.dataList = this.dataList;
        this.componentRef.instance.position = {
            x: event.clientX,
            y: event.clientY,
        };
        this.componentRef.instance.itemClickHandler = (item) => {
            this.onMenuClick.emit(item);
            this.rightClickMenuService.closeComponent(this.id);
        };
    }
    /**
     * @return {?}
     */
    onDocumentClick() {
        this.rightClickMenuService.closeComponent(this.id);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.rightClickMenuService.closeComponent(this.id);
    }
}
RightClickMenuDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyRightClickMenu]"
            },] },
];
/** @nocollapse */
RightClickMenuDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: RightClickMenuService, },
];
RightClickMenuDirective.propDecorators = {
    "jyRightClickMenu": [{ type: Input },],
    "onMenuClick": [{ type: Output },],
    "onmousedown": [{ type: HostListener, args: ["mousedown", ["$event"],] },],
    "onDocumentClick": [{ type: HostListener, args: ["document:click",] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 年月日 日期控件
 */
class YmdComponent {
    /**
     * @param {?} elementRef
     * @param {?} dateService
     * @param {?} toolsService
     * @param {?} tooltipService
     * @param {?} datetimePickerService
     */
    constructor(elementRef, dateService, toolsService, tooltipService, datetimePickerService) {
        this.elementRef = elementRef;
        this.dateService = dateService;
        this.toolsService = toolsService;
        this.tooltipService = tooltipService;
        this.datetimePickerService = datetimePickerService;
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this._minDate = null;
        this._maxDate = null;
        this._date = null;
        this._dateString = null;
        this.lastDate = null;
        this.lastDateString = "";
        this.dateChange = new EventEmitter();
        this.dateStringChange = new EventEmitter();
        this.eventIdClass = ".datetime-picker" + (Math.random() + "").replace(".", "");
        this.format = "YYYYMMDD";
        this.viewYear = null;
        this.viewMonth = null;
        this.yearList = null;
        this.monthList = null;
        this.weekList = [];
        this.viewDate = new Date();
        this.show = false;
        this.mouseEnter = false;
        this.transparent = true;
        this.clickHandler = null;
        let /** @type {?} */ host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.datetimePicker.addClass(this.eventIdClass.replace(".", ""));
    }
    /**
     * @param {?} minDate
     * @return {?}
     */
    set minDate(minDate) {
        this._minDate = this.dateService.reduceTime(minDate, this.dateService.YYYYMMDD);
        if (!this.validateRange(this._date).success) {
            this._date = null;
            this._dateString = "";
            this.emitDateChange();
        }
    }
    /**
     * @param {?} minDate
     * @return {?}
     */
    set minDateString(minDate) {
        this.minDate = this.dateService.parseTime(minDate, this.dateService.YYYYMMDD);
    }
    /**
     * @param {?} maxDate
     * @return {?}
     */
    set maxDate(maxDate) {
        this._maxDate = this.dateService.reduceTime(maxDate, this.dateService.YYYYMMDD);
        if (!this.validateRange(this._date).success) {
            this._date = null;
            this._dateString = "";
            this.emitDateChange();
        }
    }
    /**
     * @param {?} maxDate
     * @return {?}
     */
    set maxDateString(maxDate) {
        this.maxDate = this.dateService.parseTime(maxDate, this.dateService.YYYYMMDD);
    }
    /**
     * @param {?} date
     * @return {?}
     */
    set date(date) {
        date = this.dateService.reduceTime(date, this.dateService.YYYYMMDD);
        if (this._date === date) {
            return;
        }
        this._date = date;
        if (this._date !== null) {
            this._dateString = this.dateService.format(this._date, this.dateService.YYYYMMDD);
            if (!this.validateRange(this._date).success) {
                this._date = null;
                this._dateString = "";
            }
        }
        else {
            this._date = null;
            this._dateString = "";
        }
        this.emitDateChange();
    }
    /**
     * @param {?} dateString
     * @return {?}
     */
    set dateString(dateString) {
        if (this._dateString === dateString) {
            return;
        }
        this._dateString = dateString;
        if (this._dateString) {
            this._date = this.dateService.parseTime(this._dateString, this.dateService.YYYYMMDD);
            if (!this.validateRange(this._date).success) {
                this._date = null;
                this._dateString = "";
            }
        }
        else {
            this._date = null;
            this._dateString = "";
        }
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    emitDateChange() {
        setTimeout(() => {
            if (this.lastDate !== this._date) {
                this.dateChange.emit(this._date);
                this.lastDate = this._date;
                this.input[0].dispatchEvent(new Event("blur"));
            }
            if (this.lastDateString !== this._dateString) {
                this.dateStringChange.emit(this._dateString);
                this.lastDateString = this._dateString;
                this.input[0].dispatchEvent(new Event("blur"));
            }
            this.customValidatorControl.trigger(this._date ? this._date.toString() : "");
        });
    }
    /**
     * @param {?} datetimePicker
     * @return {?}
     */
    set _datetimePicker(datetimePicker) {
        this.datetimePicker = $(datetimePicker.nativeElement);
    }
    ;
    /**
     * @param {?} box
     * @return {?}
     */
    set _box(box) {
        this.box = $(box.nativeElement);
    }
    ;
    /**
     * @param {?} input
     * @return {?}
     */
    set _input(input) {
        this.input = $(input.nativeElement);
    }
    ;
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (event.keyCode === 13) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    keyup() {
        this._dateString = this.input.val();
        let /** @type {?} */ date = this.dateService.getDate(this.getCheckDateString(false, true));
        if (date) {
            this.viewDate = date;
            this.viewYear = date.getFullYear().toString();
            this.viewMonth = (date.getMonth() + 1).toString();
            this.calculateView(this.viewDate);
        }
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.disabled || this.show) {
            return;
        }
        this.show = true;
        this.transparent = true;
        this.input.addClass("search-input-focus");
        this.viewDate = this._date !== null ? new Date(this._date) : new Date();
        const /** @type {?} */ validateResult = this.validateRange(this.viewDate, false, true);
        if (!validateResult.success) {
            if (!validateResult.minDateSuccess) {
                this.viewDate = validateResult.minDate;
            }
            else if (!validateResult.maxDateSuccess) {
                this.viewDate = validateResult.maxDate;
            }
        }
        this.viewYear = this.viewDate.getFullYear().toString();
        this.viewMonth = (this.viewDate.getMonth() + 1).toString();
        this.calculateView(this.viewDate);
        this.rangeDateChange();
        setTimeout(() => {
            this.onWindowResize();
            this.transparent = false;
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.input, this.direction);
    }
    /**
     * @param {?=} check
     * @return {?}
     */
    viewHide(check = true) {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.input.removeClass("search-input-focus");
        if (check) {
            this._date = this.getCheckDateString();
            this._dateString = this._date ? this.dateService.format(this._date, this.dateService.YYYYMMDD) : "";
            this.emitDateChange();
        }
        this.input.blur();
    }
    /**
     * @param {?=} clear
     * @param {?=} noAlert
     * @return {?}
     */
    getCheckDateString(clear = false, noAlert = false) {
        const /** @type {?} */ dateString = this._dateString ? this._dateString.replace(/[^0-9]/ig, "") : "";
        let /** @type {?} */ date = null;
        if (dateString.length >= 8) {
            date = this.dateService.parse(dateString.substring(0, 8), this.format);
        }
        else if (date == null && dateString.length >= 7) {
            const /** @type {?} */ mm1 = parseInt(dateString.substring(4, 6));
            if (mm1 <= 12) {
                date = this.dateService.parse(dateString.substring(0, 6) + "0" + (dateString.charAt(6) === "0" ? "1" : dateString.charAt(6)), this.format);
            }
            else {
                date = this.dateService.parse(dateString.substring(0, 4) + "0" + dateString.charAt(5) + dateString.substring(5, 7), this.format);
            }
        }
        else if (date == null && dateString.length >= 6) {
            if (dateString.charAt(4) !== "0") {
                date = this.dateService.parse(dateString.substring(0, 4) + "0" + dateString.charAt(4) + "0" + dateString.charAt(5), this.format);
            }
            else {
                date = this.dateService.parse(dateString.substring(0, 6) + "01", this.format);
            }
        }
        else if (date == null && dateString.length >= 5) {
            if (dateString.charAt(4) !== "0") {
                date = this.dateService.parse(dateString.substring(0, 4) + "0" + dateString.charAt(4) + "01", this.format);
            }
            else {
                date = this.dateService.parse(dateString.substring(0, 4) + "0101", this.format);
            }
        }
        else if (date == null && dateString.length >= 4) {
            date = this.dateService.parse(dateString.substring(0, 4) + "0101", this.format);
        }
        if (!this.validateRange(date, false, noAlert).success) {
            if (clear) {
                this._dateString = "";
                this._date = null;
            }
            return null;
        }
        return this.dateService.getTime(date);
    }
    /**
     * @param {?} date
     * @return {?}
     */
    calculateView(date) {
        date = new Date(date.getFullYear(), date.getMonth(), 1, 0, 0, 0, 0);
        let /** @type {?} */ newWeekList = [];
        let /** @type {?} */ maxDays = this.dateService.getMaxDays(date);
        let /** @type {?} */ firstDay = date.getDay();
        if (firstDay === 0) {
            firstDay = 7;
        }
        let /** @type {?} */ selectDate = this.dateService.format(this._date, this.dateService.YYYYMMDD);
        let /** @type {?} */ todayDate = this.dateService.format(new Date(), this.dateService.YYYYMMDD);
        let /** @type {?} */ day = 1;
        let /** @type {?} */ week = [];
        for (let /** @type {?} */ i = 0; day <= maxDays || i % 7 !== 0; i++) {
            if (i !== 0 && i % 7 === 0) {
                newWeekList.push(week);
                week = [];
            }
            let /** @type {?} */ currentDate = null;
            let /** @type {?} */ current = false;
            if (i + 1 < firstDay) {
                /**
                 * 上个月的
                 */
                let /** @type {?} */ lastDate = new Date(date.getTime());
                lastDate.setDate(1);
                lastDate.setTime(lastDate.getTime() - (firstDay - i - 1) * 1000 * 60 * 60 * 24);
                currentDate = lastDate;
            }
            else {
                if (day <= maxDays) {
                    /**
                               * 当前月
                               */
                    date.setDate(day);
                    current = true;
                    day++;
                }
                else {
                    /**
                               * 下个月
                               */
                    date.setTime(date.getTime() + 1000 * 60 * 60 * 24);
                }
                currentDate = date;
            }
            let /** @type {?} */ currentDateString = this.dateService.format(currentDate, this.dateService.YYYYMMDD);
            let /** @type {?} */ today = todayDate === currentDateString;
            let /** @type {?} */ select = selectDate === currentDateString;
            let /** @type {?} */ disabled = false;
            if (this._minDate && this.dateService.format(currentDate, this.dateService.YYYYMMDD) < this.dateService.format(this._minDate, this.dateService.YYYYMMDD)) {
                disabled = true;
            }
            else if (this._maxDate && this.dateService.format(currentDate, this.dateService.YYYYMMDD) > this.dateService.format(this._maxDate, this.dateService.YYYYMMDD)) {
                disabled = true;
            }
            week.push({
                day: currentDate.getDate(),
                date: new Date(currentDate.getTime()),
                current: today ? true : current,
                today: today,
                select: select,
                disabled: disabled
            });
        }
        newWeekList.push(week);
        if (!this.weekList || JSON.stringify(this.weekList) !== JSON.stringify(newWeekList)) {
            this.weekList = newWeekList;
        }
    }
    /**
     * @return {?}
     */
    rangeDateChange() {
        if (this.yearList == null) {
            this.yearList = this.datetimePickerService.getYearList();
            this.monthList = this.datetimePickerService.getMonthList();
        }
        else {
            this.yearList.forEach((item) => {
                item.disabled = false;
            });
            this.monthList.forEach((item) => {
                item.disabled = false;
            });
        }
        let /** @type {?} */ minDate = this.getMinDate();
        let /** @type {?} */ maxDate = this.getMaxDate();
        let /** @type {?} */ minYear = minDate.getFullYear();
        let /** @type {?} */ maxYear = maxDate.getFullYear();
        let /** @type {?} */ minMonth = minDate.getMonth() + 1;
        let /** @type {?} */ maxMonth = maxDate.getMonth() + 1;
        this.yearList.forEach((item) => {
            item.disabled = item.value < minYear || item.value > maxYear;
        });
        if (this.viewYear && (parseInt(this.viewYear) === minYear || parseInt(this.viewYear) === maxYear)) {
            this.monthList.forEach((item) => {
                item.disabled = item.value < minMonth || item.value > maxMonth;
            });
        }
        this.yearList = JSON.parse(JSON.stringify(this.yearList));
        this.monthList = JSON.parse(JSON.stringify(this.monthList));
    }
    /**
     * @param {?=} event
     * @return {?}
     */
    lastYear(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(-1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    lastMonth(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(0, -1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    nextMonth(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(0, 1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    nextYear(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(1);
    }
    ;
    /**
     * @param {?} value
     * @return {?}
     */
    monthMousewheel(value) {
        if (value < 0) {
            this.lastMonth();
        }
        else if (value > 0) {
            this.nextMonth();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    yearMousewheel(value) {
        if (value < 0) {
            this.lastYear();
        }
        else if (value > 0) {
            this.nextYear();
        }
    }
    /**
     * @param {?=} viewYearDiff
     * @param {?=} viewMonthDiff
     * @return {?}
     */
    viewDateChange(viewYearDiff = 0, viewMonthDiff = 0) {
        let /** @type {?} */ viewYear = parseInt(this.viewYear) + viewYearDiff;
        let /** @type {?} */ viewMonth = parseInt(this.viewMonth) + viewMonthDiff;
        if (viewMonth === 0) {
            viewYear--;
            viewMonth = 12;
        }
        else if (viewMonth === 13) {
            viewYear++;
            viewMonth = 1;
        }
        let /** @type {?} */ viewDate = new Date(viewYear, viewMonth - 1, 1, 0, 0, 0, 0);
        if (!this.validateRange(viewDate, true).success) {
            return;
        }
        this.viewDate = viewDate;
        this.viewYear = viewYear.toString();
        this.viewMonth = viewMonth.toString();
        this.rangeDateChange();
        this.calculateView(this.viewDate);
    }
    /**
     * @param {?} date
     * @param {?=} onlyYearAndMonth
     * @param {?=} noAlert
     * @return {?}
     */
    validateRange(date, onlyYearAndMonth = false, noAlert = false) {
        let /** @type {?} */ _date = this.dateService.getDate(date);
        if (!_date) {
            this.tooltipRangeError("none");
            return {
                success: true
            };
        }
        let /** @type {?} */ minDate = this.getMinDate();
        let /** @type {?} */ maxDate = this.getMaxDate();
        if (_date.getTime() < minDate.getTime()) {
            minDate = new Date(minDate.getFullYear(), minDate.getMonth(), 1, 0, 0, 0, 0);
            if (!onlyYearAndMonth || _date.getTime() < minDate.getTime()) {
                if (!noAlert) {
                    this.tooltipRangeError("minDate");
                }
                return {
                    success: false,
                    minDateSuccess: false,
                    maxDateSuccess: true,
                    minDate: minDate,
                    maxDate: maxDate,
                };
            }
        }
        if (_date.getTime() > maxDate.getTime()) {
            maxDate = new Date(maxDate.getFullYear(), maxDate.getMonth(), this.dateService.getMaxDays(maxDate), 23, 23, 59, 999);
            if (!onlyYearAndMonth || _date.getTime() > maxDate.getTime()) {
                if (!noAlert) {
                    this.tooltipRangeError("maxDate");
                }
                return {
                    success: false,
                    minDateSuccess: true,
                    maxDateSuccess: false,
                    minDate: minDate,
                    maxDate: maxDate,
                };
            }
        }
        this.tooltipRangeError("none");
        return {
            success: true
        };
    }
    /**
     * @param {?} type
     * @return {?}
     */
    tooltipRangeError(type) {
        if (type === "minDate") {
            this.tooltipService.open({
                host: this.input,
                content: "最小可选日期为" + this.dateService.format(this.getMinDate(), this.dateService.YYYYMMDD),
                direction: this.jyTooltipDirection
            });
        }
        else if (type === "maxDate") {
            this.tooltipService.open({
                host: this.input,
                content: "最大可选日期为" + this.dateService.format(this.getMaxDate(), this.dateService.YYYYMMDD),
                direction: this.jyTooltipDirection
            });
        }
        else if (type === "none") {
            this.tooltipService.open({
                host: this.input,
                content: null
            });
        }
    }
    /**
     * @return {?}
     */
    getMinDate() {
        let /** @type {?} */ minDate = this.dateService.getDate(this._minDate);
        return minDate && minDate.getTime() > this.datetimePickerService.getMinDate().getTime() ? minDate : this.datetimePickerService.getMinDate();
    }
    /**
     * @return {?}
     */
    getMaxDate() {
        let /** @type {?} */ maxDate = this.dateService.getDate(this._maxDate);
        return maxDate && maxDate.getTime() < this.datetimePickerService.getMaxDate().getTime() ? maxDate : this.datetimePickerService.getMaxDate();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectDate(item) {
        if (item.disabled) {
            return;
        }
        if (!this.validateRange(item.date).success) {
            return;
        }
        this.mouseEnter = false;
        this._date = item.date;
        this._dateString = this.dateService.format(item.date, this.dateService.YYYYMMDD);
        this.viewHide(false);
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    today() {
        this.selectDate({
            disabled: false,
            date: this.dateService.reduce(new Date(), this.dateService.YYYYMMDD)
        });
    }
    /**
     * @return {?}
     */
    clear() {
        this.selectDate({
            disabled: false,
            date: null
        });
    }
    /**
     * @param {?} index
     * @return {?}
     */
    trackByIndex(index) {
        return index;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
YmdComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-ymd',
                template: `<div class='datetime-picker' #datetimePicker
     (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_date? _date.toString() : null" (jyCustomValidatorControl)="customValidatorControl = $event"
     [jyName]="jyName" [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection">
  <input #input type='text' class='form-control' [ngModel]="_dateString" [disabled]="disabled" [ngStyle]="{}"
         (focus)="focus()" (blur)="blur($event)" (keydown)="keydown($event)" (keyup)="keyup()">
  <div class="datetime-icon">
    <span class='icon-calendar input-icon' [jyHidden]="_date && (show || mouseEnter)"
          (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
    <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(_date && (show || mouseEnter))"
          (click)="clear()"></span>
  </div>
  <div class='fixed-box calendar-box' #box [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}">
    <div class="position-relative">
      <div class="select-box">
        <div class="select-left-button-box">
          <button class="btn btn-default" type="button" title="上一年" (click)="lastYear($event)" tabindex="-1">
            <span class="only-icon icon-double-angle-left"></span>
          </button>
          <button class="btn btn-default" type="button" title="上个月" (click)="lastMonth($event)"
                  tabindex="-1">
            <span class="only-icon icon-angle-left"></span>
          </button>
        </div>
        <div class="center">
          <select [jySelectData]="yearList" [(ngModel)]="viewYear" (change)="viewDateChange()" tabindex="-1"
                  (jyMousewhell)="yearMousewheel($event)">
          </select>
          <select [jySelectData]="monthList" [(ngModel)]="viewMonth" (change)="viewDateChange()" tabindex="-1"
                  (jyMousewhell)="monthMousewheel($event)">
          </select>
        </div>
        <div class="select-right-button-box">
          <button class="btn btn-default" type="button" title="下个" (click)="nextMonth($event)"
                  tabindex="-1">
            <span class="only-icon icon-angle-right"></span>
          </button>
          <button class="btn btn-default" type="button" title="下一年" (click)="nextYear($event)" tabindex="-1">
            <span class="only-icon icon-double-angle-right"></span>
          </button>
        </div>
      </div>
    </div>
    <table class="calendar-table" cellspacing="0" (jyMousewhell)="monthMousewheel($event)">
      <tbody>
      <tr>
        <th>一</th>
        <th>二</th>
        <th>三</th>
        <th>四</th>
        <th>五</th>
        <th>六</th>
        <th>日</th>
      </tr>
      <tr *ngFor="let week of weekList;trackBy:trackByIndex" class="repeat-animation">
        <td *ngFor="let item of week;trackBy:trackByIndex"
            [ngClass]="{'not-current':!item.current,'today':item.today,'select':item.select,'disabled':item.disabled}"
            title="{{item.disabled ? '不可选择':''}}"
            (click)="selectDate(item)">
          {{item.day}}
        </td>
      </tr>
      </tbody>
    </table>
    <div class="calendar-bottom-box">
      <button class="btn btn-default w50-100" type="button" (click)="today()" tabindex="-1">
        <span class="icon-calendar"></span>今天
      </button>
      <button class="btn btn-default w50-100" type="button" (click)="clear()" tabindex="-1">
        <span class="icon-cancel-circle-solid"></span>清除
      </button>
    </div>
  </div>
</div>
`,
                styles: [`.datetime-picker{display:inline-block;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;position:relative}.datetime-picker .btn{height:inherit;padding:.21428571rem .42857143rem;margin-bottom:0;font-size:.5rem}.datetime-picker .form-control{padding-right:.89285714rem!important}.datetime-picker .datetime-icon .icon-cancel-circle-solid{cursor:pointer;color:#679eda}.datetime-picker .datetime-icon .icon-cancel-circle-solid:hover{color:#2b6bb0}.datetime-picker .calendar-table{width:inherit}.datetime-picker .calendar-table th{text-align:center;padding:.14285714rem .35714286rem;color:#679eda;border:none;font-size:.5rem;line-height:.71428571rem}.datetime-picker .calendar-table tr{height:auto;line-height:inherit}.datetime-picker .calendar-table tr:hover{background-color:inherit}.datetime-picker .calendar-table tr:nth-of-type(odd){background-color:#fff}.datetime-picker .calendar-table td{text-align:center;cursor:pointer;border:none;word-break:normal;font-size:.5rem;border-radius:.17857143rem;padding:.17857143rem 0;line-height:.71428571rem}.datetime-picker .calendar-table td:hover{background-color:#b9d2ee;color:#679eda}.datetime-picker .calendar-table .select{background-color:#b9d2ee!important;color:#679eda}.datetime-picker .calendar-table .today{background-color:#ffffae}.datetime-picker .calendar-table .disabled{background-color:#d6d6d6!important;color:#a5a5a5!important;border-radius:0!important;cursor:no-drop}.datetime-picker .calendar-table .not-current{color:#c9c9c9}.datetime-picker .select-box{line-height:1.17857143rem;font-size:.57142857rem}.datetime-picker .select-box .select-left-button-box{display:inline-block;position:absolute;left:.14285714rem;top:-.07142857rem}.datetime-picker .select-box .select-left-button-box button:nth-child(2){margin-left:-.14285714rem}.datetime-picker .select-box .select-right-button-box{display:inline-block;position:absolute;right:.14285714rem;top:-.07142857rem}.datetime-picker .select-box .select-right-button-box button:nth-child(1){margin-left:-.14285714rem}.datetime-picker .select-box select{text-align:center}.datetime-picker .select-box button{width:.89285714rem;padding:.21428571rem 0;position:relative}.datetime-picker .select-box .only-icon{font-size:.71428571rem}.datetime-picker .time-box{text-align:center;margin:.21428571rem 0;font-size:.57142857rem}.datetime-picker .time-select-box [class^=icon-]:hover{font-weight:700;font-size:1rem}.datetime-picker .calendar-bottom-box{display:-webkit-box;display:-ms-flexbox;display:flex;margin-top:.07142857rem}.datetime-picker button{border:none;outline:0}.datetime-picker select{border:none;outline:0;background-color:#fff;-webkit-transition:border-color ease-in-out .15s,-webkit-box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,-webkit-box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s,-webkit-box-shadow ease-in-out .15s}.datetime-picker select:hover{-webkit-box-shadow:inset 0 .03571429rem .03571429rem rgba(0,0,0,.075),0 0 .28571429rem #679eda;box-shadow:inset 0 .03571429rem .03571429rem rgba(0,0,0,.075),0 0 .28571429rem #679eda}`, ``],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
YmdComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: DateService, },
    { type: ToolsService, },
    { type: TooltipService, },
    { type: DatetimePickerService, },
];
YmdComponent.propDecorators = {
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "minDate": [{ type: Input },],
    "minDateString": [{ type: Input },],
    "maxDate": [{ type: Input },],
    "maxDateString": [{ type: Input },],
    "date": [{ type: Input },],
    "dateString": [{ type: Input },],
    "dateChange": [{ type: Output },],
    "dateStringChange": [{ type: Output },],
    "_datetimePicker": [{ type: ViewChild, args: ["datetimePicker",] },],
    "_box": [{ type: ViewChild, args: ["box",] },],
    "_input": [{ type: ViewChild, args: ["input",] },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 滚轮事件  和原生的相比解决了浏览器兼容问题
 */
class MouseWhellDirective {
    /**
     * @param {?} elementRef
     * @param {?} browserService
     */
    constructor(elementRef, browserService) {
        this.elementRef = elementRef;
        this.browserService = browserService;
        this.jyMousewhell = new EventEmitter();
        this.eventName = browserService.isFirefox ? "DOMMouseScroll" : "mousewheel";
        this.mousewheelHandler = (event) => {
            this.jyMousewhell.emit(this.eventName === "mousewheel" ? -event.wheelDelta : event.detail);
        };
        this.elementRef.nativeElement.addEventListener(this.eventName, this.mousewheelHandler);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.elementRef.nativeElement.removeEventListener(this.eventName, this.mousewheelHandler);
    }
}
MouseWhellDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyMousewhell]"
            },] },
];
/** @nocollapse */
MouseWhellDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: BrowserService, },
];
MouseWhellDirective.propDecorators = {
    "jyMousewhell": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class ValidateDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyValidate(value) {
        this.host.attr(JY_VALIDATE, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: VALIDATE,
            handlerType: HandlerType.hide,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
ValidateDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyValidate]"
            },] },
];
/** @nocollapse */
ValidateDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
ValidateDirective.propDecorators = {
    "jyValidate": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class RequiredDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(this.elementRef.nativeElement);
        this.jyRequired = true;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyRequired(value) {
        if (value === false) {
            this.host.removeAttr(JY_REQUIRED);
        }
        else {
            this.host.attr(JY_REQUIRED, "true");
        }
        let /** @type {?} */ validatorChange = {
            validateType: REQUIRED,
            handlerType: HandlerType.hide,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
RequiredDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyRequired]"
            },] },
];
/** @nocollapse */
RequiredDirective.ctorParameters = () => [
    { type: ElementRef, },
];
RequiredDirective.propDecorators = {
    "jyRequired": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class ValidateTypeDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyValidateType(value) {
        this.host.attr(JY_VALIDATE_TYPE, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: VALIDATE_TYPE,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
ValidateTypeDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyValidateType]"
            },] },
];
/** @nocollapse */
ValidateTypeDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
ValidateTypeDirective.propDecorators = {
    "jyValidateType": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class EqualslengthDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyEqualslength(value) {
        this.host.attr(JY_EQUALSLENGTH, this.toolsService.getString(value));
        this.host.attr("maxlength", this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: LENGTH,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
EqualslengthDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyEqualslength]"
            },] },
];
/** @nocollapse */
EqualslengthDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
EqualslengthDirective.propDecorators = {
    "jyEqualslength": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class MaxlengthDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyMaxlength(value) {
        this.host.attr(JY_MAXLENGTH, this.toolsService.getString(value));
        this.host.attr("maxlength", this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: LENGTH,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
MaxlengthDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyMaxlength]"
            },] },
];
/** @nocollapse */
MaxlengthDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
MaxlengthDirective.propDecorators = {
    "jyMaxlength": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class MaxnumberDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyMaxnumber(value) {
        this.host.attr(JY_MAXNUMBER, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: NUMBER_SIZE,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
MaxnumberDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyMaxnumber]"
            },] },
];
/** @nocollapse */
MaxnumberDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
MaxnumberDirective.propDecorators = {
    "jyMaxnumber": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class MinlengthDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyMinlength(value) {
        this.host.attr(JY_MINLENGTH, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: LENGTH,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
MinlengthDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyMinlength]"
            },] },
];
/** @nocollapse */
MinlengthDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
MinlengthDirective.propDecorators = {
    "jyMinlength": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class MinnumberDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyMinnumber(value) {
        this.host.attr(JY_MINNUMBER, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: NUMBER_SIZE,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
MinnumberDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyMinnumber]"
            },] },
];
/** @nocollapse */
MinnumberDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
MinnumberDirective.propDecorators = {
    "jyMinnumber": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class PatternDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyPattern(value) {
        this.host.attr(JY_PATTERN, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: PATTERN,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
PatternDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyPattern]"
            },] },
];
/** @nocollapse */
PatternDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
PatternDirective.propDecorators = {
    "jyPattern": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class PatternMessageDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyPatternMessage(value) {
        this.host.attr(JY_PATTERN_MESSAGE, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: PATTERN,
            handlerType: HandlerType.reValidate,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
PatternMessageDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyPatternMessage]"
            },] },
];
/** @nocollapse */
PatternMessageDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
PatternMessageDirective.propDecorators = {
    "jyPatternMessage": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class RequiredMessageDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyRequiredMessage(value) {
        this.host.attr(JY_REQUIRED_MESSAGE, this.toolsService.getString(value));
        let /** @type {?} */ validatorChange = {
            validateType: REQUIRED,
            handlerType: HandlerType.hide,
        };
        this.host.trigger(VALIDATOR_CHANGE_EVENT_NAME, validatorChange);
    }
}
RequiredMessageDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyRequiredMessage]"
            },] },
];
/** @nocollapse */
RequiredMessageDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
RequiredMessageDirective.propDecorators = {
    "jyRequiredMessage": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * name
 */
class NameDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyName(value) {
        this.host.attr("name", this.toolsService.getString(value));
    }
}
NameDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyName]"
            },] },
];
/** @nocollapse */
NameDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
NameDirective.propDecorators = {
    "jyName": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const SORT_EVENT = "SORT_EVENT";
/**
 * @record
 */

/**
 * 表格数据
 * @record
 * @template T
 */

/**
 * @template T
 */
class DefaultPageData {
    constructor() {
        this.content = [];
    }
}
/**
 * 查询条件
 * @record
 */

class DefaultQueryParams {
}
/**
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 分页
 */
class PageableComponent {
    constructor() {
        this.loading = false;
        this.showBtnLength = 2;
        this.rowsSelectList = [10, 20, 50, 100];
        this.queryParams = new DefaultQueryParams();
        this.pageData = {
            totalPages: 0,
            totalElements: 0,
            content: []
        };
        this.showPageBtn = [1];
        this.truePage = 1;
        this.tempPage = 1;
        this.rowsSelect = "100";
        this.query = null;
    }
    /**
     * @param {?} page
     * @return {?}
     */
    jump(page) {
        if (this.loading) {
            return;
        }
        if (page < 1) {
            page = 1;
        }
        this.queryParams.page = page;
        this.queryParams.rows = parseInt(this.rowsSelect);
        this.query();
    }
    ;
    /**
     * @param {?} event
     * @param {?} page
     * @return {?}
     */
    jumpPage(event, page) {
        if (event && $(event.currentTarget).hasClass("disabled")) {
            return;
        }
        if (page < 1) {
            page = 1;
        }
        else if (page > this.pageData.totalPages) {
            page = this.pageData.totalPages;
        }
        this.jump(page);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    tempPageKeyDown(event) {
        if (event.keyCode === 13) {
            this.jumpTempPage();
        }
    }
    /**
     * @return {?}
     */
    jumpTempPage() {
        if (!isNumber(this.tempPage)) {
            this.tempPage = 1;
        }
        this.jumpPage(null, this.tempPage);
    }
    /**
     * @return {?}
     */
    onRowsSelectChange() {
        this.jump(this.queryParams.page);
        // userConfig.save(userConfig.constants.TABLE_ROWS, $scope.rowsSelect);
    }
    /**
     * @return {?}
     */
    initPageBtn() {
        this.rowsSelect = this.queryParams.rows + "";
        this.truePage = this.queryParams.page;
        this.tempPage = this.queryParams.page;
        if (this.queryParams.page !== 1 && this.queryParams.page > this.pageData.totalPages) {
            this.queryParams.page = this.pageData.totalPages;
            this.jump(this.queryParams.page);
            return;
        }
        let /** @type {?} */ before = this.queryParams.page;
        let /** @type {?} */ showPageBtn = [];
        let /** @type {?} */ beforeBtnLength = before - this.showBtnLength;
        for (let /** @type {?} */ i = beforeBtnLength; i < this.queryParams.page; i++) {
            if (i > 0) {
                showPageBtn.push(i);
            }
        }
        let /** @type {?} */ surplus = this.showBtnLength - showPageBtn.length + 1;
        for (let /** @type {?} */ i = this.queryParams.page; i < this.queryParams.page + this.showBtnLength + surplus && i <= this.pageData.totalPages; i++) {
            if (showPageBtn.length < this.showBtnLength * 2 + 1 && i > 0) {
                showPageBtn.push(i);
            }
        }
        if (showPageBtn.length > 0) {
            while (showPageBtn.length < this.showBtnLength * 2 + 1) {
                let /** @type {?} */ p = showPageBtn[0];
                if (p <= 1) {
                    break;
                }
                else {
                    showPageBtn.push(p - 1);
                    showPageBtn.sort(function (a, b) {
                        return a > b ? 1 : -1;
                    });
                }
            }
            this.showPageBtn = showPageBtn;
        }
        else {
            this.showPageBtn = [1];
        }
    }
}
PageableComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-pageable',
                template: `<div class="table-page">
  <div class="left bottom-box-parent">
  </div>
  <div class="right">
    <ul class="pagination left">
      <li class="page-first" [ngClass]="{disabled:queryParams.page === 1 || loading}"
          (click)="jumpPage($event,1)">
        <a>
          <i class="icon-double-angle-left"></i>
        </a>
      </li>
      <li class="page-pre" [ngClass]="{disabled:queryParams.page === 1 || loading}"
          (click)="jumpPage($event,queryParams.page - 1)">
        <a>
          <i class="icon-angle-left"></i>
        </a>
      </li>
      <li class="page-number" *ngFor="let pageBtn of showPageBtn"
          [ngClass]="{'active':truePage === pageBtn,disabled:loading}"
          (click)="jumpPage($event,pageBtn)">
        <a>
          {{pageBtn}}
        </a>
      </li>
      <li class="page-next"
          [ngClass]="{disabled:pageData.totalPages === 0 || queryParams.page === pageData.totalPages || loading}"
          (click)="jumpPage($event,queryParams.page + 1)">
        <a>
          <i class="icon-angle-right"></i>
        </a>
      </li>
      <li class="page-last"
          [ngClass]="{disabled:pageData.totalPages === 0 || queryParams.page === pageData.totalPages || loading}"
          (click)="jumpPage($event,pageData.totalPages)">
        <a>
          <i class="icon-double-angle-right"></i>
        </a>
      </li>
    </ul>
    <input type="number" class="form-control left page-input"
           [disabled]="loading" [(ngModel)]="tempPage" (keydown)="tempPageKeyDown($event)">
    <span class="left span-text">&nbsp;/{{pageData.totalPages}}页&nbsp;</span>
    <button class="btn btn-default left" (click)="jumpTempPage()" type="button"
            [disabled]="loading">跳转
    </button>
    <span class="left span-text">
          &nbsp;共&nbsp;{{pageData['totalElements']}}&nbsp;条,每页&nbsp;
  </span>
    <select class="form-control left select-rows" [(ngModel)]="rowsSelect"
            [disabled]="loading" (change)="onRowsSelectChange()">
      <option *ngFor="let rows of rowsSelectList" value="{{rows}}">{{rows}}条</option>
    </select>
  </div>
</div>
`,
                styles: [`.table-page{width:calc(100% - .35714286rem);float:right;margin:.17857143rem}.table-page .btn,.table-page .form-control{height:1.21428571rem;padding:.21428571rem .42857143rem}.table-page .select-rows{padding:.14285714rem .03571429rem .14285714rem .07142857rem;width:2.85714286rem}.table-page .page-input{width:2.85714286rem;text-align:center;margin-left:.35714286rem}.table-page .span-text{margin-top:.28571429rem}.table-page .pagination i{font-size:.39285714rem}.table-page .pagination li a,.table-page .pagination li span{padding:.25rem .42857143rem}`]
            },] },
];
/** @nocollapse */
PageableComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * table box
 */
class TableBoxService {
    /**
     * @param {?} tableBoxProvider
     * @return {?}
     */
    setProvider(tableBoxProvider) {
        if (!tableBoxProvider) {
            return;
        }
        this.tableBoxProvider = tableBoxProvider;
    }
    /**
     * @return {?}
     */
    getTableRows() {
        return this.tableBoxProvider ? this.tableBoxProvider.getTableRows() : null;
    }
    /**
     * @param {?} rows
     * @return {?}
     */
    setTableRows(rows) {
        if (this.tableBoxProvider) {
            this.tableBoxProvider.setTableRows(rows);
        }
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getTableWidth(key) {
        if (!this.tableWidthMap) {
            this.tableWidthMap = this.tableBoxProvider ? this.tableBoxProvider.getTableWidthMap() : {};
        }
        if (key === null || isUndefined(key)) {
            return null;
        }
        if (!this.tableWidthMap[key]) {
            console.error("table width key not find(" + key + ")");
            return 0;
        }
        return this.tableWidthMap[key];
    }
}
TableBoxService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TableBoxService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * table-box
 */
class TableBoxDirective {
    /**
     * @param {?} elementRef
     * @param {?} viewContainerRef
     * @param {?} toolsService
     * @param {?} browserService
     * @param {?} dynamicComponentService
     * @param {?} globalEventsService
     * @param {?} tableBoxService
     * @param {?} remService
     * @param {?} validatorService
     */
    constructor(elementRef, viewContainerRef, toolsService, browserService, dynamicComponentService, globalEventsService, tableBoxService, remService, validatorService) {
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
        this.toolsService = toolsService;
        this.browserService = browserService;
        this.dynamicComponentService = dynamicComponentService;
        this.globalEventsService = globalEventsService;
        this.tableBoxService = tableBoxService;
        this.remService = remService;
        this.validatorService = validatorService;
        this.pageableHeight = 35;
        this.defaultColumnWidth = 100;
        this.minTableHeight = 200;
        this.headRows = 1;
        this.footRows = 1;
        this.hidePage = false;
        this.closeSelected = false;
        this.defaultRows = null;
        this.dontAutoQuery = false;
        this.onQuery = new EventEmitter();
        this.onLoading = new EventEmitter();
        this.onInit = new EventEmitter();
        this._loading = false;
        this.leftTableWidth = 0;
        this.rightTableWidth = 0;
        this.headTr = $("<tr class='head-tr'></tr>");
        this.bodyTr = $("<tr class='body-tr'></tr>");
        this.footTr = null;
        this.initOpenSearchBox = true;
        this.host = $(elementRef.nativeElement);
        this.host.hide();
        this.windowResizeResetType = this.globalEventsService.addWindowResize(this.onWindowResize.bind(this));
    }
    /**
     * @param {?} pageData
     * @return {?}
     */
    set pageData(pageData) {
        this._pageData = pageData;
        this.loading = false;
        if (this.messageBox) {
            if (!pageData || !pageData.content || pageData.content.length > 0) {
                this.messageBox.stop().animate({
                    opacity: 0,
                }, 200, () => {
                    this.messageBox.hide();
                });
            }
            else {
                this.messageBox.stop().show().css("opacity", 0).animate({
                    opacity: 1,
                }, 200);
            }
        }
        if (this.pageableComponent) {
            this.initPageable();
        }
    }
    /**
     * @param {?} queryParams
     * @return {?}
     */
    set queryParams(queryParams) {
        this.firstQueryParams = JSON.parse(JSON.stringify(queryParams));
        this.defaultRows = queryParams.rows;
        this._queryParams = queryParams;
        if (this.pageableComponent) {
            this.initPageable();
        }
        this.dispatchSortEvent();
    }
    /**
     * @return {?}
     */
    disabledInput() {
        if (this.searchBox) {
            this.searchBoxDisabled = this.searchBox.find("searchInput,textarea,button,select").not(':disabled');
            this.searchBoxDisabled.attr("disabled", "disabled");
        }
        if (this.bottomBox) {
            this.bottomBoxDisabled = this.bottomBox.find("searchInput,textarea,button,select").not(':disabled');
            this.bottomBoxDisabled.attr("disabled", "disabled");
        }
    }
    /**
     * @return {?}
     */
    resetDisabledInput() {
        if (this.searchBoxDisabled) {
            this.searchBoxDisabled.removeAttr("disabled");
            this.searchBoxDisabled = null;
        }
        if (this.bottomBoxDisabled) {
            this.bottomBoxDisabled.removeAttr("disabled");
            this.bottomBoxDisabled = null;
        }
    }
    /**
     * @param {?} loading
     * @return {?}
     */
    set loading(loading) {
        this._loading = loading;
        if (this.pageableComponent) {
            this.pageableComponent.loading = loading;
        }
        if (this._loading) {
            this.disabledInput();
        }
        else {
            this.resetDisabledInput();
        }
        if (this.messageBox && this.loadingBox) {
            if (loading) {
                this.messageBox.hide();
                this.loadingBox.stop().show().css("opacity", 0).animate({
                    opacity: 1,
                }, 200);
            }
            else {
                this.loadingBox.stop().animate({
                    opacity: 0,
                }, 200, () => {
                    this.loadingBox.hide();
                });
            }
        }
        setTimeout(() => {
            this.onLoading.emit(this._loading);
        });
        this.dispatchSortEvent();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.host.show();
            this.initTableBox();
            this.initPageable();
            this.initSearchBox();
            this.initBottomBox();
            this.windowResize(0, false, this.initOpenSearchBox);
            if (!this.dontAutoQuery) {
                this.query();
            }
            setTimeout(() => {
                this.windowResize(0, false, this.initOpenSearchBox);
                this.onInit.emit({
                    query: () => {
                        this.query();
                    }
                });
            });
            this.dispatchSortEvent();
            if (this._queryParams) {
                this.firstQueryParams = JSON.parse(JSON.stringify(this._queryParams));
            }
        }, this.toolsService.jqNotNull(this.host.closest(".modal-body")) ? 250 : 0);
    }
    /**
     * @return {?}
     */
    initTableBox() {
        this.host.addClass("table-box direction-relative");
        this.leftHeadTable = this.toolsService.jqNotNull(this.host.find(".left-head-table"));
        this.centerHeadTable = this.toolsService.jqNotNull(this.host.find(".center-head-table"));
        this.rightHeadTable = this.toolsService.jqNotNull(this.host.find(".right-head-table"));
        this.leftBodyTable = this.toolsService.jqNotNull(this.host.find(".left-body-table"));
        this.centerBodyTable = this.toolsService.jqNotNull(this.host.find(".center-body-table"));
        this.rightBodyTable = this.toolsService.jqNotNull(this.host.find(".right-body-table"));
        this.leftFootTable = this.toolsService.jqNotNull(this.host.find(".left-foot-table"));
        this.centerFootTable = this.toolsService.jqNotNull(this.host.find(".center-foot-table"));
        this.rightFootTable = this.toolsService.jqNotNull(this.host.find(".right-foot-table"));
        let /** @type {?} */ leftHeadBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ centerHeadBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ rightHeadBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ leftBodyBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ centerBodyBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ rightBodyBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ leftFootBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ centerFootBlankLine = $(`<tr class="blank-line"></tr>`);
        let /** @type {?} */ rightFootBlankLine = $(`<tr class="blank-line"></tr>`);
        this.containerTable = $("<table class='container-table'></table>");
        this.host.append(this.containerTable);
        if (this.leftHeadTable) {
            this.leftHeadTd = $("<td class='left-head-td'></td>");
            this.leftHeadDiv = $("<div class='left-head-div'></div>");
            this.leftHeadTable.prepend(leftHeadBlankLine);
            this.leftHeadDiv.append(this.leftHeadTable);
            this.leftHeadTd.append(this.leftHeadDiv);
            this.headTr.append(this.leftHeadTd);
        }
        if (this.centerHeadTable) {
            this.centerHeadTd = $("<td class='center-head-td'></td>");
            this.centerHeadDiv = $("<div class='center-head-div'></div>");
            this.centerHeadTable.prepend(centerHeadBlankLine);
            this.centerHeadDiv.append(this.centerHeadTable);
            this.centerHeadTd.append(this.centerHeadDiv);
            this.headTr.append(this.centerHeadTd);
        }
        if (this.rightHeadTable) {
            this.rightHeadTd = $("<td class='right-head-td'></td>");
            this.rightHeadDiv = $("<div class='right-head-div'></div>");
            this.rightHeadTable.prepend(rightHeadBlankLine);
            this.rightHeadDiv.append(this.rightHeadTable);
            this.rightHeadTd.append(this.rightHeadDiv);
            this.headTr.append(this.rightHeadTd);
        }
        if (this.leftBodyTable) {
            this.leftBodyTd = $("<td class='left-body-td'></td>");
            this.leftBodyDiv = $("<div class='left-body-div'></div>");
            this.leftBodyTable.prepend(leftBodyBlankLine);
            this.leftBodyDiv.append(this.leftBodyTable);
            this.leftBodyTd.append(this.leftBodyDiv);
            this.leftBodyScrollPlace = $("<div class='scroll-place-left'></div>");
            this.leftBodyTd.append(this.leftBodyScrollPlace);
            this.bodyTr.append(this.leftBodyTd);
        }
        if (this.centerBodyTable) {
            this.centerBodyTd = $("<td class='center-body-td'></td>");
            this.centerBodyDiv = $("<div class='center-body-div'></div>");
            this.centerBodyTable.prepend(centerBodyBlankLine);
            this.centerBodyDiv.append(this.centerBodyTable);
            this.centerBodyTd.append(this.centerBodyDiv);
            this.bodyTr.append(this.centerBodyTd);
        }
        if (this.rightBodyTable) {
            this.rightBodyTd = $("<td class='right-body-td'></td>");
            this.rightBodyDiv = $("<div class='right-body-div'></div>");
            this.rightBodyTable.prepend(rightBodyBlankLine);
            this.rightBodyDiv.append(this.rightBodyTable);
            this.rightBodyTd.append(this.rightBodyDiv);
            this.rightBodyScrollPlace = $("<div class='scroll-place-right'></div>");
            this.rightBodyTd.append(this.rightBodyScrollPlace);
            this.bodyTr.append(this.rightBodyTd);
        }
        if (this.leftFootTable || this.centerFootTable || this.rightFootTable) {
            this.footTr = $("<tr class='foot-tr'></tr>");
            if (this.leftFootTable) {
                this.leftFootTd = $("<td class='left-foot-td'></td>");
                this.leftFootDiv = $("<div class='left-foot-div'></div>");
                this.leftFootTable.prepend(leftFootBlankLine);
                this.leftFootDiv.append(this.leftFootTable);
                this.leftFootTd.append(this.leftFootDiv);
                this.footTr.append(this.leftFootTd);
            }
            if (this.centerFootTable) {
                this.centerFootTd = $("<td class='center-foot-td'></td>");
                this.centerFootDiv = $("<div class='center-foot-div'></div>");
                this.centerFootTable.prepend(centerFootBlankLine);
                this.centerFootDiv.append(this.centerFootTable);
                this.centerFootTd.append(this.centerFootDiv);
                this.footTr.append(this.centerFootTd);
            }
            if (this.rightFootTable) {
                this.rightFootTd = $("<td class='right-foot-td'></td>");
                this.rightFootDiv = $("<div class='right-foot-div'></div>");
                this.rightFootTable.prepend(rightFootBlankLine);
                this.rightFootDiv.append(this.rightFootTable);
                this.rightFootTd.append(this.rightFootDiv);
                this.footTr.append(this.rightFootTd);
            }
        }
        this.containerTable.append(this.headTr).append(this.bodyTr);
        this.headTr.height(this.remService.realPx(40) * this.headRows);
        if (this.footTr) {
            this.footTr.height(this.remService.realPx(32) * this.footRows);
            this.containerTable.append(this.footTr);
        }
        let /** @type {?} */ scrollDiv;
        if (this.rightHeadTable) {
            scrollDiv = this.rightBodyDiv;
            this.rightBodyDiv.css("overflow-y", "auto");
            this.centerBodyDiv.css("overflow-y", "hidden");
        }
        else {
            scrollDiv = this.centerBodyDiv;
            this.centerBodyDiv.css("overflow-y", "auto");
        }
        this.messageBox = $("<div class='table-message'>未查找到数据</div>");
        this.loadingBox = $("<div class='table-loading'><span class='animation-icon-spin icon-spinner'></span></div>");
        this.host.append(this.messageBox);
        this.host.append(this.loadingBox);
        this.titleBox = this.toolsService.jqNotNull(this.host.find(".title-box"));
        if (this.titleBox) {
            this.host.prepend(this.titleBox);
        }
        else {
            this.containerTable.css("border-top", "none");
        }
        if (this.hidePage && !this.bottomBox) {
            this.containerTable.css("border-bottom", "none");
        }
        this.toolsService.scrollDispatchClickEvent(this.centerBodyDiv);
        this.centerBodyDiv.scroll(() => {
            if (this.centerBodyDiv[0].scrollLeft + this.centerBodyDiv[0].offsetWidth > this.centerBodyDiv[0].scrollWidth) {
                this.centerBodyDiv[0].scrollLeft = this.centerBodyDiv[0].scrollWidth - this.centerBodyDiv[0].offsetWidth;
            }
            this.centerHeadDiv[0].scrollLeft = this.centerBodyDiv[0].scrollLeft;
            if (this.centerFootDiv) {
                this.centerFootDiv[0].scrollLeft = this.centerBodyDiv[0].scrollLeft;
            }
        });
        scrollDiv.scroll(() => {
            if (scrollDiv === this.rightBodyDiv) {
                this.centerBodyDiv[0].scrollTop = scrollDiv[0].scrollTop;
            }
            if (this.leftBodyDiv) {
                this.leftBodyDiv[0].scrollTop = scrollDiv[0].scrollTop;
            }
        });
        let /** @type {?} */ rightWidthCalculation = (position) => {
            let /** @type {?} */ _headTd;
            let /** @type {?} */ _headTable;
            let /** @type {?} */ _bodyTable;
            let /** @type {?} */ _footTable;
            let /** @type {?} */ _headBlankLine;
            let /** @type {?} */ _bodyBlankLine;
            let /** @type {?} */ _footBlankLine;
            if (position === "left") {
                _headTd = this.leftHeadTd;
                _headTable = this.leftHeadTable;
                _bodyTable = this.leftBodyTable;
                _footTable = this.leftFootTable;
                _headBlankLine = leftHeadBlankLine;
                _bodyBlankLine = leftBodyBlankLine;
                _footBlankLine = leftFootBlankLine;
            }
            else if (position === "center") {
                _headTd = this.centerHeadTd;
                _headTable = this.centerHeadTable;
                _bodyTable = this.centerBodyTable;
                _footTable = this.centerFootTable;
                _headBlankLine = centerHeadBlankLine;
                _bodyBlankLine = centerBodyBlankLine;
                _footBlankLine = centerFootBlankLine;
            }
            else if (position === "right") {
                _headTd = this.rightHeadTd;
                _headTable = this.rightHeadTable;
                _bodyTable = this.rightBodyTable;
                _footTable = this.rightFootTable;
                _headBlankLine = rightHeadBlankLine;
                _bodyBlankLine = rightBodyBlankLine;
                _footBlankLine = rightFootBlankLine;
            }
            let /** @type {?} */ headTds = this.toolsService.jqNotNull(_headTable.find(".head-tr:eq(0)"));
            if (!headTds) {
                headTds = _headTable.find("tr:eq(1)");
            }
            let /** @type {?} */ tableWidth = 0;
            let /** @type {?} */ blankLineHtml = "";
            for (let /** @type {?} */ i = 0; i < headTds[0].children.length; i++) {
                let /** @type {?} */ td = $(headTds[0].children[i]);
                if (td.css("display") !== "none" || td.hasClass("width-hide")) {
                    let /** @type {?} */ widthString = td.attr("width");
                    let /** @type {?} */ width = null;
                    if (this.validatorService.isInteger(widthString)) {
                        width = this.toolsService.parseInt(widthString);
                    }
                    else {
                        width = this.tableBoxService.getTableWidth(widthString);
                    }
                    if (!width) {
                        width = this.defaultColumnWidth;
                    }
                    blankLineHtml += `<td width="` + width / rem + `rem"></td>`;
                    tableWidth += width;
                }
            }
            if (_headBlankLine.html() !== blankLineHtml) {
                _headBlankLine.html(blankLineHtml);
            }
            if (_bodyBlankLine.html() !== blankLineHtml) {
                _bodyBlankLine.html(blankLineHtml);
            }
            if (_footBlankLine.html() !== blankLineHtml) {
                _footBlankLine.html(blankLineHtml);
            }
            tableWidth += 2;
            if (position === "left") {
                this.leftTableWidth = this.remService.realPx(tableWidth);
            }
            else if (position === "right") {
                this.rightTableWidth = this.remService.realPx(tableWidth);
            }
            let /** @type {?} */ tableWidthRem = tableWidth / rem;
            _headTable.width(tableWidthRem + "rem");
            _bodyTable.width(tableWidthRem + "rem");
            if (_footTable) {
                _footTable.width(tableWidthRem + "rem");
            }
            if (position === "left" || position === "right") {
                _headTd.width(tableWidthRem + "rem");
            }
            this.windowResize();
        };
        rightWidthCalculation("center");
        this.toolsService.addDomShowChangeListener(this.centerHeadTable[0], ["tr", "td", "th"], () => {
            rightWidthCalculation("center");
        });
        if (this.leftHeadTable) {
            rightWidthCalculation("left");
            this.toolsService.addDomShowChangeListener(this.leftHeadTable[0], ["tr", "td", "th"], () => {
                rightWidthCalculation("left");
            });
        }
        if (this.rightHeadTable) {
            rightWidthCalculation("right");
            this.toolsService.addDomShowChangeListener(this.rightHeadTable[0], ["tr", "td", "th"], () => {
                rightWidthCalculation("right");
            });
        }
        (() => {
            let /** @type {?} */ lastTarget = null;
            let /** @type {?} */ lastLeftTr = null;
            let /** @type {?} */ lastCenterTr = null;
            let /** @type {?} */ lastRightTr = null;
            let /** @type {?} */ hover = (event) => {
                if (lastTarget && lastTarget[0] === event.target) {
                    return;
                }
                if (lastLeftTr) {
                    lastLeftTr.removeClass("tr-hover");
                    lastLeftTr = null;
                }
                if (lastCenterTr) {
                    lastCenterTr.removeClass("tr-hover");
                    lastCenterTr = null;
                }
                if (lastRightTr) {
                    lastRightTr.removeClass("tr-hover");
                    lastRightTr = null;
                }
                lastTarget = $(event.target);
                let /** @type {?} */ table = lastTarget.closest("table");
                if (!(table.is(this.leftBodyTable) || table.is(this.centerBodyTable) || table.is(this.rightBodyTable)
                    || table.is(this.leftFootTable) || table.is(this.centerFootTable) || table.is(this.rightFootTable))) {
                    return;
                }
                let /** @type {?} */ tr = this.toolsService.jqNotNull(lastTarget.closest("tr"));
                let /** @type {?} */ td = this.toolsService.jqNotNull(lastTarget.closest("td"));
                if (lastTarget.is("td") || lastTarget.is("th")) {
                    td = lastTarget;
                }
                if (!tr || !table.is(tr.closest("table"))) {
                    return;
                }
                if (td.html().toLocaleLowerCase().indexOf("</button>") < 0) {
                    td.attr("title", td.text());
                }
                let /** @type {?} */ trList = table[0].children[0].children;
                let /** @type {?} */ index;
                for (let /** @type {?} */ i = 0; i < trList.length; i++) {
                    if (trList[i] === tr[0]) {
                        index = i;
                        break;
                    }
                }
                let /** @type {?} */ leftTable;
                let /** @type {?} */ centerTable;
                let /** @type {?} */ rightTable;
                if (table.is(this.leftBodyTable) || table.is(this.centerBodyTable) || table.is(this.rightBodyTable)) {
                    leftTable = this.leftBodyTable;
                    centerTable = this.centerBodyTable;
                    rightTable = this.rightBodyTable;
                }
                else if (table.is(this.leftFootTable) || table.is(this.centerFootTable) || table.is(this.rightFootTable)) {
                    leftTable = this.leftFootTable;
                    centerTable = this.centerFootTable;
                    rightTable = this.rightFootTable;
                }
                lastCenterTr = $(centerTable[0].children[0].children[index]);
                lastCenterTr.addClass("tr-hover");
                if (leftTable) {
                    lastLeftTr = $(leftTable[0].children[0].children[index]);
                    lastLeftTr.addClass("tr-hover");
                }
                if (rightTable) {
                    lastRightTr = $(rightTable[0].children[0].children[index]);
                    lastRightTr.addClass("tr-hover");
                }
            };
            let /** @type {?} */ hoverOut = () => {
                lastTarget = null;
                if (lastLeftTr) {
                    lastLeftTr.removeClass("tr-hover");
                    lastLeftTr = null;
                }
                if (lastCenterTr) {
                    lastCenterTr.removeClass("tr-hover");
                    lastCenterTr = null;
                }
                if (lastRightTr) {
                    lastRightTr.removeClass("tr-hover");
                    lastRightTr = null;
                }
            };
            this.centerBodyTable.mousemove(hover);
            this.centerBodyTable.mouseleave(hoverOut);
            if (this.leftBodyTable) {
                this.leftBodyTable.mousemove(hover);
                this.leftBodyTable.mouseleave(hoverOut);
            }
            if (this.rightBodyTable) {
                this.rightBodyTable.mousemove(hover);
                this.rightBodyTable.mouseleave(hoverOut);
            }
            if (this.centerFootTable) {
                this.centerFootTable.mousemove(hover);
                this.centerFootTable.mouseleave(hoverOut);
            }
            if (this.leftFootTable) {
                this.leftFootTable.mousemove(hover);
                this.leftFootTable.mouseleave(hoverOut);
            }
            if (this.rightFootTable) {
                this.rightFootTable.mousemove(hover);
                this.rightFootTable.mouseleave(hoverOut);
            }
            if (this.leftBodyDiv) {
                let /** @type {?} */ eventName = this.browserService.isFirefox ? "DOMMouseScroll" : "mousewheel";
                this.leftBodyDiv[0].addEventListener(eventName, (event) => {
                    let /** @type {?} */ detail = eventName === "mousewheel" ? -event.wheelDelta : event.detail;
                    scrollDiv.scrollTop(scrollDiv.scrollTop() + detail);
                });
            }
            if (this.rightBodyDiv) {
                let /** @type {?} */ eventName = this.browserService.isFirefox ? "DOMMouseScroll" : "mousewheel";
                this.centerBodyDiv[0].addEventListener(eventName, (event) => {
                    let /** @type {?} */ detail = eventName === "mousewheel" ? -event.wheelDelta : event.detail;
                    scrollDiv.scrollTop(scrollDiv.scrollTop() + detail);
                });
            }
        })();
        if (!this.closeSelected) {
            (() => {
                let /** @type {?} */ lastLeftTr = null;
                let /** @type {?} */ lastCenterTr = null;
                let /** @type {?} */ lastRightTr = null;
                let /** @type {?} */ clickSelect = (event) => {
                    let /** @type {?} */ $target = $(event.target);
                    if (!$target.is("td") && !$target.is("th")) {
                        return;
                    }
                    let /** @type {?} */ table = $target.closest("table");
                    if (!table.is(this.leftBodyTable) && !table.is(this.centerBodyTable) && !table.is(this.rightBodyTable) &&
                        !table.is(this.leftFootTable) && !table.is(this.centerFootTable) && !table.is(this.rightFootTable)) {
                        return;
                    }
                    let /** @type {?} */ tr = $target.closest("tr");
                    if (!tr || !table.is(tr.closest("table"))) {
                        return;
                    }
                    let /** @type {?} */ trList = table[0].children[0].children;
                    let /** @type {?} */ index;
                    for (let /** @type {?} */ i = 0; i < trList.length; i++) {
                        if (trList[i] === tr[0]) {
                            index = i;
                            break;
                        }
                    }
                    let /** @type {?} */ re = lastCenterTr && $(this.centerBodyTable[0].children[0].children[index]).is(lastCenterTr) && lastCenterTr.hasClass("tr-selected");
                    if (lastLeftTr) {
                        lastLeftTr.removeClass("tr-selected");
                        lastLeftTr = null;
                    }
                    if (lastCenterTr) {
                        lastCenterTr.removeClass("tr-selected");
                        lastCenterTr = null;
                    }
                    if (lastRightTr) {
                        lastRightTr.removeClass("tr-selected");
                        lastRightTr = null;
                    }
                    if (re) {
                        return;
                    }
                    let /** @type {?} */ leftTable;
                    let /** @type {?} */ centerTable;
                    let /** @type {?} */ rightTable;
                    if (table.is(this.leftBodyTable) || table.is(this.centerBodyTable) || table.is(this.rightBodyTable)) {
                        leftTable = this.leftBodyTable;
                        centerTable = this.centerBodyTable;
                        rightTable = this.rightBodyTable;
                    }
                    else if (table.is(this.leftFootTable) || table.is(this.centerFootTable) || table.is(this.rightFootTable)) {
                        leftTable = this.leftFootTable;
                        centerTable = this.centerFootTable;
                        rightTable = this.rightFootTable;
                    }
                    if (leftTable) {
                        lastLeftTr = $(leftTable[0].children[0].children[index]);
                        lastLeftTr.addClass("tr-selected");
                    }
                    if (centerTable) {
                        lastCenterTr = $(centerTable[0].children[0].children[index]);
                        lastCenterTr.addClass("tr-selected");
                    }
                    if (rightTable) {
                        lastRightTr = $(rightTable[0].children[0].children[index]);
                        lastRightTr.addClass("tr-selected");
                    }
                };
                this.centerBodyTable.click(clickSelect);
                if (this.leftBodyTable) {
                    this.leftBodyTable.click(clickSelect);
                }
                if (this.rightBodyTable) {
                    this.rightBodyTable.click(clickSelect);
                }
                if (this.centerFootTable) {
                    this.centerFootTable.click(clickSelect);
                }
                if (this.leftFootTable) {
                    this.leftFootTable.click(clickSelect);
                }
                if (this.rightFootTable) {
                    this.rightFootTable.click(clickSelect);
                }
            })();
        }
        (() => {
            let /** @type {?} */ dblclickAdaptable = (event) => {
                let /** @type {?} */ $target = $(event.target);
                let /** @type {?} */ table = $target.closest("table");
                if (!(table.is(this.leftHeadTable) || table.is(this.centerHeadTable) || table.is(this.rightHeadTable))) {
                    return;
                }
                let /** @type {?} */ td = $target.closest("td");
                if (!td || !table.is(td.closest("table")) || td.attr("colspan") || td.attr("rowspan")) {
                    td = $target.closest("th");
                    if (!td || !table.is(td.closest("table")) || td.attr("colspan") || td.attr("rowspan")) {
                        return;
                    }
                }
                if (td.attr("old-width")) {
                    td.attr("width", td.attr("old-width"));
                    td.removeAttr("old-width");
                    return;
                }
                let /** @type {?} */ tdList = td.parent()[0].children;
                let /** @type {?} */ index;
                for (let /** @type {?} */ i = 0; i < tdList.length; i++) {
                    if (tdList[i] === td[0]) {
                        index = i;
                        break;
                    }
                }
                let /** @type {?} */ bodyTable;
                let /** @type {?} */ footTable;
                if (table.is(this.leftHeadTable)) {
                    bodyTable = this.leftBodyTable;
                    footTable = this.leftFootTable;
                }
                else if (table.is(this.centerHeadTable)) {
                    bodyTable = this.centerBodyTable;
                    footTable = this.centerFootTable;
                }
                else if (table.is(this.rightFootTable)) {
                    bodyTable = this.rightBodyTable;
                    footTable = this.rightFootTable;
                }
                let /** @type {?} */ maxWidth = this.toolsService.getStringWidth(td.text().trim(), 14);
                let /** @type {?} */ getMaxWidth = (trList) => {
                    if (!trList) {
                        return;
                    }
                    for (let /** @type {?} */ i = 0; i < trList.length; i++) {
                        let /** @type {?} */ text = $(trList[i].children[index]).text().trim();
                        let /** @type {?} */ _maxWidth = this.toolsService.getStringWidth(text);
                        if (maxWidth < _maxWidth) {
                            maxWidth = _maxWidth;
                        }
                    }
                };
                getMaxWidth(bodyTable[0].children[0].children);
                if (footTable) {
                    getMaxWidth(footTable[0].children[0].children);
                }
                td.attr("old-width", td.attr("width"));
                td.attr("width", this.toolsService.parseInt(this.remService.remPxConvertToPx(maxWidth).toFixed(0)) + 20);
            };
            this.centerHeadTable.dblclick(dblclickAdaptable);
            if (this.leftHeadTable) {
                this.leftHeadTable.dblclick(dblclickAdaptable);
            }
            if (this.rightHeadTable) {
                this.rightHeadTable.dblclick(dblclickAdaptable);
            }
        })();
    }
    /**
     * @return {?}
     */
    initPageable() {
        if (this.hidePage) {
            return;
        }
        if (!this.pageableComponent) {
            this.pageableComponent = this.dynamicComponentService.createByComponent(this.viewContainerRef, PageableComponent).instance;
            this.pageableComponent.query = () => {
                if (!this.defaultRows) {
                    this.tableBoxService.setTableRows(this._queryParams.rows);
                }
                this.query();
            };
        }
        this.pageableComponent.loading = this._loading;
        if (this._queryParams.rows === null || isUndefined(this._queryParams.rows)) {
            this._queryParams.rows = this.tableBoxService.getTableRows();
            if (this._queryParams.rows === null || isUndefined(this._queryParams.rows)) {
                this._queryParams.rows = 100;
            }
        }
        if (this._queryParams.page === null || isUndefined(this._queryParams.page)) {
            this._queryParams.page = 1;
        }
        this.pageableComponent.queryParams = this._queryParams;
        this.pageableComponent.pageData = this._pageData;
        this.pageableComponent.initPageBtn();
    }
    /**
     * @return {?}
     */
    initBottomBox() {
        let /** @type {?} */ bottomBoxParent = this.toolsService.jqNotNull(this.host.find(".bottom-box-parent"));
        this.bottomBox = this.toolsService.jqNotNull(this.host.find(".bottom-box"));
        if (this.bottomBox) {
            if (bottomBoxParent) {
                bottomBoxParent.append(this.bottomBox);
            }
            else {
                this.bottomBox.css("padding", "5px");
                this.host.append(this.bottomBox);
            }
        }
    }
    /**
     * @return {?}
     */
    initSearchBox() {
        this.searchBox = this.toolsService.jqNotNull(this.host.find(".search-box"));
        if (!this.searchBox) {
            return;
        }
        if (this.titleBox) {
            this.titleBox.after(this.searchBox);
        }
        else {
            this.host.prepend(this.searchBox);
        }
        this.searchBox.after($(`<div class="clear-both"></div>`));
        let /** @type {?} */ searchInputKeyup = (event) => {
            if (event.keyCode === 13) {
                this.query();
            }
        };
        setTimeout(() => {
            this.searchBox.find("input").keyup((event) => {
                searchInputKeyup(event);
            });
            this.searchBox.find("select").keyup((event) => {
                searchInputKeyup(event);
            });
        });
        let /** @type {?} */ searchBoxHeight = this.searchBox.height();
        let /** @type {?} */ searchDownButton = $("<span class='animated top-icons icon-caret-down up-down-rotate'></span>");
        this.host.append(searchDownButton);
        let /** @type {?} */ running = false;
        searchDownButton.click(() => {
            if (running) {
                return;
            }
            running = true;
            searchBoxHeight = this.searchBox.height();
            if (searchDownButton.hasClass("down-up-rotate")) {
                searchDownButton.removeClass("down-up-rotate");
                searchDownButton.addClass("up-down-rotate");
                this.searchBox.find("searchInput:eq(0)").focus();
                this.windowResize(-searchBoxHeight, true, true);
            }
            else {
                searchDownButton.removeClass("up-down-rotate");
                searchDownButton.addClass("down-up-rotate");
                this.windowResize(searchBoxHeight, true, false);
            }
            this.searchBox.animate({
                height: "toggle",
                opacity: "toggle"
            }, 500, function () {
                running = false;
            });
        });
        let /** @type {?} */ searchButton = $("<span class='top-icons icon-search' title='查询'></span>");
        searchButton.click(() => {
            this.query();
        });
        this.searchBox.append(searchButton);
        let /** @type {?} */ resetButton = $("<span class='top-icons icon-cancel' title='清空搜索条件'></span>");
        resetButton.click(() => {
            this.query(this.firstQueryParams);
        });
        this.searchBox.append(resetButton);
    }
    /**
     * @return {?}
     */
    dispatchSortEvent() {
        if (this.host) {
            this.host.find("jy-sort").trigger(SORT_EVENT, [{
                    queryParams: this._queryParams,
                    loading: this._loading,
                    query: () => {
                        this.query();
                    }
                }]);
        }
    }
    /**
     * @param {?=} queryParams
     * @return {?}
     */
    query(queryParams = null) {
        if (this._loading) {
            return;
        }
        if (queryParams) {
            for (let /** @type {?} */ key in this._queryParams) {
                if (key) {
                    this._queryParams[key] = queryParams[key];
                }
            }
        }
        this.loading = true;
        this.onQuery.emit();
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.windowResize(0);
    }
    /**
     * @param {?=} offsetTop
     * @param {?=} animate
     * @param {?=} searchBoxShow
     * @return {?}
     */
    windowResize(offsetTop = null, animate$$1 = false, searchBoxShow = null) {
        if (!this.bodyTr) {
            return;
        }
        if (this.bodyTr.offset().top === 0) {
            return;
        }
        let /** @type {?} */ centerHeadWidth = this.host.width();
        if (this.leftHeadTd) {
            centerHeadWidth -= this.leftTableWidth;
        }
        if (this.rightHeadTd) {
            centerHeadWidth -= this.rightTableWidth;
        }
        if (centerHeadWidth < this.centerHeadTable.width()) {
            this.centerHeadTd.width(centerHeadWidth);
            this.centerBodyDiv.css("overflow-x", "scroll");
            if (this.leftBodyDiv) {
                this.leftBodyDiv.css("padding-bottom", this.remService.realPx(16));
                this.leftBodyScrollPlace.show();
            }
            if (this.rightBodyDiv) {
                this.rightBodyDiv.css("padding-bottom", this.remService.realPx(16));
                this.rightBodyScrollPlace.show();
            }
        }
        else {
            centerHeadWidth = this.centerHeadTable.width();
            this.centerHeadTd.width(this.centerHeadTable.width());
            this.centerBodyDiv.css("overflow-x", "hidden");
            if (this.leftBodyDiv) {
                this.leftBodyDiv.css("padding-bottom", 0);
                this.leftBodyScrollPlace.hide();
            }
            if (this.rightBodyDiv) {
                this.rightBodyDiv.css("padding-bottom", 0);
                this.rightBodyScrollPlace.hide();
            }
        }
        this.containerTable.width(this.remService.pxConvertToRem(this.leftTableWidth + this.rightTableWidth + centerHeadWidth + this.remService.realPx(1)) + "rem");
        let /** @type {?} */ windowHeight = window.innerHeight;
        let /** @type {?} */ maxHeight = 0;
        if (this.fixedHeight) {
            maxHeight = this.fixedHeight;
            if (this.searchBox) {
                maxHeight -= this.searchBox.height();
            }
            maxHeight -= this.headTr.height();
            if (this.footTr) {
                maxHeight -= this.footTr.height();
            }
            if (!this.hidePage || this.bottomBox) {
                maxHeight -= this.remService.realPx(this.pageableHeight);
            }
            if (offsetTop !== null) {
                maxHeight += offsetTop;
            }
        }
        else if (this.heightPercent) {
            maxHeight = windowHeight * this.heightPercent;
            if (this.searchBox) {
                maxHeight -= this.searchBox.height();
            }
            maxHeight -= this.headTr.height();
            if (this.footTr) {
                maxHeight -= this.footTr.height();
            }
            if (!this.hidePage || this.bottomBox) {
                maxHeight -= this.remService.realPx(this.pageableHeight);
            }
            if (offsetTop !== null) {
                maxHeight += offsetTop;
            }
        }
        else {
            maxHeight = windowHeight - this.centerBodyTd.offset().top - this.remService.realPx(18);
            if (!this.hidePage || this.bottomBox) {
                maxHeight -= this.remService.realPx(this.pageableHeight);
            }
            if (this.centerFootTd) {
                maxHeight -= this.remService.realPx(this.pageableHeight);
            }
            if (offsetTop !== null) {
                maxHeight += offsetTop;
            }
            if (this.toolsService.jqNotNull(this.host.closest(".modal-box"))) {
                maxHeight -= this.remService.realPx(23);
                let /** @type {?} */ modalFooter = this.toolsService.jqNotNull(this.host.closest(".modal-box").find(".modal-footer"));
                if (modalFooter) {
                    maxHeight -= modalFooter.outerHeight();
                    maxHeight -= this.remService.realPx(15);
                }
            }
        }
        if (this.offsetHeight) {
            maxHeight += this.offsetHeight;
        }
        if (maxHeight < this.remService.realPx(this.minTableHeight)) {
            maxHeight = this.remService.realPx(this.minTableHeight);
        }
        let /** @type {?} */ bodyTop = this.headTr.height();
        if (this.titleBox) {
            bodyTop += this.titleBox.height();
        }
        if (this.searchBox && searchBoxShow !== false) {
            bodyTop += this.searchBox.height();
        }
        let /** @type {?} */ loadingWidth = this.remService.realPx(60);
        let /** @type {?} */ loadingHeight = this.remService.realPx(80);
        let /** @type {?} */ loadingTop = maxHeight / 2 - loadingHeight / 2 + bodyTop;
        let /** @type {?} */ messageTop = maxHeight / 2 - this.messageBox.height() / 2 + bodyTop;
        if (animate$$1) {
            this.loadingBox.animate({
                "top": loadingTop
            }, 500);
            this.messageBox.animate({
                "top": messageTop
            }, 500);
            this.centerBodyTd.animate({
                "height": maxHeight
            }, 500);
        }
        else {
            this.centerBodyTd.height(maxHeight);
            this.loadingBox.css("top", loadingTop);
            this.messageBox.css("top", messageTop);
        }
        this.loadingBox.css("left", this.host.width() / 2 - loadingWidth / 2);
        this.messageBox.css("left", this.host.width() / 2 - this.messageBox.width() / 2);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.windowResizeResetType();
    }
}
TableBoxDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyTableBox]"
            },] },
];
/** @nocollapse */
TableBoxDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ViewContainerRef, },
    { type: ToolsService, },
    { type: BrowserService, },
    { type: DynamicComponentService, },
    { type: GlobalEventsService, },
    { type: TableBoxService, },
    { type: RemService, },
    { type: ValidatorService, },
];
TableBoxDirective.propDecorators = {
    "pageData": [{ type: Input },],
    "defaultColumnWidth": [{ type: Input },],
    "heightPercent": [{ type: Input },],
    "fixedHeight": [{ type: Input },],
    "offsetHeight": [{ type: Input },],
    "minTableHeight": [{ type: Input },],
    "headRows": [{ type: Input },],
    "footRows": [{ type: Input },],
    "hidePage": [{ type: Input },],
    "closeSelected": [{ type: Input },],
    "queryParams": [{ type: Input },],
    "dontAutoQuery": [{ type: Input },],
    "onQuery": [{ type: Output },],
    "onLoading": [{ type: Output },],
    "onInit": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * class
 */
class ClassDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyClass(value) {
        this.currentClass = value;
        this.host.removeClass(this.lastClass);
        this.lastClass = value;
        this.host.addClass(this.currentClass);
    }
}
ClassDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyClass]"
            },] },
];
/** @nocollapse */
ClassDirective.ctorParameters = () => [
    { type: ElementRef, },
];
ClassDirective.propDecorators = {
    "jyClass": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * title
 */
class TitleDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyTitle(value) {
        this.host.attr("title", this.toolsService.getString(value));
    }
}
TitleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyTitle]"
            },] },
];
/** @nocollapse */
TitleDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
TitleDirective.propDecorators = {
    "jyTitle": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 排序
 */
class SortComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.over = false;
        this.queryParams = new DefaultQueryParams();
        this.host = $(elementRef.nativeElement);
        this.host.on(SORT_EVENT, (event, sortEventData) => {
            this.sortEventData = sortEventData;
            this.queryParams = sortEventData.queryParams;
        });
    }
    /**
     * @return {?}
     */
    sort() {
        if (!this.sortEventData || this.sortEventData.loading) {
            return;
        }
        if (this.queryParams.sortAsc == null || this.sortId !== this.queryParams.sortId) {
            this.queryParams.sortId = this.sortId;
            this.queryParams.sortAsc = true;
        }
        else if (this.queryParams.sortAsc === true) {
            this.queryParams.sortId = this.sortId;
            this.queryParams.sortAsc = false;
        }
        else {
            this.queryParams.sortId = null;
            this.queryParams.sortAsc = null;
        }
        this.sortEventData.query();
    }
    ;
}
SortComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-sort',
                template: `<span class="table-sort fa" title="排序" (mouseover)="over = true;" (mouseleave)="over = false;"
      [ngClass]="{
          'icon-sort':!((queryParams.sortId && queryParams.sortId == sortId && queryParams.sortAsc === true) || (queryParams.sortId && queryParams.sortId == sortId && queryParams.sortAsc === false)),
          'icon-sort-down':(queryParams.sortId && queryParams.sortId == sortId && queryParams.sortAsc === false),
          'icon-sort-up':(queryParams.sortId && queryParams.sortId == sortId && queryParams.sortAsc === true),
          'none':!(over || (queryParams.sortId && queryParams.sortId == sortId)),
          'primary':(over || (queryParams.sortId && queryParams.sortId == sortId))
          }"
      (click)="sort()">
</span>
`,
                styles: [`.table-sort{position:absolute;top:.10714286rem;right:.17857143rem;cursor:pointer}`]
            },] },
];
/** @nocollapse */
SortComponent.ctorParameters = () => [
    { type: ElementRef, },
];
SortComponent.propDecorators = {
    "sortId": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * class
 */
class ValueDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyValue(value) {
        this.host.attr("value", this.toolsService.getString(value));
    }
}
ValueDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyValue]"
            },] },
];
/** @nocollapse */
ValueDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
ValueDirective.propDecorators = {
    "jyValue": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DatePipe {
    /**
     * @param {?} dateService
     */
    constructor(dateService) {
        this.dateService = dateService;
    }
    /**
     * @param {?} value
     * @param {?=} args
     * @return {?}
     */
    transform(value, args) {
        if (value === null || isUndefined(value)) {
            return "";
        }
        try {
            let /** @type {?} */ date = null;
            if (isDate(value)) {
                date = value;
            }
            else {
                date = new Date(value);
            }
            return this.dateService.format(date, args ? args : this.dateService.YYYYMMDDHHMMSS);
        }
        catch (/** @type {?} */ e) {
            return "";
        }
    }
}
DatePipe.decorators = [
    { type: Pipe, args: [{
                name: 'jyDate'
            },] },
];
/** @nocollapse */
DatePipe.ctorParameters = () => [
    { type: DateService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AmountPipe {
    /**
     * @param {?} value
     * @param {?=} args
     * @return {?}
     */
    transform(value, args) {
        if (value === null || isUndefined(value) || value.toString().trim() === "") {
            return "";
        }
        try {
            value = parseFloat(value);
            return value.toFixed(2);
        }
        catch (/** @type {?} */ e) {
            return "";
        }
    }
}
AmountPipe.decorators = [
    { type: Pipe, args: [{
                name: 'jyAmount'
            },] },
];
/** @nocollapse */
AmountPipe.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 验证器指令
 */
class ValidatorDirective {
    /**
     * @param {?} elementRef
     * @param {?} validatorService
     */
    constructor(elementRef, validatorService) {
        this.elementRef = elementRef;
        this.validatorService = validatorService;
        this.async = false;
        this.validatorControlInit = new EventEmitter();
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.validatorControl = this.validatorService.init(this.host, this.async, this.customValidator);
        this.validatorControlInit.emit(this.validatorControl);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.validatorControl.destroy();
    }
}
ValidatorDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyValidator]"
            },] },
];
/** @nocollapse */
ValidatorDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ValidatorService, },
];
ValidatorDirective.propDecorators = {
    "async": [{ type: Input },],
    "customValidator": [{ type: Input },],
    "validatorControlInit": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * class
 */
class EnterDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.jyEnter = new EventEmitter();
        $(elementRef.nativeElement).keyup((event) => {
            if (event.keyCode === 13) {
                this.jyEnter.emit(event);
            }
        });
    }
}
EnterDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyEnter]"
            },] },
];
/** @nocollapse */
EnterDirective.ctorParameters = () => [
    { type: ElementRef, },
];
EnterDirective.propDecorators = {
    "jyEnter": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * focus
 */
class FocusDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyFocus(value) {
        this.value = value;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            if (this.value !== false) {
                this.host.focus();
            }
        }, 100);
    }
}
FocusDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyFocus]"
            },] },
];
/** @nocollapse */
FocusDirective.ctorParameters = () => [
    { type: ElementRef, },
];
FocusDirective.propDecorators = {
    "jyFocus": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * src
 */
class SrcDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jySrc(value) {
        this.host.attr("src", this.toolsService.getString(value));
    }
}
SrcDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jySrc]"
            },] },
];
/** @nocollapse */
SrcDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
SrcDirective.propDecorators = {
    "jySrc": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * accept
 */
class AcceptDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyAccept(value) {
        this.host.attr("accept", this.toolsService.getString(value));
    }
}
AcceptDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyAccept]"
            },] },
];
/** @nocollapse */
AcceptDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
AcceptDirective.propDecorators = {
    "jyAccept": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 提示框
 */
class ImagePreviewComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.imagePreviewParams = null;
        this.closeFlag = false;
    }
    /**
     * @param {?} imagePreviewParams
     * @return {?}
     */
    setTransmitData(imagePreviewParams) {
        this.imagePreviewParams = imagePreviewParams;
    }
    /**
     * @return {?}
     */
    close() {
        if (this.closeFlag) {
            return;
        }
        this.closeFlag = true;
        this.imagePreviewParams.preClose();
        this.imagePreview.animate({
            top: this.imagePreviewParams.top,
            left: this.imagePreviewParams.left,
            width: this.imagePreviewParams.width,
            height: this.imagePreviewParams.height,
            opacity: 0.7
        }, 500, "swing", () => {
            this.imagePreviewParams.close();
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    click(event) {
        if ((/** @type {?} */ (event.target)).nodeName.toLocaleLowerCase() === "img") {
            return;
        }
        this.close();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.imagePreview = $(this.elementRef.nativeElement).find(".image-preview");
        this.imagePreview.css({
            top: this.imagePreviewParams.top,
            left: this.imagePreviewParams.left,
            width: this.imagePreviewParams.width,
            height: this.imagePreviewParams.height,
            opacity: 0.7
        }).animate({
            top: 0,
            left: 0,
            width: "100%",
            height: "100%",
            opacity: 1
        }, 500, "swing");
    }
}
ImagePreviewComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-image-preview',
                template: `<div class="image-preview" (click)="click($event)">
  <div class="image-preview-slider">
    <div class="full-image">
      <figure>
        <img [jySrc]="imagePreviewParams.imageUrl">
      </figure>
    </div>
  </div>
  <button class="image-preview-button" (click)="close()">
    <svg width="30" height="30">
      <g stroke="rgb(160, 160, 160)" stroke-width="4">
        <line x1="5" y1="5" x2="25" y2="25"></line>
        <line x1="5" y1="25" x2="25" y2="5"></line>
      </g>
    </svg>
  </button>
</div>
`,
                styles: [``]
            },] },
];
/** @nocollapse */
ImagePreviewComponent.ctorParameters = () => [
    { type: ElementRef, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 图片上传
 */
class ImageUploadComponent {
    /**
     * @param {?} elementRef
     * @param {?} fileUploadService
     * @param {?} alertService
     * @param {?} toolsService
     * @param {?} modalService
     * @param {?} remService
     */
    constructor(elementRef, fileUploadService, alertService, toolsService, modalService, remService) {
        this.elementRef = elementRef;
        this.fileUploadService = fileUploadService;
        this.alertService = alertService;
        this.toolsService = toolsService;
        this.modalService = modalService;
        this.remService = remService;
        this.rem = rem;
        this.jyName = "";
        this.jyRequiredMessage = "请上传图片";
        this.jyRequired = false;
        this.jyValidate = true;
        this.imageAccept = ".BMP,.JPG,.JPEG,.PNG";
        this.disabled = false;
        this._imageWidth = 102;
        this._imageHeight = 102;
        this.showDelete = true;
        this._imageId = "";
        this.imageIdChange = new EventEmitter();
        this.mouseover = false;
        this.imageUrl = "";
        this.uploading = false;
        this.nullImageFontSize = 70;
        this.nullImageMarginTop = 0;
        this.formatSize = "";
        this.percent = 0;
        this.loaded = "";
        this.currentSpeed = "";
        this.host = $(elementRef.nativeElement);
        this.host.css("display", "block");
        this.imageResize();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set imageWidth(value) {
        this._imageWidth = value;
        this.host.css("width", this._imageWidth / rem + "rem");
        this.imageResize();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set imageHeight(value) {
        this._imageHeight = value;
        this.host.css("height", this._imageHeight / rem + "rem");
        this.imageResize();
    }
    /**
     * @return {?}
     */
    get imageId() {
        return this._imageId;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set imageId(value) {
        if (this._imageId === value) {
            return;
        }
        this._imageId = value;
        if (this.toolsService.isNotNull(this._imageId)) {
            this.imageUrl = this.fileUploadService.getFileUrl(this._imageId);
        }
        else {
            this.imageUrl = "";
        }
        setTimeout(() => {
            this.imageIdChange.emit(this._imageId);
        });
    }
    /**
     * @return {?}
     */
    onchange() {
        if (this.uploading || this.disabled) {
            return;
        }
        let /** @type {?} */ fileList = (/** @type {?} */ (this.fileInput.get(0))).files;
        if (fileList == null || fileList.length === 0) {
            return;
        }
        this.fileUploadService.upload({
            file: fileList[0],
            init: (data) => {
                let /** @type {?} */ validate = false;
                for (let /** @type {?} */ accept of this.imageAccept.split(",")) {
                    if (accept.toLowerCase() === "." + data.postfix.toLowerCase()) {
                        validate = true;
                        break;
                    }
                }
                if (!validate) {
                    this.alertService.open({
                        iconType: Icon.warning,
                        content: "上传的文件不是图片格式！"
                    });
                    return;
                }
                this.uploading = true;
                this.formatSize = data.formatSize;
                data.start();
            },
            success: (event, data) => {
                this.imageId = data.fileId;
                this.uploading = false;
                this.formatSize = "";
                this.percent = 0;
                this.loaded = "";
                this.currentSpeed = "";
            },
            progress: (event, data) => {
                this.percent = data.percent;
                this.currentSpeed = data.currentSpeed;
                this.loaded = data.loaded;
            },
            error: (event, data) => {
                this.uploading = false;
                this.formatSize = "";
                this.percent = 0;
                this.loaded = "";
                this.currentSpeed = "";
            }
        });
        this.fileInput.val("");
    }
    /**
     * @return {?}
     */
    selectFile() {
        if (this.uploading || this.disabled) {
            return;
        }
        this.fileInput.click();
    }
    /**
     * @return {?}
     */
    download() {
        if (this.imageUrl) {
            window.location.href = this.imageUrl;
        }
    }
    /**
     * @return {?}
     */
    openPreview() {
        if (this.imageUrl) {
            this.modalService.open(/** @type {?} */ ({
                imageUrl: this.imageUrl,
                top: (this.image.offset().top + this.remService.realPx(1)),
                left: (this.image.offset().left + this.remService.realPx(1)),
                width: this._imageWidth - this.remService.realPx(2),
                height: this._imageHeight - this.remService.realPx(2),
            }), ImagePreviewComponent, false);
        }
    }
    /**
     * @return {?}
     */
    imageResize() {
        this.nullImageFontSize = (this._imageHeight - this.remService.realPx(2)) * 0.7;
        if (this.nullImageFontSize > this._imageWidth - this.remService.realPx(2)) {
            this.nullImageFontSize = this._imageWidth - this.remService.realPx(2);
            this.nullImageMarginTop = (this._imageHeight - this.remService.realPx(2) - this.nullImageFontSize * 1.4) / 2;
            this.nullImageFontSize -= this.remService.realPx(20);
            this.nullImageMarginTop += this.remService.realPx(10);
        }
        else {
            this.nullImageMarginTop = 0;
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.fileInput = this.host.find("input");
        this.image = this.host.find("img");
    }
}
ImageUploadComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-image-upload',
                template: `<div class="image-upload" [ngStyle]="{'width.rem': _imageWidth/rem,'height.rem': _imageHeight/rem}"
     (mouseover)="mouseover = true" (mouseleave)="mouseover = false;" [jyCustomValidator]="imageId"
     [jyValidate]="jyValidate" [jyRequired]="jyRequired" [jyName]="jyName" [jyRequiredMessage]="jyRequiredMessage">
  <input class="hide" type="file" [jyAccept]="imageAccept" (change)="onchange()"/>
  <div [ngStyle]="{cursor: disabled ? 'auto' : 'pointer'}" (click)="selectFile()">
    <img [jySrc]="imageUrl" [jyTitle]="disabled ? '':'点击上传'"
         [@fadeOnlyShow]="imageUrl && !uploading ? 'show':'hide'"
         [ngStyle]="{'width.rem': (_imageWidth - 2)/rem, 'height.rem': (_imageHeight - 2)/rem}"
         [ngClass]="{'cursor-pointer': !disabled}">
    <span class="icon-image" [@fadeOnlyShow]="!imageUrl && !uploading ? 'show':'hide'"
          [ngStyle]="{'font-size.rem': nullImageFontSize/rem,'margin-top.rem':nullImageMarginTop/rem}"></span>
  </div>
  <div class="progress-box" [@fadeOnlyShow]="uploading ? 'show':'hide'"
       [ngStyle]="{'width.rem': (_imageWidth * 0.7)/rem,'top.rem': _imageHeight/2/rem - 20/rem,'left.rem': ((_imageWidth/rem) * 0.3)/2}">
    <div class="progress-text">
      &nbsp;
      <span [jyHidden]="_imageWidth < 160">
         {{loaded + "/" + formatSize}}
      </span>
    </div>
    <div class="progress">
      <div class="progress-bar progress-bar-info progress-bar-striped active" role="progressbar"
           [ngStyle]="{width: percent + '%'}">
      </div>
    </div>
  </div>
  <span class="current-speed" [@fadeOnlyShow]="uploading ? 'show':'hide'">{{currentSpeed}}</span>
  <div class="button-box" [ngStyle]="{'width.rem': (_imageWidth - 2)/rem}"
       [jyHidden]="!mouseover || !imageUrl">
    <span class="icon-download" (click)="download()" title="下载"></span>
    <span class="icon-search" (click)="openPreview()" title="预览"></span>
    <span class="icon-cancel" [jyHidden]="disabled || !showDelete" (click)="imageId = ''"
          title="删除"></span>
  </div>
</div>
`,
                styles: [`.image-upload{border:.03571429rem solid #ccc;border-radius:.14285714rem;position:relative;text-align:center;vertical-align:middle;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.image-upload img{border-radius:.14285714rem;display:block}.image-upload .icon-image{color:#ccc}.image-upload .icon-spinner{color:#ccc;position:absolute;font-size:1.42857143rem;top:calc(50% - 1.07142857rem);left:calc(50% - .71428571rem)}.image-upload .button-box{position:absolute;bottom:0;background-color:rgba(0,0,0,.7);line-height:1.14285714rem;color:#fff}.image-upload .button-box span{padding:0 .28571429rem;margin:0 .03571429rem;cursor:pointer;-webkit-transition:All .3s ease-in-out;transition:All .3s ease-in-out}.image-upload .button-box span:hover{-webkit-transform:scale(1.4);transform:scale(1.4)}.image-upload .progress-box{position:absolute}.image-upload .progress-box .progress-text{font-size:.42857143rem;text-align:right}.image-upload .current-speed{position:absolute;right:.07142857rem;top:0}.image-upload .progress{margin-bottom:0;height:.53571429rem}`],
                animations: [fadeShow, fadeOnlyShow]
            },] },
];
/** @nocollapse */
ImageUploadComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: FileUploadService, },
    { type: AlertService, },
    { type: ToolsService, },
    { type: ModalService, },
    { type: RemService, },
];
ImageUploadComponent.propDecorators = {
    "jyName": [{ type: Input },],
    "jyRequiredMessage": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "imageAccept": [{ type: Input },],
    "disabled": [{ type: Input },],
    "imageWidth": [{ type: Input },],
    "imageHeight": [{ type: Input },],
    "showDelete": [{ type: Input },],
    "imageId": [{ type: Input },],
    "imageIdChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * class
 */
class HiddenDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(elementRef.nativeElement);
        this.display = this.host.css("display");
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyHidden(value) {
        this.host.css("display", value ? "none" : this.display);
    }
}
HiddenDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyHidden]"
            },] },
];
/** @nocollapse */
HiddenDirective.ctorParameters = () => [
    { type: ElementRef, },
];
HiddenDirective.propDecorators = {
    "jyHidden": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 年月日 日期控件
 */
class YmdHmComponent {
    /**
     * @param {?} elementRef
     * @param {?} dateService
     * @param {?} toolsService
     * @param {?} tooltipService
     * @param {?} datetimePickerService
     */
    constructor(elementRef, dateService, toolsService, tooltipService, datetimePickerService) {
        this.elementRef = elementRef;
        this.dateService = dateService;
        this.toolsService = toolsService;
        this.tooltipService = tooltipService;
        this.datetimePickerService = datetimePickerService;
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this._minDate = null;
        this._maxDate = null;
        this._date = null;
        this._dateString = null;
        this.lastDate = null;
        this.lastDateString = "";
        this.dateChange = new EventEmitter();
        this.dateStringChange = new EventEmitter();
        this.eventIdClass = ".datetime-picker" + (Math.random() + "").replace(".", "");
        this.format = "YYYYMMDDHHmm";
        this.viewYear = null;
        this.viewMonth = null;
        this.viewHours = null;
        this.viewMinutes = null;
        this.yearList = null;
        this.monthList = null;
        this.hoursList = null;
        this.minutesList = null;
        this.weekList = [];
        this.viewDate = new Date();
        this.show = false;
        this.mouseEnter = false;
        this.transparent = true;
        this.clickHandler = null;
        let /** @type {?} */ host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.datetimePicker.addClass(this.eventIdClass.replace(".", ""));
    }
    /**
     * @param {?} minDate
     * @return {?}
     */
    set minDate(minDate) {
        this._minDate = this.dateService.reduceTime(minDate, this.dateService.YYYYMMDDHHMM);
        if (!this.validateRange(this._date).success) {
            this._date = null;
            this._dateString = "";
            this.emitDateChange();
        }
    }
    /**
     * @param {?} minDate
     * @return {?}
     */
    set minDateString(minDate) {
        this.minDate = this.dateService.parseTime(minDate, this.dateService.YYYYMMDDHHMM);
    }
    /**
     * @param {?} maxDate
     * @return {?}
     */
    set maxDate(maxDate) {
        this._maxDate = this.dateService.reduceTime(maxDate, this.dateService.YYYYMMDDHHMM);
        if (!this.validateRange(this._date).success) {
            this._date = null;
            this._dateString = "";
            this.emitDateChange();
        }
    }
    /**
     * @param {?} maxDate
     * @return {?}
     */
    set maxDateString(maxDate) {
        this.maxDate = this.dateService.parseTime(maxDate, this.dateService.YYYYMMDDHHMM);
    }
    /**
     * @param {?} date
     * @return {?}
     */
    set date(date) {
        date = this.dateService.reduceTime(date, this.dateService.YYYYMMDDHHMM);
        if (this._date === date) {
            return;
        }
        this._date = date;
        if (this._date) {
            this._dateString = this.dateService.format(this._date, this.dateService.YYYYMMDDHHMM);
            if (!this.validateRange(this._date).success) {
                this._date = null;
                this._dateString = "";
            }
        }
        else {
            this._date = null;
            this._dateString = "";
        }
        this.emitDateChange();
    }
    /**
     * @param {?} dateString
     * @return {?}
     */
    set dateString(dateString) {
        if (this._dateString === dateString) {
            return;
        }
        this._dateString = dateString;
        if (this._dateString) {
            this._date = this.dateService.parseTime(this._dateString, this.dateService.YYYYMMDDHHMM);
            if (!this.validateRange(this._date).success) {
                this._date = null;
                this._dateString = "";
            }
        }
        else {
            this._date = null;
            this._dateString = "";
        }
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    emitDateChange() {
        setTimeout(() => {
            if (this.lastDate !== this._date) {
                this.dateChange.emit(this._date);
                this.lastDate = this._date;
                this.input[0].dispatchEvent(new Event("blur"));
            }
            if (this.lastDateString !== this._dateString) {
                this.dateStringChange.emit(this._dateString);
                this.lastDateString = this._dateString;
                this.input[0].dispatchEvent(new Event("blur"));
            }
            this.customValidatorControl.trigger(this._date ? this._date.toString() : "");
        });
    }
    /**
     * @param {?} datetimePicker
     * @return {?}
     */
    set _datetimePicker(datetimePicker) {
        this.datetimePicker = $(datetimePicker.nativeElement);
    }
    ;
    /**
     * @param {?} box
     * @return {?}
     */
    set _box(box) {
        this.box = $(box.nativeElement);
    }
    ;
    /**
     * @param {?} input
     * @return {?}
     */
    set _input(input) {
        this.input = $(input.nativeElement);
    }
    ;
    /**
     * @return {?}
     */
    hmChange() {
        if (this._date !== null) {
            let /** @type {?} */ date = new Date(this._date);
            date.setHours(parseInt(this.viewHours));
            date.setMinutes(parseInt(this.viewMinutes));
            this._date = date.getTime();
            this._dateString = this.dateService.format(date, this.dateService.YYYYMMDDHHMM);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (event.keyCode === 13) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    keyup() {
        this._dateString = this.input.val();
        let /** @type {?} */ date = this.dateService.getDate(this.getCheckDateString(false, true));
        if (date) {
            date = new Date(date.getFullYear(), date.getMonth() + 1, 1, 0, 0, 0, 0);
            this.viewDate = date;
            this.viewYear = date.getFullYear().toString();
            this.viewMonth = (date.getMonth() + 1).toString();
            this.calculateView(this.viewDate);
        }
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.disabled || this.show) {
            return;
        }
        this.show = true;
        this.transparent = true;
        this.input.addClass("search-input-focus");
        this.viewDate = this._date !== null ? new Date(this._date) : new Date();
        const /** @type {?} */ validateResult = this.validateRange(this.viewDate, false, true);
        if (!validateResult.success) {
            if (!validateResult.minDateSuccess) {
                this.viewDate = validateResult.minDate;
            }
            else if (!validateResult.maxDateSuccess) {
                this.viewDate = validateResult.maxDate;
            }
        }
        this.viewYear = this.viewDate.getFullYear().toString();
        this.viewMonth = (this.viewDate.getMonth() + 1).toString();
        if (this.viewDate.getTime() === this._date) {
            this.viewHours = this.viewDate.getHours().toString();
            this.viewMinutes = this.viewDate.getMinutes().toString();
        }
        else {
            this.viewHours = "0";
            this.viewMinutes = "0";
        }
        this.calculateView(this.viewDate);
        this.rangeDateChange();
        setTimeout(() => {
            this.onWindowResize();
            this.transparent = false;
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.input, this.direction);
    }
    /**
     * @param {?=} check
     * @return {?}
     */
    viewHide(check = true) {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.input.removeClass("search-input-focus");
        if (check) {
            this._date = this.getCheckDateString();
            this._dateString = this._date ? this.dateService.format(this._date, this.dateService.YYYYMMDDHHMM) : "";
            this.emitDateChange();
        }
        this.input.blur();
    }
    /**
     * @param {?=} clear
     * @param {?=} noAlert
     * @return {?}
     */
    getCheckDateString(clear = false, noAlert = false) {
        const /** @type {?} */ dateString = this._dateString ? this._dateString.replace(/[^0-9]/ig, "") : "";
        let /** @type {?} */ date = null;
        if (dateString.length >= 12) {
            date = this.dateService.parse(dateString.substring(0, 12), this.format);
        }
        else if (dateString.length === 11) {
            date = this.dateService.parse(dateString + "0", this.format);
        }
        else if (dateString.length === 10) {
            date = this.dateService.parse(dateString + "00", this.format);
        }
        else if (dateString.length === 9) {
            date = this.dateService.parse(dateString + "000", this.format);
        }
        else if (dateString.length === 8) {
            date = this.dateService.parse(dateString + "0000", this.format);
        }
        else if (dateString.length === 7) {
            if (dateString.endsWith("0")) {
                date = this.dateService.parse(dateString + "10000", this.format);
            }
            else {
                date = this.dateService.parse(dateString + "00000", this.format);
            }
        }
        else if (dateString.length === 6) {
            date = this.dateService.parse(dateString + "010000", this.format);
        }
        else if (dateString.length === 5) {
            if (dateString.endsWith("0")) {
                date = this.dateService.parse(dateString + "1010000", this.format);
            }
            else {
                date = this.dateService.parse(dateString + "0010000", this.format);
            }
        }
        else if (dateString.length === 4) {
            date = this.dateService.parse(dateString + "01010000", this.format);
        }
        if (date && !this.validateRange(date, false, noAlert).success) {
            if (clear) {
                this._dateString = "";
                this._date = null;
            }
            return null;
        }
        return date ? date.getTime() : null;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    calculateView(date) {
        date = new Date(date.getFullYear(), date.getMonth(), 1, 0, 0, 0, 0);
        let /** @type {?} */ newWeekList = [];
        let /** @type {?} */ maxDays = this.dateService.getMaxDays(date);
        let /** @type {?} */ firstDay = date.getDay();
        if (firstDay === 0) {
            firstDay = 7;
        }
        let /** @type {?} */ selectDate = this.dateService.format(this._date, this.dateService.YYYYMMDD);
        let /** @type {?} */ todayDate = this.dateService.format(new Date(), this.dateService.YYYYMMDD);
        let /** @type {?} */ day = 1;
        let /** @type {?} */ week = [];
        for (let /** @type {?} */ i = 0; day <= maxDays || i % 7 !== 0; i++) {
            if (i !== 0 && i % 7 === 0) {
                newWeekList.push(week);
                week = [];
            }
            let /** @type {?} */ currentDate = null;
            let /** @type {?} */ current = false;
            if (i + 1 < firstDay) {
                /**
                 * 上个月的
                 */
                let /** @type {?} */ lastDate = new Date(date.getTime());
                lastDate.setDate(1);
                lastDate.setTime(lastDate.getTime() - (firstDay - i - 1) * 1000 * 60 * 60 * 24);
                currentDate = lastDate;
            }
            else {
                if (day <= maxDays) {
                    /**
                               * 当前月
                               */
                    date.setDate(day);
                    current = true;
                    day++;
                }
                else {
                    /**
                               * 下个月
                               */
                    date.setTime(date.getTime() + 1000 * 60 * 60 * 24);
                }
                currentDate = date;
            }
            let /** @type {?} */ currentDateString = this.dateService.format(currentDate, this.dateService.YYYYMMDD);
            let /** @type {?} */ today = todayDate === currentDateString;
            let /** @type {?} */ select = selectDate === currentDateString;
            let /** @type {?} */ disabled = false;
            if (this._minDate && this.dateService.format(currentDate, this.dateService.YYYYMMDD) < this.dateService.format(this._minDate, this.dateService.YYYYMMDD)) {
                disabled = true;
            }
            else if (this._maxDate && this.dateService.format(currentDate, this.dateService.YYYYMMDD) > this.dateService.format(this._maxDate, this.dateService.YYYYMMDD)) {
                disabled = true;
            }
            week.push({
                day: currentDate.getDate(),
                date: new Date(currentDate.getTime()),
                current: today ? true : current,
                today: today,
                select: select,
                disabled: disabled
            });
        }
        newWeekList.push(week);
        if (!this.weekList || JSON.stringify(this.weekList) !== JSON.stringify(newWeekList)) {
            this.weekList = newWeekList;
        }
    }
    /**
     * @return {?}
     */
    rangeDateChange() {
        if (this.yearList == null) {
            this.yearList = this.datetimePickerService.getYearList();
            this.monthList = this.datetimePickerService.getMonthList();
            this.hoursList = this.datetimePickerService.getHoursList();
            this.minutesList = this.datetimePickerService.getMinutesList();
        }
        else {
            this.yearList.forEach((item) => {
                item.disabled = false;
            });
            this.monthList.forEach((item) => {
                item.disabled = false;
            });
            this.hoursList.forEach((item) => {
                item.disabled = false;
            });
            this.minutesList.forEach((item) => {
                item.disabled = false;
            });
        }
        let /** @type {?} */ minDate = this.getMinDate();
        let /** @type {?} */ maxDate = this.getMaxDate();
        let /** @type {?} */ minYear = minDate.getFullYear();
        let /** @type {?} */ maxYear = maxDate.getFullYear();
        let /** @type {?} */ minMonth = minDate.getMonth() + 1;
        let /** @type {?} */ maxMonth = maxDate.getMonth() + 1;
        let /** @type {?} */ minDay = minDate.getDate();
        let /** @type {?} */ maxDay = maxDate.getDate();
        let /** @type {?} */ minHours = minDate.getHours();
        let /** @type {?} */ maxHours = maxDate.getHours();
        let /** @type {?} */ minMinutes = minDate.getMinutes();
        let /** @type {?} */ maxMinutes = maxDate.getMinutes();
        let /** @type {?} */ viewDay = this._date !== null ? new Date(this._date).getDate() : null;
        this.yearList.forEach((item) => {
            item.disabled = item.value < minYear || item.value > maxYear;
        });
        if (this.viewYear && (parseInt(this.viewYear) === minYear || parseInt(this.viewYear) === maxYear)) {
            this.monthList.forEach((item) => {
                item.disabled = item.value < minMonth || item.value > maxMonth;
            });
            if (viewDay && this.viewMonth) {
                if (parseInt(this.viewMonth) === minMonth && viewDay === minDay) {
                    this.hoursList.forEach((item) => {
                        if (!item.disabled) {
                            item.disabled = item.value < minHours;
                        }
                    });
                    if (this.hoursList.filter(item => item.disabled && item.value === parseInt(this.viewHours)).length > 0) {
                        this.viewHours = this.hoursList.filter(item => !item.disabled)[0].value.toString();
                    }
                    if (this.viewHours && parseInt(this.viewHours) === minHours) {
                        this.minutesList.forEach((item) => {
                            if (!item.disabled) {
                                item.disabled = item.value < minMinutes;
                            }
                        });
                        if (this.minutesList.filter(item => item.disabled && item.value === parseInt(this.viewMinutes)).length > 0) {
                            this.viewMinutes = this.minutesList.filter(item => !item.disabled)[0].value.toString();
                        }
                    }
                }
                if (parseInt(this.viewMonth) === maxMonth && viewDay === maxDay) {
                    this.hoursList.forEach((item) => {
                        if (!item.disabled) {
                            item.disabled = item.value > maxHours;
                        }
                    });
                    if (this.hoursList.filter(item => item.disabled && item.value === parseInt(this.viewHours)).length > 0) {
                        let /** @type {?} */ filterHoursList = this.hoursList.filter(item => !item.disabled);
                        this.viewHours = filterHoursList[filterHoursList.length - 1].value.toString();
                    }
                    if (this.viewHours && parseInt(this.viewHours) === maxHours) {
                        this.minutesList.forEach((item) => {
                            if (!item.disabled) {
                                item.disabled = item.value > maxMinutes;
                            }
                        });
                        if (this.minutesList.filter(item => item.disabled && item.value === parseInt(this.viewMinutes)).length > 0) {
                            let /** @type {?} */ filterMinutesList = this.minutesList.filter(item => !item.disabled);
                            this.viewMinutes = filterMinutesList[filterMinutesList.length - 1].value.toString();
                        }
                    }
                }
            }
        }
        this.hmChange();
        this.yearList = JSON.parse(JSON.stringify(this.yearList));
        this.monthList = JSON.parse(JSON.stringify(this.monthList));
        this.hoursList = JSON.parse(JSON.stringify(this.hoursList));
        this.minutesList = JSON.parse(JSON.stringify(this.minutesList));
    }
    /**
     * @param {?=} event
     * @return {?}
     */
    lastYear(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(-1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    lastMonth(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(0, -1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    nextMonth(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(0, 1);
    }
    ;
    /**
     * @param {?=} event
     * @return {?}
     */
    nextYear(event = null) {
        if (event !== null) {
            (/** @type {?} */ (event.currentTarget)).blur();
        }
        this.viewDateChange(1);
    }
    ;
    /**
     * @param {?} value
     * @return {?}
     */
    monthMousewheel(value) {
        if (value < 0) {
            this.lastMonth();
        }
        else if (value > 0) {
            this.nextMonth();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    yearMousewheel(value) {
        if (value < 0) {
            this.lastYear();
        }
        else if (value > 0) {
            this.nextYear();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    hoursMousewheel(value) {
        this.viewTimeChange((value < 0 ? -1 : 1), 0);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    minutesMousewheel(value) {
        this.viewTimeChange(0, (value < 0 ? -1 : 1));
    }
    /**
     * @param {?=} viewYearDiff
     * @param {?=} viewMonthDiff
     * @return {?}
     */
    viewDateChange(viewYearDiff = 0, viewMonthDiff = 0) {
        let /** @type {?} */ viewYear = parseInt(this.viewYear) + viewYearDiff;
        let /** @type {?} */ viewMonth = parseInt(this.viewMonth) + viewMonthDiff;
        if (viewMonth === 0) {
            viewYear--;
            viewMonth = 12;
        }
        else if (viewMonth === 13) {
            viewYear++;
            viewMonth = 1;
        }
        let /** @type {?} */ viewDate = new Date(viewYear, viewMonth - 1, 1, 0, 0, 0, 0);
        if (!this.validateRange(viewDate, true).success) {
            return;
        }
        this.viewDate = viewDate;
        this.viewYear = viewYear.toString();
        this.viewMonth = viewMonth.toString();
        this.rangeDateChange();
        this.calculateView(this.viewDate);
    }
    /**
     * @param {?=} viewHoursDiff
     * @param {?=} viewMinutesDiff
     * @return {?}
     */
    viewTimeChange(viewHoursDiff = 0, viewMinutesDiff = 0) {
        let /** @type {?} */ viewHours = parseInt(this.viewHours) + viewHoursDiff;
        let /** @type {?} */ viewMinutes = parseInt(this.viewMinutes) + viewMinutesDiff;
        if (this.hoursList.filter(item => item.value === viewHours && item.disabled).length > 0) {
            this.tooltipRangeError(viewHoursDiff < 0 ? "minDate" : "maxDate");
            return;
        }
        if (this.minutesList.filter(item => item.value === viewMinutes && item.disabled).length > 0) {
            this.tooltipRangeError(viewMinutesDiff < 0 ? "minDate" : "maxDate");
            return;
        }
        this.viewHours = viewHours.toString();
        if (this.viewHours === "-1") {
            this.viewHours = "23";
        }
        else if (this.viewHours === "24") {
            this.viewHours = "0";
        }
        this.viewMinutes = viewMinutes.toString();
        if (this.viewMinutes === "-1") {
            this.viewMinutes = "59";
        }
        else if (this.viewMinutes === "60") {
            this.viewMinutes = "0";
        }
        this.hmChange();
        this.rangeDateChange();
    }
    /**
     * @param {?} date
     * @param {?=} onlyYearAndMonth
     * @param {?=} noAlert
     * @return {?}
     */
    validateRange(date, onlyYearAndMonth = false, noAlert = false) {
        let /** @type {?} */ _date = this.dateService.getDate(date);
        if (!_date) {
            this.tooltipRangeError("none");
            return {
                success: true
            };
        }
        let /** @type {?} */ minDate = this.getMinDate();
        let /** @type {?} */ maxDate = this.getMaxDate();
        if (onlyYearAndMonth) {
            _date = this.dateService.reduce(_date, this.dateService.YYYYMM);
            minDate = this.dateService.reduce(minDate, this.dateService.YYYYMM);
            maxDate = this.dateService.reduce(maxDate, this.dateService.YYYYMM);
        }
        if (_date.getTime() < minDate.getTime()) {
            if (!noAlert) {
                this.tooltipRangeError("minDate");
            }
            return {
                success: false,
                minDateSuccess: false,
                maxDateSuccess: true,
                minDate: minDate,
                maxDate: maxDate,
            };
        }
        if (_date.getTime() > maxDate.getTime()) {
            if (!noAlert) {
                this.tooltipRangeError("maxDate");
            }
            return {
                success: false,
                minDateSuccess: true,
                maxDateSuccess: false,
                minDate: minDate,
                maxDate: maxDate,
            };
        }
        this.tooltipRangeError("none");
        return {
            success: true
        };
    }
    /**
     * @param {?} type
     * @return {?}
     */
    tooltipRangeError(type) {
        if (type === "minDate") {
            this.tooltipService.open({
                host: this.input,
                content: "最小可选日期为" + this.dateService.format(this.getMinDate(), this.dateService.YYYYMMDDHHMM),
                direction: this.jyTooltipDirection
            });
        }
        else if (type === "maxDate") {
            this.tooltipService.open({
                host: this.input,
                content: "最大可选日期为" + this.dateService.format(this.getMaxDate(), this.dateService.YYYYMMDDHHMM),
                direction: this.jyTooltipDirection
            });
        }
        else if (type === "none") {
            this.tooltipService.open({
                host: this.input,
                content: null
            });
        }
    }
    /**
     * @return {?}
     */
    getMinDate() {
        let /** @type {?} */ minDate = this.dateService.getDate(this._minDate);
        return minDate && minDate.getTime() > this.datetimePickerService.getMinDate().getTime() ? minDate : this.datetimePickerService.getMinDate();
    }
    /**
     * @return {?}
     */
    getMaxDate() {
        let /** @type {?} */ maxDate = this.dateService.getDate(this._maxDate);
        return maxDate && maxDate.getTime() < this.datetimePickerService.getMaxDate().getTime() ? maxDate : this.datetimePickerService.getMaxDate();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectDate(item) {
        if (item.disabled) {
            return;
        }
        if (!this.validateRange(item.date, true).success) {
            return;
        }
        if (!item.date) {
            this._date = null;
            this._dateString = "";
            this.ok();
            return;
        }
        let /** @type {?} */ date = this.dateService.reduce(item.date, this.dateService.YYYYMMDD);
        date.setHours(parseInt(this.viewHours));
        date.setMinutes(parseInt(this.viewMinutes));
        this._date = date.getTime();
        this._dateString = this.dateService.format(date, this.dateService.YYYYMMDDHHMM);
        this.calculateView(new Date(this._date));
        this.rangeDateChange();
    }
    /**
     * @return {?}
     */
    ok() {
        this.viewHide(false);
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    today() {
        let /** @type {?} */ newDate = new Date();
        if (!this.validateRange(newDate).success) {
            return;
        }
        this.viewHours = newDate.getHours().toString();
        this.viewMinutes = newDate.getMinutes().toString();
        this.selectDate({
            disabled: false,
            date: this.dateService.reduce(newDate, this.dateService.YYYYMMDD)
        });
    }
    /**
     * @return {?}
     */
    clear() {
        this.selectDate({
            disabled: false,
            date: null
        });
    }
    /**
     * @param {?} index
     * @return {?}
     */
    trackByIndex(index) {
        return index;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
YmdHmComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-ymd-hm',
                template: `<div class='datetime-picker' #datetimePicker
     (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_date? _date.toString() : null" (jyCustomValidatorControl)="customValidatorControl = $event"
     [jyName]="jyName" [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection">
  <input #input type='text' class='form-control' [ngModel]="_dateString" [disabled]="disabled"
         (focus)="focus()" (blur)="blur($event)" (keydown)="keydown($event)" (keyup)="keyup()">
  <div class="datetime-icon">
    <span class='icon-calendar input-icon' [jyHidden]="_date && (show || mouseEnter)"
          (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
    <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(_date && (show || mouseEnter))"
          (click)="clear()"></span>
  </div>
  <div class='fixed-box calendar-box' #box [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}">
    <div class="position-relative">
      <div class="select-box">
        <div class="select-left-button-box">
          <button class="btn btn-default" type="button" title="上一年" (click)="lastYear($event)" tabindex="-1">
            <span class="only-icon icon-double-angle-left"></span>
          </button>
          <button class="btn btn-default" type="button" title="上个月" (click)="lastMonth($event)"
                  tabindex="-1">
            <span class="only-icon icon-angle-left"></span>
          </button>
        </div>
        <div class="center">
          <select [jySelectData]="yearList" [(ngModel)]="viewYear" (change)="viewDateChange()" tabindex="-1"
                  (jyMousewhell)="yearMousewheel($event)">
          </select>
          <select [jySelectData]="monthList" [(ngModel)]="viewMonth" (change)="viewDateChange()" tabindex="-1"
                  (jyMousewhell)="monthMousewheel($event)">
          </select>
        </div>
        <div class="select-right-button-box">
          <button class="btn btn-default" type="button" title="下个月" (click)="nextMonth($event)"
                  tabindex="-1">
            <span class="only-icon icon-angle-right"></span>
          </button>
          <button class="btn btn-default" type="button" title="下一年" (click)="nextYear($event)" tabindex="-1">
            <span class="only-icon icon-double-angle-right"></span>
          </button>
        </div>
      </div>
    </div>
    <table class="calendar-table" cellspacing="0" (jyMousewhell)="monthMousewheel($event)">
      <tbody>
      <tr>
        <th>一</th>
        <th>二</th>
        <th>三</th>
        <th>四</th>
        <th>五</th>
        <th>六</th>
        <th>日</th>
      </tr>
      <tr *ngFor="let week of weekList;trackBy:trackByIndex" class="repeat-animation">
        <td *ngFor="let item of week;trackBy:trackByIndex"
            [ngClass]="{'not-current':!item.current,'today':item.today,'select':item.select,'disabled':item.disabled}"
            title="{{item.disabled ? '不可选择':''}}"
            (click)="selectDate(item)">
          {{item.day}}
        </td>
      </tr>
      </tbody>
    </table>
    <div class="hm-box">
      <select [jySelectData]="hoursList" [(ngModel)]="viewHours" tabindex="-1" (change)="viewTimeChange()"
              (jyMousewhell)="hoursMousewheel($event)">
      </select>
      :
      <select [jySelectData]="minutesList" [(ngModel)]="viewMinutes" tabindex="-1" (change)="viewTimeChange()"
              (jyMousewhell)="minutesMousewheel($event)">
      </select>
    </div>
    <div class="calendar-bottom-box">
      <button class="btn btn-default w33-100" type="button" (click)="ok()" tabindex="-1">
        <span class="icon-ok"></span>确定
      </button>
      <button class="btn btn-default w33-100" type="button" (click)="today()" tabindex="-1">
        <span class="icon-calendar"></span>今天
      </button>
      <button class="btn btn-default w33-100" type="button" (click)="clear()" tabindex="-1">
        <span class="icon-cancel-circle-solid"></span>清除
      </button>
    </div>
  </div>
</div>
`,
                styles: [`.datetime-picker{display:inline-block;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;position:relative}.datetime-picker .btn{height:inherit;padding:.21428571rem .42857143rem;margin-bottom:0;font-size:.5rem}.datetime-picker .form-control{padding-right:.89285714rem!important}.datetime-picker .datetime-icon .icon-cancel-circle-solid{cursor:pointer;color:#679eda}.datetime-picker .datetime-icon .icon-cancel-circle-solid:hover{color:#2b6bb0}.datetime-picker .calendar-table{width:inherit}.datetime-picker .calendar-table th{text-align:center;padding:.14285714rem .35714286rem;color:#679eda;border:none;font-size:.5rem;line-height:.71428571rem}.datetime-picker .calendar-table tr{height:auto;line-height:inherit}.datetime-picker .calendar-table tr:hover{background-color:inherit}.datetime-picker .calendar-table tr:nth-of-type(odd){background-color:#fff}.datetime-picker .calendar-table td{text-align:center;cursor:pointer;border:none;word-break:normal;font-size:.5rem;border-radius:.17857143rem;padding:.17857143rem 0;line-height:.71428571rem}.datetime-picker .calendar-table td:hover{background-color:#b9d2ee;color:#679eda}.datetime-picker .calendar-table .select{background-color:#b9d2ee!important;color:#679eda}.datetime-picker .calendar-table .today{background-color:#ffffae}.datetime-picker .calendar-table .disabled{background-color:#d6d6d6!important;color:#a5a5a5!important;border-radius:0!important;cursor:no-drop}.datetime-picker .calendar-table .not-current{color:#c9c9c9}.datetime-picker .select-box{line-height:1.17857143rem;font-size:.57142857rem}.datetime-picker .select-box .select-left-button-box{display:inline-block;position:absolute;left:.14285714rem;top:-.07142857rem}.datetime-picker .select-box .select-left-button-box button:nth-child(2){margin-left:-.14285714rem}.datetime-picker .select-box .select-right-button-box{display:inline-block;position:absolute;right:.14285714rem;top:-.07142857rem}.datetime-picker .select-box .select-right-button-box button:nth-child(1){margin-left:-.14285714rem}.datetime-picker .select-box select{text-align:center}.datetime-picker .select-box button{width:.89285714rem;padding:.21428571rem 0;position:relative}.datetime-picker .select-box .only-icon{font-size:.71428571rem}.datetime-picker .time-box{text-align:center;margin:.21428571rem 0;font-size:.57142857rem}.datetime-picker .time-select-box [class^=icon-]:hover{font-weight:700;font-size:1rem}.datetime-picker .calendar-bottom-box{display:-webkit-box;display:-ms-flexbox;display:flex;margin-top:.07142857rem}.datetime-picker button{border:none;outline:0}.datetime-picker select{border:none;outline:0;background-color:#fff;-webkit-transition:border-color ease-in-out .15s,-webkit-box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,-webkit-box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s;transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s,-webkit-box-shadow ease-in-out .15s}.datetime-picker select:hover{-webkit-box-shadow:inset 0 .03571429rem .03571429rem rgba(0,0,0,.075),0 0 .28571429rem #679eda;box-shadow:inset 0 .03571429rem .03571429rem rgba(0,0,0,.075),0 0 .28571429rem #679eda}`, `.form-control{width:5.89285714rem!important}.hm-box{text-align:center;font-size:.71428571rem;margin:.14285714rem 0}`],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
YmdHmComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: DateService, },
    { type: ToolsService, },
    { type: TooltipService, },
    { type: DatetimePickerService, },
];
YmdHmComponent.propDecorators = {
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "minDate": [{ type: Input },],
    "minDateString": [{ type: Input },],
    "maxDate": [{ type: Input },],
    "maxDateString": [{ type: Input },],
    "date": [{ type: Input },],
    "dateString": [{ type: Input },],
    "dateChange": [{ type: Output },],
    "dateStringChange": [{ type: Output },],
    "_datetimePicker": [{ type: ViewChild, args: ["datetimePicker",] },],
    "_box": [{ type: ViewChild, args: ["box",] },],
    "_input": [{ type: ViewChild, args: ["input",] },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 组件内部使用
 */
class SelectDataDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.jySelectDisabledKey = "disabled";
        this.jySelectValueKey = "value";
        this.jySelectLabelKey = "label";
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} _jySelectData
     * @return {?}
     */
    set jySelectData(_jySelectData) {
        let /** @type {?} */ oldValue = this.host.val();
        this._jySelectData = _jySelectData;
        let /** @type {?} */ html = "";
        if (this._jySelectData) {
            for (let /** @type {?} */ item of this._jySelectData) {
                if (item[this.jySelectDisabledKey]) {
                    html += `<optgroup class="select-disabled" label="` + item[this.jySelectLabelKey] + `"></optgroup>`;
                }
                else {
                    html += `<option value="` + item[this.jySelectValueKey] + `">` + item[this.jySelectLabelKey] + `</option>`;
                }
            }
        }
        this.host.html(html);
        this.host.val(oldValue);
    }
}
SelectDataDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jySelectData]"
            },] },
];
/** @nocollapse */
SelectDataDirective.ctorParameters = () => [
    { type: ElementRef, },
];
SelectDataDirective.propDecorators = {
    "jySelectDisabledKey": [{ type: Input },],
    "jySelectValueKey": [{ type: Input },],
    "jySelectLabelKey": [{ type: Input },],
    "jySelectData": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 验证器指令
 */
class CustomValidatorDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.jyCustomValidatorControl = new EventEmitter();
        this.host = $(this.elementRef.nativeElement);
        this.host.addClass(CUSTOM_VALIDATOR.replace(".", ""));
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyCustomValidator(value) {
        this._jyCustomValidator = value;
        this.host.attr(JY_CUSTOM_VALIDATOR_VALUE, this.toolsService.getString(value));
        this.host.trigger(CUSTOM_VALIDATOR_VALUE_CHANGE);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.jyCustomValidatorControl.emit({
            trigger: (value) => {
                this.jyCustomValidator = value;
            }
        });
    }
}
CustomValidatorDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyCustomValidator]"
            },] },
];
/** @nocollapse */
CustomValidatorDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
CustomValidatorDirective.propDecorators = {
    "jyCustomValidator": [{ type: Input },],
    "jyCustomValidatorControl": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 文件导入
 */
class FileImportComponent {
    /**
     * @param {?} elementRef
     * @param {?} fileUploadService
     * @param {?} alertService
     */
    constructor(elementRef, fileUploadService, alertService) {
        this.elementRef = elementRef;
        this.fileUploadService = fileUploadService;
        this.alertService = alertService;
        this.state = "none";
        this.iconClass = "icon-file";
        this.label = "导入文件";
        this.disabled = false;
        this._fileAccept = "";
        this.importFile = new EventEmitter();
        this.percent = 0;
        this.host = $(elementRef.nativeElement);
        this.host.css("display", "block");
    }
    /**
     * @param {?} fileAccept
     * @return {?}
     */
    set fileAccept(fileAccept) {
        this._fileAccept = fileAccept;
        this.iconClass = this.fileUploadService.getFileIcon(fileAccept);
    }
    /**
     * @return {?}
     */
    onchange() {
        if (this.state === "uploading" || this.disabled) {
            return;
        }
        let /** @type {?} */ fileList = (/** @type {?} */ (this.fileInput.get(0))).files;
        if (fileList == null || fileList.length === 0) {
            return;
        }
        this.fileUploadService.upload({
            file: fileList[0],
            init: (data) => {
                let /** @type {?} */ validate = false;
                for (let /** @type {?} */ accept of this._fileAccept.split(",")) {
                    if (accept.toLowerCase() === "." + data.postfix.toLowerCase()) {
                        validate = true;
                    }
                }
                if (!validate) {
                    this.alertService.open({
                        iconType: Icon.error,
                        content: "导入的文件格式错误！"
                    });
                    return;
                }
                this.state = "uploading";
                data.start();
            },
            success: (event, data) => {
                this.percent = 0;
                this.state = "executing";
                this.importFile.emit({
                    fileId: data.fileId,
                    end: () => {
                        this.state = "end";
                    }
                });
            },
            progress: (event, data) => {
                this.percent = data.percent;
            },
            error: (event, data) => {
                this.state = "none";
                this.percent = 0;
            }
        });
        this.fileInput.val("");
    }
    /**
     * @return {?}
     */
    selectFile() {
        if ((this.state !== "none" && this.state !== "end") || this.disabled) {
            return;
        }
        this.fileInput.click();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.fileInput = this.host.find("input");
    }
}
FileImportComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-file-import',
                template: `<button class="btn btn-primary" [disabled]="disabled && ( state === 'none' || state === 'end')"
        (click)="selectFile()">
  <span [jyHidden]="state !== 'none'">
    <span [jyClass]="iconClass"></span>
    <span class="file-label">{{label}}</span>
  </span>
  <span [jyHidden]="state !== 'uploading'">
    <span class="icon-spinner animation-icon-spin"></span>
    <span class="file-label">上传中({{percent}}%)</span>
  </span>
  <span [jyHidden]="state !== 'executing'">
    <span class="icon-spinner animation-icon-spin"></span>
    <span class="file-label">数据处理中</span>
  </span>
  <span [jyHidden]="state !== 'end'">
    导入成功
  </span>
</button>
<input class="hide" type="file" [jyAccept]="_fileAccept" (change)="onchange()"/>
`,
                styles: [`.btn-primary{width:4.64285714rem;text-align:center}.btn-primary .icon-file:before,.btn-primary .icon-spinner:before{margin-right:0}.btn-primary .file-label{margin-left:.10714286rem}`]
            },] },
];
/** @nocollapse */
FileImportComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: FileUploadService, },
    { type: AlertService, },
];
FileImportComponent.propDecorators = {
    "label": [{ type: Input },],
    "disabled": [{ type: Input },],
    "fileAccept": [{ type: Input },],
    "importFile": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 下拉框选择
 */
class EnumService {
    /**
     * @param {?} enumProvider
     * @return {?}
     */
    setProvider(enumProvider) {
        if (!enumProvider) {
            return;
        }
        this.enumProvider = enumProvider;
    }
    /**
     * @param {?} id
     * @return {?}
     */
    getEnumData(id) {
        return this.enumProvider.getEnumData(id);
    }
}
EnumService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EnumService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 下拉框
 */
class SelectComponent {
    /**
     * @param {?} elementRef
     * @param {?} enumService
     * @param {?} toolsService
     */
    constructor(elementRef, enumService, toolsService) {
        this.elementRef = elementRef;
        this.enumService = enumService;
        this.toolsService = toolsService;
        this.rem = rem;
        this.boxHeight = 189;
        this.lineHeight = 27;
        this.init = false;
        this.dataListDataMap = {};
        this.dataListLabelMap = {};
        this._lastData = null;
        this._data = null;
        this.label = "";
        this.showPlaceholder = "";
        this.placeholder = "请选择";
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.jyClass = "";
        this.dataChange = new EventEmitter();
        this.eventIdClass = ".select" + (Math.random() + "").replace(".", "");
        this.mouseEnter = false;
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        this.host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(this.host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
    }
    /**
     * @param {?} dataList
     * @return {?}
     */
    set dataList(dataList) {
        this._dataList = dataList ? dataList : [];
        this.filterDataList = this._dataList;
        this.dataListDataMap = {};
        this.dataListLabelMap = {};
        this._dataList.forEach(item => {
            this.dataListDataMap[item.data] = item;
            this.dataListLabelMap[item.label.trim()] = item;
        });
        let /** @type {?} */ data = this._data;
        this._data = null;
        this.data = data;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        if (this._data === data) {
            return;
        }
        if (!this.init) {
            this._data = data;
            return;
        }
        if (data && this.dataListDataMap[data]) {
            this.selectItem(this.dataListDataMap[data]);
            this.emitDataChange();
            return;
        }
        this.clear();
        this.emitDataChange();
    }
    /**
     * @return {?}
     */
    emitDataChange() {
        setTimeout(() => {
            if (this._lastData !== this._data) {
                this._lastData = this._data;
                this.dataChange.emit(this._data);
                this.customValidatorControl.trigger(this._data);
            }
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (event.keyCode === 13) {
            if (this.keySelectedItem) {
                this.selectedItem = this.keySelectedItem;
            }
            else if (this.label && this.filterDataList.length > 0) {
                this.selectedItem = this.filterDataList[0];
            }
            this.label = "";
            this.viewHide();
        }
        else if (this.filterDataList.length > 0 && (event.keyCode === 38 || event.keyCode === 40)) {
            let /** @type {?} */ index = this.filterDataList.indexOf(this.keySelectedItem) + (event.keyCode === 38 ? -1 : 1);
            if (index < 0) {
                index = this.filterDataList.length - 1;
            }
            else if (index >= this.filterDataList.length) {
                index = 0;
            }
            this.keySelectedItem = this.filterDataList[index];
            this.correctScrollBar();
        }
    }
    /**
     * @return {?}
     */
    keyInput() {
        this.keySelectedItem = null;
        clearTimeout(this.keyupTimer);
        this.keyupTimer = setTimeout(() => {
            let /** @type {?} */ value = this.input.val().trim().toLocaleLowerCase();
            if (!value) {
                this.filterDataList = this._dataList;
            }
            else {
                this.filterDataList = this._dataList.filter(item => {
                    return item.label.trim().toLocaleLowerCase().indexOf(value) > -1;
                });
            }
            setTimeout(() => {
                this.onWindowResize();
            });
        }, 50);
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.disabled || this.show) {
            return;
        }
        this.width = this.input.outerWidth();
        this.show = true;
        this.transparent = true;
        this.keySelectedItem = null;
        this.input.addClass("input-focus");
        this.filterDataList = this._dataList;
        this.showPlaceholder = this.label;
        this.label = "";
        setTimeout(() => {
            this.onWindowResize();
            this.transparent = false;
            this.correctScrollBar();
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.input, this.direction);
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.keySelectedItem = null;
        this.input.removeClass("input-focus");
        if (!this.label) {
            if (this.selectedItem) {
                this._data = this.selectedItem.data;
                this.label = this.selectedItem.label;
            }
            else {
                this.clear();
            }
        }
        else {
            let /** @type {?} */ selectedItem = this.dataListLabelMap[this.label.trim()];
            if (selectedItem) {
                this.selectedItem = selectedItem;
                this._data = selectedItem.data;
                this.label = selectedItem.label;
            }
            else {
                this.clear();
            }
        }
        this.emitDataChange();
        this.showPlaceholder = this.placeholder;
        this.input.blur();
        this.customValidatorControl.trigger(this._data);
    }
    /**
     * @param {?=} viewHide
     * @return {?}
     */
    clear(viewHide = false) {
        this.selectedItem = null;
        this._data = null;
        this.label = "";
        this.emitDataChange();
        if (viewHide) {
            this.viewHide();
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectItem(item) {
        this.mouseEnter = false;
        this.selectedItem = item;
        this._data = item.data;
        this.label = item.label.trim();
        this.viewHide();
    }
    /**
     * @return {?}
     */
    correctScrollBar() {
        let /** @type {?} */ selectedItem = this.keySelectedItem ? this.keySelectedItem : this.selectedItem;
        let /** @type {?} */ index = this.filterDataList.indexOf(selectedItem);
        if (!selectedItem || this.filterDataList.length === 0 || index < 0) {
            return;
        }
        this.toolsService.correctScrollBar(this.box, this.boxHeight, this.lineHeight, index);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.select = this.host.find(".select");
            this.input = this.host.find("input");
            this.box = this.host.find(".fixed-box");
            this.select.addClass(this.eventIdClass.replace(".", ""));
            if (this.dataListId) {
                this._dataList = this.enumService.getEnumData(this.dataListId);
            }
            this.filterDataList = this._dataList;
            this._dataList.forEach(item => {
                this.dataListDataMap[item.data] = item;
                this.dataListLabelMap[item.label.trim()] = item;
            });
            this.showPlaceholder = this.placeholder;
            this.init = true;
            if (this._data) {
                let /** @type {?} */ _data = this._data;
                this._data = null;
                this.data = _data;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-select',
                template: `<div class="select" [jyClass]="jyClass" (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_data" (jyCustomValidatorControl)="customValidatorControl = $event" [jyName]="jyName"
     [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection"
     [jyTitle]="selectedItem ? selectedItem.label : ''">
  <input type='text' class='form-control' [(ngModel)]="label" [disabled]="disabled" [placeholder]="showPlaceholder"
         (focus)="focus()" (blur)="blur($event)" (keydown)="keydown($event)" (input)="keyInput()">
  <span class='icon-caret-down input-icon' [jyHidden]="!disabled && _data && (show || mouseEnter)"
        (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
  <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(!disabled && _data && (show || mouseEnter))"
        (click)="clear(true)"></span>
  <div class='fixed-box' [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}"
       [ngStyle]="{'width.px':width}">
    <div class="select-item ellipsis" *ngFor="let item of filterDataList"
         [ngClass]="{'key-selected':keySelectedItem == item,selected:selectedItem === item}"
         (click)="selectItem(item)" [jyTitle]="item.label">
      {{item.label}}
    </div>
  </div>
</div>
`,
                styles: [`.select{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.select .input-icon{font-size:.57142857rem}.select .icon-cancel-circle-solid{cursor:pointer;color:#679eda}.select .icon-cancel-circle-solid:hover{color:#2b6bb0}.select .form-control{padding-right:1.14285714rem}.select .fixed-box{max-height:6.75rem;overflow-y:auto;padding:0}.select .select-item{cursor:pointer;padding:.17857143rem;-webkit-transition:background-color .2s;transition:background-color .2s}.select .select-item:hover{background-color:#e2edf8}.select .selected{font-weight:800;background-color:#e6e6e6!important}.select .key-selected{font-weight:inherit!important;background-color:#e2edf8!important}`],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
SelectComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: EnumService, },
    { type: ToolsService, },
];
SelectComponent.propDecorators = {
    "dataListId": [{ type: Input },],
    "dataList": [{ type: Input },],
    "data": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "jyClass": [{ type: Input },],
    "dataChange": [{ type: Output },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 验证器指令
 */
class TooltipDirectionDirective {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.host = $(this.elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyTooltipDirection(value) {
        this.host.attr(JY_TOOLTIP_DIRECTION, this.toolsService.getString(value));
    }
}
TooltipDirectionDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyTooltipDirection]"
            },] },
];
/** @nocollapse */
TooltipDirectionDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
TooltipDirectionDirective.propDecorators = {
    "jyTooltipDirection": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EnumPipe {
    /**
     * @param {?} enumService
     */
    constructor(enumService) {
        this.enumService = enumService;
    }
    /**
     * @param {?} value
     * @param {?=} args
     * @return {?}
     */
    transform(value, args) {
        if (value === null || isUndefined(value)) {
            return "";
        }
        let /** @type {?} */ enumData = this.enumService.getEnumData(args);
        if (!enumData) {
            return "";
        }
        enumData = enumData.filter(item => item.data === value);
        if (enumData.length === 0) {
            return "";
        }
        return enumData[0].label;
    }
}
EnumPipe.decorators = [
    { type: Pipe, args: [{
                name: 'jyEnum'
            },] },
];
/** @nocollapse */
EnumPipe.ctorParameters = () => [
    { type: EnumService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/7/19.
 */
/**
 * notification
 */
class NotificationComponent {
    constructor() {
        this.openList = [];
        this.closeSelf = Symbol();
        this.closeOther = Symbol();
        this.closeAll = Symbol();
        this.rightClickMenuItem = [{
                label: "关闭",
                data: this.closeSelf,
            }, {
                label: "关闭其他",
                data: this.closeOther,
            }, {
                label: "关闭所有",
                data: this.closeAll,
            }];
    }
    /**
     * @param {?} rightClickMenuItem
     * @param {?} notificationParams
     * @return {?}
     */
    onMenuClick(rightClickMenuItem, notificationParams) {
        if (rightClickMenuItem.data === this.closeSelf) {
            notificationParams.closeFlag = true;
        }
        else if (rightClickMenuItem.data === this.closeOther) {
            for (let /** @type {?} */ _notificationParams of this.openList) {
                if (_notificationParams !== notificationParams) {
                    _notificationParams.closeFlag = true;
                }
            }
        }
        else if (rightClickMenuItem.data === this.closeAll) {
            for (let /** @type {?} */ _notificationParams of this.openList) {
                _notificationParams.closeFlag = true;
            }
        }
    }
    /**
     * @param {?} notificationModalParams
     * @return {?}
     */
    setTransmitData(notificationModalParams) {
        notificationModalParams.init({
            add: (notificationParams) => {
                notificationParams.transmitData.close = () => {
                    notificationParams.closeFlag = true;
                };
                notificationParams.close = () => {
                    if (this.openList.indexOf(notificationParams) < 0) {
                        return;
                    }
                    this.openList.splice(this.openList.indexOf(notificationParams), 1);
                    if (notificationParams.closeHandler) {
                        notificationParams.closeHandler();
                    }
                };
                this.openList.push(notificationParams);
            }
        });
    }
    /**
     * @param {?} event
     * @param {?} notificationParams
     * @return {?}
     */
    closed(event, notificationParams) {
        if (event.toState === "hide" && event.totalTime > 0) {
            notificationParams.close();
        }
    }
    /**
     * @return {?}
     */
    close() {
    }
}
NotificationComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-notification',
                template: `<div class="notification">
  <div class="notification-box" *ngFor="let item of openList">
    <div class="notification-item" (click)="item['closeFlag'] = true" [@fadeShow]="item.closeFlag ? 'hide':'show'"
         [@slideInUp]="item.closeFlag ? 'up':'down'" (@fadeShow.done)="closed($event,item)"
         [jyRightClickMenu]="rightClickMenuItem" (onMenuClick)="onMenuClick($event,item)">
      <button type="button" class="notification-close" (click)="item['closeFlag'] = true" *ngIf="!item.hideClose">
        ×
      </button>
      <jy-dynamic-component [componentSelector]="item.selector"
                            [transmitData]="item.transmitData"></jy-dynamic-component>
    </div>
  </div>
</div>
`,
                styles: [`.notification{position:fixed;width:100%;top:.57142857rem;left:0;pointer-events:none}.notification .notification-box{text-align:right;width:100%;margin-top:.17857143rem;padding-right:.57142857rem}.notification .notification-box .notification-item{position:relative;padding:.57142857rem .64285714rem .28571429rem .28571429rem;border-radius:.14285714rem;-webkit-box-shadow:0 .07142857rem .28571429rem rgba(0,0,0,.2);box-shadow:0 .07142857rem .28571429rem rgba(0,0,0,.2);background:#fff;display:inline-block;pointer-events:all;cursor:pointer}.notification .notification-box .notification-item .notification-close{position:absolute;right:.17857143rem;top:.17857143rem;font-size:.75rem;font-weight:700;line-height:1;text-shadow:0 .03571429rem 0 #fff;opacity:.2;-webkit-appearance:none;padding:0;cursor:pointer;background:0 0;border:0;outline:0;margin-top:-.07142857rem}.notification .notification-box .notification-item .notification-close:focus,.notification .notification-box .notification-item .notification-close:hover{color:#000;text-decoration:none;cursor:pointer;opacity:.5}`],
                animations: [fadeShow, slideInUp]
            },] },
];
/** @nocollapse */
NotificationComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NotificationSimpleComponent {
    constructor() {
        this.endFlag = false;
    }
    /**
     * @param {?} transmitData
     * @return {?}
     */
    setTransmitData(transmitData) {
        this.transmitData = transmitData;
        let { okLabel = "知道了", yesLabel = "确定", noLabel = "取消", } = transmitData;
        transmitData.okLabel = okLabel;
        transmitData.yesLabel = yesLabel;
        transmitData.noLabel = noLabel;
    }
    /**
     * @return {?}
     */
    okClick() {
        if (this.endFlag) {
            return;
        }
        if (this.transmitData.okClick) {
            this.transmitData.okClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    yesClick() {
        if (this.endFlag) {
            return;
        }
        if (this.transmitData.yesClick) {
            this.transmitData.yesClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    noClick() {
        if (this.endFlag) {
            return;
        }
        if (this.transmitData.noClick) {
            this.transmitData.noClick();
        }
        this.close();
    }
    /**
     * @return {?}
     */
    close() {
        this.endFlag = true;
        this.transmitData.close();
    }
}
NotificationSimpleComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-notification-simple',
                styles: [`.notification-simple{max-width:10.71428571rem}.notification-simple .notification-head{text-align:left;display:-webkit-box;display:-ms-flexbox;display:flex}.notification-simple .notification-head .notification-title{font-size:.57142857rem;padding-left:.35714286rem;margin-top:.25rem;font-weight:bolder;float:left}.notification-simple .notification-head [class*=" icon-"],.notification-simple .notification-head [class^=icon-]{font-size:.92857143rem;float:left}.notification-simple .notification-head .icon-ok-circle-solid{color:#1ec434}.notification-simple .notification-head .icon-info-circle-solid{color:#00b6f3}.notification-simple .notification-head .icon-question-circle-solid{color:#ffb201}.notification-simple .notification-head .icon-cancel-circle-solid{color:#ff5e5e}.notification-simple .notification-head .icon-warning-circle-solid{color:#ff8e35}.notification-simple .notification-content{text-align:left;padding:0 .35714286rem .35714286rem 1.17857143rem}.notification-simple .notification-content-no-icon{text-align:left;padding:0 .35714286rem .35714286rem}.notification-simple .notification-button-group{text-align:right}`],
                template: `<div class="notification-simple">
  <div class="notification-head" *ngIf="transmitData.iconType || transmitData.title">
    <span *ngIf="transmitData.iconType" [ngClass]="{
          'icon-ok-circle-solid': transmitData.iconType === 'success',
          'icon-cancel-circle-solid': transmitData.iconType === 'error',
          'icon-warning-circle-solid': transmitData.iconType === 'warning',
          'icon-info-circle-solid': transmitData.iconType === 'info',
          'icon-question-circle-solid': transmitData.iconType === 'question'
      }"></span>
    <span *ngIf="transmitData.title"
          class="notification-title">{{transmitData.title}}</span>
  </div>
  <div
    [ngClass]="{'notification-content':transmitData.iconType,'notification-content-no-icon':!transmitData.iconType}">
    {{transmitData.content}}
  </div>
  <div *ngIf="transmitData.okClick || transmitData.yesClick || transmitData.noClick" class="notification-button-group">
    <div *ngIf="transmitData.okClick">
      <button class="btn btn-primary" (click)="okClick()">
        {{transmitData.okLabel}}
      </button>
    </div>
    <div *ngIf="transmitData.yesClick || transmitData.noClick">
      <button class="btn btn-default" (click)="noClick()">
        {{transmitData.noLabel}}
      </button>
      <button class="btn btn-primary" (click)="yesClick()">
        {{transmitData.yesLabel}}
      </button>
    </div>
  </div>
</div>
`
            },] },
];
/** @nocollapse */
NotificationSimpleComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/6/28.
 */
/**
 * notification提示框
 */
class NotificationService {
    /**
     * @param {?} modalService
     */
    constructor(modalService) {
        this.modalService = modalService;
    }
    /**
     * @param {?} notificationParams
     * @return {?}
     */
    openCustom(notificationParams) {
        this.notificationControl.add(notificationParams);
    }
    /**
     * @param {?} notificationSimpleParams
     * @param {?=} notificationParams
     * @return {?}
     */
    openSimple(notificationSimpleParams, notificationParams = null) {
        if (!notificationParams) {
            notificationParams = {
                transmitData: notificationSimpleParams,
                selector: NotificationSimpleComponent,
            };
        }
        else {
            notificationParams.transmitData = notificationSimpleParams;
            notificationParams.selector = NotificationSimpleComponent;
        }
        this.openCustom(notificationParams);
    }
    /**
     * @return {?}
     */
    init() {
        let /** @type {?} */ notificationModalParams = {
            modalTop: true,
            init: (notificationControl) => {
                this.notificationControl = notificationControl;
            }
        };
        this.modalService.open(notificationModalParams, NotificationComponent);
    }
}
NotificationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
NotificationService.ctorParameters = () => [
    { type: ModalService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/8/30 0030.
 */
/**
 * 缓存
 */
class RippleService {
    /**
     * @param {?} rippleProvider
     * @return {?}
     */
    setProvider(rippleProvider) {
        if (!rippleProvider) {
            return;
        }
        this.rippleProvider = rippleProvider;
    }
    /**
     * @return {?}
     */
    init() {
        let /** @type {?} */ body = $(document.body);
        body.click((event) => {
            if (!this.rippleProvider) {
                return;
            }
            let /** @type {?} */ target = $(event.target);
            let /** @type {?} */ rippleTarget = this.rippleProvider.getRippleTarget(target);
            if (!rippleTarget || rippleTarget.hasClass("dont-ripple")) {
                return;
            }
            setTimeout(() => {
                let /** @type {?} */ ripple = $(`<div class="ripple"></div>`);
                let /** @type {?} */ borderColor = rippleTarget.css("border-color");
                if (rippleTarget.css("border-style") === "none") {
                    borderColor = rippleTarget.css("background-color");
                }
                ripple.css({
                    "right": "0",
                    "bottom": "0",
                    "left": "0",
                    "top": "0",
                    "border-color": borderColor,
                    "border-radius": rippleTarget.css("border-radius")
                });
                this.rippleProvider.prepareRipple(rippleTarget, ripple);
                borderColor = ripple.css("border-color");
                if (borderColor.indexOf("rgba") > -1) {
                    let /** @type {?} */ rgba = borderColor.substring(borderColor.indexOf("(") + 1, borderColor.indexOf(")")).split(",");
                    if (parseInt(rgba[3]) === 0) {
                        return;
                    }
                }
                let /** @type {?} */ ripple1 = ripple.clone();
                ripple1.addClass("ripple1");
                let /** @type {?} */ ripple2 = ripple.clone();
                ripple2.addClass("ripple2");
                let /** @type {?} */ ripple3 = ripple.clone();
                ripple3.addClass("ripple3");
                let /** @type {?} */ oldPosition = rippleTarget.css("position");
                if (oldPosition !== "absolute" && oldPosition !== "fixed") {
                    rippleTarget.css("position", "relative");
                }
                setTimeout(() => {
                    if (ripple1.parent().length === 0) {
                        return;
                    }
                    ripple1.remove();
                    ripple2.remove();
                    ripple3.remove();
                    if (oldPosition === "static") {
                        rippleTarget.css("position", "");
                    }
                    else {
                        rippleTarget.css("position", oldPosition);
                    }
                }, 500);
                rippleTarget.find(".ripple").remove();
                rippleTarget.append(ripple1).append(ripple2).append(ripple3);
            });
        });
    }
}
RippleService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
RippleService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/6/28.
 */
/**
 * ProvinceCityArea
 */
class ProvinceCityAreaService {
    constructor() {
        this.codeParentListMap = {};
        this.codeMap = {};
        this.nameMap = {};
        this.allCity = [];
        this.allArea = [];
    }
    /**
     * @param {?} provinceCityAreaProvider
     * @return {?}
     */
    setProvider(provinceCityAreaProvider) {
        if (!provinceCityAreaProvider) {
            return;
        }
        this.provinceCityAreaProvider = provinceCityAreaProvider;
        this.getAllCodeAndName(this.provinceCityAreaProvider.getProvinceCityAreaData(), null, 1);
    }
    /**
     * @param {?} provinceCityAreaList
     * @param {?} parent
     * @param {?} index
     * @return {?}
     */
    getAllCodeAndName(provinceCityAreaList, parent, index) {
        if (!provinceCityAreaList || provinceCityAreaList.length === 0) {
            return;
        }
        for (let /** @type {?} */ provinceCityArea of provinceCityAreaList) {
            provinceCityArea.parent = parent;
            this.codeMap[provinceCityArea.code] = provinceCityArea;
            this.nameMap[provinceCityArea.name] = provinceCityArea;
            this.codeParentListMap[provinceCityArea.code] = provinceCityAreaList;
            this.getAllCodeAndName(provinceCityArea.children, provinceCityArea, index + 1);
            if (index === 2) {
                this.allCity.push(provinceCityArea);
            }
            else if (index === 3) {
                this.allArea.push(provinceCityArea);
            }
        }
    }
    /**
     * @param {?} code
     * @return {?}
     */
    getNameByCode(code) {
        return this.codeMap[code] ? this.codeMap[code].name : "";
    }
    /**
     * @param {?} name
     * @return {?}
     */
    getCodeByName(name) {
        return this.nameMap[name] ? this.nameMap[name].code : "";
    }
    /**
     * @param {?} code
     * @return {?}
     */
    getChildrenByCode(code) {
        return this.codeMap[code] ? this.codeMap[code].children : [];
    }
    /**
     * @param {?} code
     * @return {?}
     */
    getParentListByCode(code) {
        return this.codeParentListMap[code] ? this.codeParentListMap[code] : [];
    }
    /**
     * @return {?}
     */
    getProvinceCityAreaData() {
        return this.provinceCityAreaProvider.getProvinceCityAreaData();
    }
    /**
     * @return {?}
     */
    getAllCity() {
        return this.allCity;
    }
    /**
     * @return {?}
     */
    getAllArea() {
        return this.allArea;
    }
    /**
     * @return {?}
     */
    getAllProvinceToDataAndLabel() {
        return this.getProvinceCityAreaData().map(value => {
            return {
                data: value.code,
                label: value.name
            };
        });
    }
}
ProvinceCityAreaService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ProvinceCityAreaService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 初始化
 */
class InitService {
    /**
     * @param {?} toastService
     * @param {?} notificationService
     * @param {?} rippleService
     * @param {?} remService
     * @param {?} httpService
     * @param {?} modalService
     * @param {?} dynamicComponentService
     * @param {?} fileUploadService
     * @param {?} enumService
     * @param {?} globalEventsService
     * @param {?} rightClickMenuService
     * @param {?} tableBoxService
     * @param {?} provinceCityAreaService
     */
    constructor(toastService, notificationService, rippleService, remService, httpService, modalService, dynamicComponentService, fileUploadService, enumService, globalEventsService, rightClickMenuService, tableBoxService, provinceCityAreaService) {
        this.toastService = toastService;
        this.notificationService = notificationService;
        this.rippleService = rippleService;
        this.remService = remService;
        this.httpService = httpService;
        this.modalService = modalService;
        this.dynamicComponentService = dynamicComponentService;
        this.fileUploadService = fileUploadService;
        this.enumService = enumService;
        this.globalEventsService = globalEventsService;
        this.rightClickMenuService = rightClickMenuService;
        this.tableBoxService = tableBoxService;
        this.provinceCityAreaService = provinceCityAreaService;
    }
    /**
     * @param {?} coreProvider
     * @return {?}
     */
    init(coreProvider) {
        this.httpService.setProvider(coreProvider.httpProvider);
        this.modalService.setProvider(coreProvider.modalProvider);
        this.dynamicComponentService.setProvider(coreProvider.dynamicComponentFactoryProvider);
        this.fileUploadService.setProvider(coreProvider.fileUploadProvider);
        this.enumService.setProvider(coreProvider.enumProvider);
        this.globalEventsService.setProvider(coreProvider.globalEventsProvider);
        this.rightClickMenuService.setProvider(coreProvider.rightClickMenuProvider);
        this.rippleService.setProvider(coreProvider.rippleProvider);
        this.tableBoxService.setProvider(coreProvider.tableBoxProvider);
        this.provinceCityAreaService.setProvider(coreProvider.provinceCityAreaProvider);
        this.remService.setProvider(coreProvider.remProvider);
        this.toastService.init();
        this.notificationService.init();
        this.rippleService.init();
        this.remService.init();
    }
}
InitService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
InitService.ctorParameters = () => [
    { type: ToastService, },
    { type: NotificationService, },
    { type: RippleService, },
    { type: RemService, },
    { type: HttpService, },
    { type: ModalService, },
    { type: DynamicComponentService, },
    { type: FileUploadService, },
    { type: EnumService, },
    { type: GlobalEventsService, },
    { type: RightClickMenuService, },
    { type: TableBoxService, },
    { type: ProvinceCityAreaService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 附件上传
 */
class AttachmentComponent {
    /**
     * @param {?} elementRef
     * @param {?} fileUploadService
     * @param {?} alertService
     */
    constructor(elementRef, fileUploadService, alertService) {
        this.elementRef = elementRef;
        this.fileUploadService = fileUploadService;
        this.alertService = alertService;
        this.jyName = "";
        this.jyRequiredMessage = "请上传附件";
        this.jyRequired = false;
        this.jyValidate = true;
        this._fileAccept = "";
        this.disabled = false;
        this.showDelete = true;
        this._fileId = "";
        this.fileSize = "";
        this.fileIdChange = new EventEmitter();
        this.state = "none";
        this.iconClass = "";
        this.fileInfo = null;
        this.formatSize = "";
        this.percent = 0;
        this.loaded = "";
        this.currentSpeed = "";
        this.host = $(elementRef.nativeElement);
        this.host.css("display", "block");
        this.iconClass = this.fileUploadService.getFileIcon("");
    }
    /**
     * @param {?} fileAccept
     * @return {?}
     */
    set fileAccept(fileAccept) {
        this._fileAccept = fileAccept;
        if (!this.fileInfo) {
            this.iconClass = this.fileUploadService.getFileIcon(fileAccept);
        }
    }
    /**
     * @return {?}
     */
    get fileId() {
        return this._fileId;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set fileId(value) {
        if (this._fileId === value) {
            return;
        }
        this._fileId = value;
        if (this._fileId) {
            this.state = "loading";
            this.fileUploadService.getFileInfo(this._fileId, (fileInfo) => {
                if (this._fileId === fileInfo.fileId) {
                    this.fileInfo = fileInfo;
                    this.state = "none";
                    this.iconClass = this.fileUploadService.getFileIcon(fileInfo.fileExtName);
                    this.fileSize = this.fileUploadService.formatFileSize(fileInfo.fileLength);
                }
            });
        }
        else {
            this.fileInfo = null;
            this.fileSize = "";
            this.iconClass = this.fileUploadService.getFileIcon("");
        }
        setTimeout(() => {
            this.fileIdChange.emit(this._fileId);
        });
    }
    /**
     * @return {?}
     */
    onchange() {
        if (this.state !== "none" || this.disabled) {
            return;
        }
        let /** @type {?} */ fileList = (/** @type {?} */ (this.fileInput.get(0))).files;
        if (fileList == null || fileList.length === 0) {
            return;
        }
        this.fileUploadService.upload({
            file: fileList[0],
            init: (data) => {
                if (this._fileAccept) {
                    let /** @type {?} */ validate = false;
                    for (let /** @type {?} */ accept of this._fileAccept.split(",")) {
                        if (accept.toLowerCase() === "." + data.postfix.toLowerCase()) {
                            validate = true;
                        }
                    }
                    if (!validate) {
                        this.alertService.open({
                            iconType: Icon.warning,
                            content: "上传的文件格式不正确（" + this._fileAccept + "）"
                        });
                        return;
                    }
                }
                this.state = "uploading";
                this.formatSize = data.formatSize;
                this.iconClass = this.fileUploadService.getFileIcon(data.postfix);
                data.start();
            },
            success: (event, data) => {
                this.fileId = data.fileId;
                this.formatSize = "";
                this.percent = 0;
                this.loaded = "";
                this.currentSpeed = "";
            },
            progress: (event, data) => {
                this.percent = data.percent;
                this.currentSpeed = data.currentSpeed;
                this.loaded = data.loaded;
            },
            error: (event) => {
                this.state = "none";
                this.formatSize = "";
                this.percent = 0;
                this.loaded = "";
                this.currentSpeed = "";
                this.fileId = "";
            }
        });
        this.fileInput.val("");
    }
    /**
     * @return {?}
     */
    selectFile() {
        if (this.state !== "none" || this.disabled) {
            return;
        }
        this.fileInput.click();
    }
    /**
     * @return {?}
     */
    download() {
        if (this._fileId) {
            window.location.href = this.fileUploadService.getFileUrl(this._fileId);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.fileInput = this.host.find("input");
    }
}
AttachmentComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-attachment',
                template: `<div class="attachment" [jyCustomValidator]="_fileId" [jyName]="jyName"
     [jyValidate]="jyValidate" [jyRequired]="jyRequired" [jyRequiredMessage]="jyRequiredMessage">
  <i class="attachment-icon" [jyClass]="iconClass" [ngClass]="{'no-select':state === 'none' && !_fileId}"></i>
  <div class="attachment-body">
    <div class="file-info" [@fadeOnlyShow]="state === 'none' ? 'show':'hide'">
      <div class="file-name">
        <span *ngIf="fileInfo" [jyTitle]="fileInfo.fileName+'('+fileSize+')'">{{fileInfo.fileName}}({{fileSize}})</span>
        <span *ngIf="!fileInfo" class="none">暂无文件</span>
      </div>
      <div class="button-box">
        <div class="button-i" [jyHidden]="disabled" (click)="selectFile()">
          <i class="icon-upload"></i>上传
        </div>
        <div class="button-i" (click)="download()" [jyHidden]="!_fileId">
          <i class="icon-download"></i>下载
        </div>
        <div class="button-i" (click)="fileId = ''" [jyHidden]="disabled || !showDelete || !_fileId">
          <i class="icon-cancel"></i>删除
        </div>
      </div>
    </div>
    <div class="file-info-loading" [@fadeOnlyShow]="state === 'loading' ? 'show':'hide'">
      <span class="icon-spinner animation-icon-spin"></span>
    </div>
    <div class="progress-box" [@fadeOnlyShow]="state === 'uploading' ? 'show':'hide'">
      <div class="progress-text">
        <span class="left">
          {{currentSpeed}}
        </span>
        {{loaded + "/" + formatSize}}
      </div>
      <div class="progress">
        <div class="progress-bar progress-bar-info progress-bar-striped active" role="progressbar"
             [ngStyle]="{width: percent + '%'}">
        </div>
      </div>
    </div>
  </div>
  <input class="hide" type="file" [jyAccept]="_fileAccept" (change)="onchange()"/>
</div>
`,
                styles: [`.attachment{border:.03571429rem solid #ccc;border-radius:.14285714rem;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:9.28571429rem;height:1.78571429rem}.attachment .attachment-icon{font-size:1.21428571rem;margin-left:.35714286rem}.attachment .attachment-icon.no-select{color:#ccc!important}.attachment .attachment-body{position:absolute;right:0;top:0;width:7.5rem;height:1.71428571rem}.attachment .attachment-body .file-info .file-name{padding:.10714286rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.attachment .attachment-body .file-info .button-box{margin-top:.07142857rem;text-align:center}.attachment .attachment-body .file-info .button-box .button-i{display:inline-block;margin:0 .35714286rem;cursor:pointer;color:#679eda}.attachment .attachment-body .file-info .button-box .button-i:hover{color:#2b6bb0}.attachment .attachment-body .file-info-loading{opacity:1;height:1.71428571rem;font-size:1.07142857rem;text-align:center;color:gray}.attachment .attachment-body .progress-box{opacity:1;height:1.71428571rem;padding:.21428571rem}.attachment .attachment-body .progress-box .progress-text{width:100%;text-align:right}.attachment .icon-file,.attachment .icon-file-text{color:#656565}.attachment .icon-file-pdf{color:#da0102}.attachment .icon-file-word{color:#2a5699}.attachment .icon-file-excel{color:#1f7246}.attachment .icon-file-ppt{color:#d04626}.attachment .icon-file-image{color:#609ae2}.attachment .icon-file-zip{color:#a14079}.attachment .icon-file-sound{color:#329edf}.attachment .icon-file-video{color:#3fa0a1}.attachment .progress{margin-bottom:0;height:.53571429rem}`],
                animations: [fadeShow, fadeOnlyShow]
            },] },
];
/** @nocollapse */
AttachmentComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: FileUploadService, },
    { type: AlertService, },
];
AttachmentComponent.propDecorators = {
    "jyName": [{ type: Input },],
    "jyRequiredMessage": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "fileAccept": [{ type: Input },],
    "disabled": [{ type: Input },],
    "showDelete": [{ type: Input },],
    "fileId": [{ type: Input },],
    "fileIdChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 组件内部使用
 */
class CheckboxService {
    constructor() {
        this.group = {};
    }
    /**
     * @param {?} checkboxComponent
     * @return {?}
     */
    register(checkboxComponent) {
        let /** @type {?} */ checkboxGroup = this.group[checkboxComponent.groupId];
        if (!checkboxGroup) {
            checkboxGroup = [];
            this.group[checkboxComponent.groupId] = checkboxGroup;
        }
        checkboxGroup.push(checkboxComponent);
        checkboxComponent.onChange(() => {
            if (checkboxComponent.isParent) {
                let /** @type {?} */ checkboxState = checkboxComponent.checked ? "checked" : "unchecked";
                checkboxGroup.forEach(item => item.silenceSetState(checkboxState));
            }
            else {
                let /** @type {?} */ parentCheckbox = null;
                let /** @type {?} */ noOneSelected = true;
                let /** @type {?} */ hasUnselected = false;
                checkboxGroup.forEach(item => {
                    if (item.isParent) {
                        parentCheckbox = item;
                    }
                    else {
                        if (item.checked) {
                            noOneSelected = false;
                        }
                        else {
                            hasUnselected = true;
                        }
                    }
                });
                if (!parentCheckbox) {
                    throw new Error("CheckboxGroupId no parent:" + checkboxComponent.groupId);
                }
                if (noOneSelected) {
                    parentCheckbox.silenceSetState("unchecked");
                }
                else if (!noOneSelected && hasUnselected) {
                    parentCheckbox.silenceSetState("indeterminate");
                }
                else if (!noOneSelected && !hasUnselected) {
                    parentCheckbox.silenceSetState("checked");
                }
            }
        });
    }
    /**
     * @param {?} checkboxComponent
     * @return {?}
     */
    destroy(checkboxComponent) {
        let /** @type {?} */ checkboxGroup = this.group[checkboxComponent.groupId];
        if (!checkboxGroup) {
            return;
        }
        checkboxGroup.splice(checkboxGroup.indexOf(checkboxComponent), 1);
        if (checkboxGroup.length === 0) {
            delete this.group[checkboxComponent.groupId];
        }
    }
}
CheckboxService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
CheckboxService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 复选框
 */
class CheckboxComponent {
    /**
     * @param {?} checkboxService
     */
    constructor(checkboxService) {
        this.checkboxService = checkboxService;
        this.disabled = false;
        this.isParent = false;
        this._state = "unchecked";
        this._checked = false;
        this.stateChange = new EventEmitter();
        this.checkedChange = new EventEmitter();
        this.lastState = "unchecked";
        this.lastChecked = false;
    }
    /**
     * @param {?} state
     * @return {?}
     */
    set state(state$$1) {
        if (state$$1 === null || isUndefined(state$$1)) {
            return;
        }
        this._state = state$$1;
        this._checked = this._state === "checked";
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    get state() {
        return this._state;
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    set checked(checked) {
        if (checked === null || isUndefined(checked)) {
            return;
        }
        this._checked = checked;
        this._state = this._checked ? "checked" : (this._state === "indeterminate" ? "indeterminate" : "unchecked");
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    get checked() {
        return this._checked;
    }
    /**
     * @param {?=} silence
     * @return {?}
     */
    emitDateChange(silence = false) {
        setTimeout(() => {
            if (this.lastState !== this._state) {
                this.stateChange.emit(this._state);
                this.lastState = this._state;
            }
            if (this.lastChecked !== this._checked) {
                this.checkedChange.emit(this._checked);
                this.lastChecked = this._checked;
            }
            if (this.callback && !this.isParent && !silence) {
                this.callback();
            }
        });
    }
    /**
     * @return {?}
     */
    click() {
        if (this.disabled) {
            return;
        }
        this.checked = !this._checked;
        if (this.callback && this.isParent) {
            this.callback();
        }
    }
    /**
     * @param {?} state
     * @return {?}
     */
    silenceSetState(state$$1) {
        this._state = state$$1;
        this._checked = this._state === "checked";
        this.emitDateChange(true);
    }
    /**
     * @param {?} callback
     * @return {?}
     */
    onChange(callback) {
        this.callback = callback;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (!this.groupId) {
            return;
        }
        this.checkboxService.register(this);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (!this.groupId) {
            return;
        }
        this._checked = false;
        if (this.callback) {
            try {
                this.callback();
            }
            catch (/** @type {?} */ e) {
            }
        }
        this.callback = null;
        this.checkboxService.destroy(this);
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-checkbox',
                template: `<label class="checkbox-box" (click)="click()" [ngClass]="{'checkbox-disabled': disabled}">
  <span class="checkbox"
        [ngClass]="{'checkbox-checked': _state === 'checked','checkbox-indeterminate': _state === 'indeterminate','dont-ripple': disabled}">
    <span class="checkbox-inner"></span>
  </span>
  <span *ngIf="label">{{label}}</span>
</label>
`,
                styles: [`.checkbox-box{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;font-size:.42857143rem;display:inline-block}.checkbox-box .checkbox{white-space:nowrap;outline:0;display:inline-block;line-height:1;position:relative;vertical-align:text-bottom}.checkbox-box .checkbox .checkbox-inner{position:relative;top:0;left:0;display:block;width:.5rem;height:.5rem;border:.03571429rem solid #ccc;border-radius:.07142857rem;background-color:#fff;-webkit-transition:all .3s;transition:all .3s}.checkbox-box .checkbox-checked .checkbox-inner,.checkbox-box .checkbox-indeterminate .checkbox-inner{background-color:#679eda;border-color:#679eda}.checkbox-box .checkbox-checked .checkbox-inner:after,.checkbox-box .checkbox-indeterminate .checkbox-inner:after{position:absolute;content:" ";border:.07142857rem solid #fff;border-top:0;border-left:0;display:table}.checkbox-box .checkbox-indeterminate .checkbox-inner:after{left:.03571429rem;top:.17857143rem;width:.28571429rem;height:0;-webkit-transition:all .2s cubic-bezier(.71,-.46,.88,.6);transition:all .2s cubic-bezier(.71,-.46,.88,.6)}.checkbox-box .checkbox-checked .checkbox-inner:after{-webkit-transform:rotate(45deg);transform:rotate(45deg);left:.10714286rem;top:-.03571429rem;width:.17857143rem;height:.28571429rem;-webkit-transition:all .2s cubic-bezier(.12,.4,.29,1.46);transition:all .2s cubic-bezier(.12,.4,.29,1.46)}.checkbox+span,.checkbox-box+span{padding:0 .10714286rem}.checkbox-disabled{cursor:not-allowed;opacity:.65}`]
            },] },
];
/** @nocollapse */
CheckboxComponent.ctorParameters = () => [
    { type: CheckboxService, },
];
CheckboxComponent.propDecorators = {
    "disabled": [{ type: Input },],
    "isParent": [{ type: Input },],
    "groupId": [{ type: Input },],
    "label": [{ type: Input },],
    "state": [{ type: Input },],
    "checked": [{ type: Input },],
    "stateChange": [{ type: Output },],
    "checkedChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 单选框
 */
class RadioComponent {
    constructor() {
        this.disabled = false;
        this.dataChange = new EventEmitter();
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        this._data = data;
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    get data() {
        return this._data;
    }
    /**
     * @return {?}
     */
    emitDateChange() {
        setTimeout(() => {
            if (this._lastData !== this._data) {
                this.dataChange.emit(this._data);
                this._lastData = this._data;
            }
        });
    }
    /**
     * @return {?}
     */
    click() {
        if (this.disabled) {
            return;
        }
        this.data = this.value;
    }
}
RadioComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-radio',
                template: `<label class="radio-box" (click)="click()" [ngClass]="{'radio-disabled': disabled}">
  <span class="radio" [ngClass]="{'radio-checked':data === value,'dont-ripple': disabled}">
    <span class="radio-inner"></span>
  </span>
  <span *ngIf="label">{{label}}</span>
</label>
`,
                styles: [`.radio-box{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;font-size:.42857143rem;display:inline-block}.radio-box .radio{outline:0;line-height:1;vertical-align:text-bottom;position:relative;white-space:nowrap;display:inline-block}.radio-box .radio .radio-inner{position:relative;top:0;left:0;display:inline-block;width:.5rem;height:.5rem;border-radius:.5rem;border:.03571429rem solid #ccc;background-color:#fff;-webkit-transition:all .3s;transition:all .3s}.radio-box .radio .radio-inner:after{position:absolute;width:.21428571rem;height:.21428571rem;left:.10714286rem;top:.10714286rem;border-radius:.14285714rem;display:table;border-top:0;border-left:0;content:" ";background-color:#679eda;opacity:0;-webkit-transform:scale(0);transform:scale(0);-webkit-transition:all .3s cubic-bezier(.78,.14,.15,.86);transition:all .3s cubic-bezier(.78,.14,.15,.86)}.radio-box .radio-checked .radio-inner{border-color:#679eda}.radio-box .radio-checked .radio-inner:after{-webkit-transform:scale(1);transform:scale(1);opacity:1;-webkit-transition:all .3s cubic-bezier(.78,.14,.15,.86);transition:all .3s cubic-bezier(.78,.14,.15,.86)}.radio+span,.radio-box+span{padding:0 .10714286rem}.radio-disabled{cursor:not-allowed;opacity:.65}`]
            },] },
];
/** @nocollapse */
RadioComponent.ctorParameters = () => [];
RadioComponent.propDecorators = {
    "disabled": [{ type: Input },],
    "label": [{ type: Input },],
    "value": [{ type: Input },],
    "data": [{ type: Input },],
    "dataChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * less对应的变量值 需要的就加
 */
class LessService {
    constructor() {
        this.initCallbackList = [];
    }
    /**
     * @param {?} lessAttributeMap
     * @return {?}
     */
    init(lessAttributeMap) {
        this.lessAttributeMap = lessAttributeMap;
        this.initCallbackList.forEach(item => item());
    }
    /**
     * @param {?} lessAttribute
     * @return {?}
     */
    get(lessAttribute) {
        if (!this.lessAttributeMap) {
            return "";
        }
        return this.lessAttributeMap[lessAttribute];
    }
    /**
     * @param {?} lessAttribute
     * @param {?} callback
     * @return {?}
     */
    asyncGet(lessAttribute, callback) {
        if (this.lessAttributeMap) {
            callback(this.lessAttributeMap[lessAttribute]);
        }
        else {
            this.initCallbackList.push(() => {
                callback(this.lessAttributeMap[lessAttribute]);
            });
        }
    }
}
LessService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
LessService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LessAttribute {
}
LessAttribute.COLOR_PRIMARY = "color-primary";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * less的变量 需要的往里面加
 */
class LessComponent {
    /**
     * @param {?} elementRef
     * @param {?} lessService
     */
    constructor(elementRef, lessService) {
        this.elementRef = elementRef;
        this.lessService = lessService;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        let /** @type {?} */ lessAttributeMap = {};
        lessAttributeMap[LessAttribute.COLOR_PRIMARY] = this.host.find(".color-primary").css("color");
        this.lessService.init(lessAttributeMap);
    }
}
LessComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-less',
                template: `<div class="less-box">
  <span class="color-primary"></span>
</div>
`,
                styles: [`.less-box{display:none}.less-box .color-primary{color:#679eda}`]
            },] },
];
/** @nocollapse */
LessComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: LessService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Created by ouyangjingzhou@jianyi.tech on 2017/1/1.
 */
/**
 * 查询
 * 使用缓存和延迟查询 提高效率和用户体验
 */
class SearchService {
    constructor() {
        this.timer = {};
        this.lastData = {};
        this.cacheData = {};
    }
    /**
     * 查询发起后判断当前的key是不是已经有查询过 假设123查出来10条数据  那么1234肯定不会更多 这时候将使用缓存进行本地过滤 不发请求
     * 如果本地没有匹配的数据则发请求获得数据 直接返回 此时不再进行本地过滤 后端应与前端做相同的匹配处理
     * 注意：这里的execute内部的http要使用preventRepetition 避免多个请求同时回调
     * @param {?} id 保证唯一性即可
     * @param {?} key 查询的关键字
     * @param {?} maxlength 如果返回数据量大于或等于最大值 本地缓存不做记录 因为数据不完整
     * @param {?} execute 执行后台查询的方法
     * @param {?} itemFilter 本地缓存时的过滤
     * @param {?} callback 数据过滤后的回调
     * @return {?}
     */
    search(id, key, maxlength, execute, itemFilter, callback) {
        if (key) {
            key = key.trim().toLocaleLowerCase();
        }
        if (this.lastData[id] === key) {
            callback(null);
            return;
        }
        this.lastData[id] = key;
        if (!key) {
            callback([]);
            return;
        }
        clearTimeout(this.timer[id]);
        if (this.cacheData[id]) {
            let /** @type {?} */ nearest = null;
            for (let /** @type {?} */ _key in this.cacheData[id]) {
                if (_key) {
                    if (key === _key) {
                        nearest = this.cacheData[id][_key];
                        break;
                    }
                    else if (key.indexOf(_key) > -1 && (!nearest || this.cacheData[id][_key].length > nearest.length)) {
                        nearest = this.cacheData[id][_key];
                    }
                }
            }
            if (nearest) {
                if (nearest.length === 0) {
                    this.cacheData[id][key] = [];
                    callback([]);
                }
                else {
                    let /** @type {?} */ filterData = [];
                    let /** @type {?} */ returnLength = 0;
                    for (let /** @type {?} */ item of nearest) {
                        itemFilter(key, item, (match) => {
                            if (match) {
                                filterData.push(item);
                            }
                            if (++returnLength === nearest.length) {
                                this.cacheData[id][key] = filterData;
                                callback(filterData);
                            }
                        });
                    }
                }
                return;
            }
        }
        this.timer[id] = setTimeout(() => {
            execute(key, (dataList) => {
                if (dataList.length < maxlength) {
                    if (!this.cacheData[id]) {
                        this.cacheData[id] = {};
                    }
                    this.cacheData[id][key] = dataList;
                }
                callback(dataList);
            });
        }, 100);
    }
    /**
     * @param {?} id
     * @return {?}
     */
    clear(id) {
        delete this.timer[id];
        delete this.cacheData[id];
        delete this.lastData[id];
    }
    ;
}
SearchService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
SearchService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 带后台查询的下拉框
 */
class SearchSelectComponent {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     * @param {?} httpService
     * @param {?} searchService
     */
    constructor(elementRef, toolsService, httpService, searchService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.httpService = httpService;
        this.searchService = searchService;
        this.rem = rem;
        this.searching = false;
        this.boxHeight = 189;
        this.lineHeight = 27;
        this._fixedDataList = [];
        this.filterDataList = [];
        this._lastData = null;
        this._data = null;
        this.dataLoading = false;
        this.init = false;
        this.label = "";
        this.showPlaceholder = "";
        this.placeholder = "请输入关键字查询";
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.jyClass = "";
        this.customItemFilter = false;
        this.customExecuteQuery = false;
        this.executeQuery = new EventEmitter();
        this.itemFilter = new EventEmitter();
        this.dataChange = new EventEmitter();
        this.eventIdClass = ".search-select" + (Math.random() + "").replace(".", "");
        this.mouseEnter = false;
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        this.host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(this.host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
    }
    /**
     * @param {?} fixedDataList
     * @return {?}
     */
    set fixedDataList(fixedDataList) {
        this._fixedDataList = fixedDataList ? fixedDataList : [];
        let /** @type {?} */ data = this._data;
        this._data = null;
        this.data = data;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        if (this._data === data) {
            return;
        }
        if (!this.init) {
            this._data = data;
            return;
        }
        this.dataLoading = true;
        if (data) {
            for (let /** @type {?} */ item of this._fixedDataList) {
                if (item.data === data) {
                    this._data = data;
                    this.label = item.label.trim();
                    this.selectedItem = item;
                    this.dataLoading = false;
                    this.emitDataChange();
                    return;
                }
            }
            this.httpService.get({
                preventRepetition: true,
                preventRepetitionId: "queryByIdUrl" + this.eventIdClass,
                url: this.queryByIdUrl,
                params: { id: data },
                success: (dataAndLabel) => {
                    if (!this.dataLoading) {
                        return;
                    }
                    this.dataLoading = false;
                    if (dataAndLabel) {
                        this._data = data;
                        this.label = dataAndLabel.label;
                        this.selectedItem = dataAndLabel;
                    }
                    else {
                        this.clear();
                    }
                    this.emitDataChange();
                }
            });
        }
        else {
            this.clear();
            this.emitDataChange();
            this.dataLoading = false;
        }
    }
    /**
     * @return {?}
     */
    emitDataChange() {
        setTimeout(() => {
            if (this._lastData !== this._data) {
                this._lastData = this._data;
                this.dataChange.emit(this._data);
                this.customValidatorControl.trigger(this._data);
            }
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (this.dataLoading) {
            return;
        }
        if (event.keyCode === 13) {
            if (this.keySelectedItem) {
                this.selectedItem = this.keySelectedItem;
            }
            else if (this.label && this.filterDataList.length > 0) {
                this.selectedItem = this.filterDataList[0];
            }
            this.label = "";
            this.viewHide();
        }
        else if (this.filterDataList.length > 0 && (event.keyCode === 38 || event.keyCode === 40)) {
            let /** @type {?} */ index = this.filterDataList.indexOf(this.keySelectedItem) + (event.keyCode === 38 ? -1 : 1);
            if (index < 0) {
                index = this.filterDataList.length - 1;
            }
            else if (index >= this.filterDataList.length) {
                index = 0;
            }
            this.keySelectedItem = this.filterDataList[index];
            this.correctScrollBar();
        }
    }
    /**
     * @return {?}
     */
    keyInput() {
        if (this.dataLoading) {
            return;
        }
        this.keySelectedItem = null;
        this.searching = true;
        this.searchService.search(this.eventIdClass, this.input.val(), 1000, (key, callback) => {
            if (this.customExecuteQuery) {
                this.executeQuery.emit({
                    key: key,
                    callback: callback
                });
            }
            else {
                this.httpService.get({
                    url: this.queryUrl,
                    preventRepetition: true,
                    preventRepetitionId: "queryUrl" + this.eventIdClass,
                    params: {
                        key: key
                    },
                    success: (dataList) => {
                        callback(dataList);
                    }
                });
            }
        }, (key, item, callback) => {
            if (this.customItemFilter) {
                this.itemFilter.emit({
                    key: key,
                    item: item,
                    callback: callback
                });
            }
            else {
                callback(item.label.trim().toLocaleLowerCase().indexOf(key) > -1);
            }
        }, (filterDataList) => {
            if (filterDataList) {
                this.filterDataList = filterDataList;
            }
            this.searching = false;
            setTimeout(() => {
                this.onWindowResize();
            });
        });
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.dataLoading || this.disabled || this.show) {
            return;
        }
        this.width = this.input.outerWidth();
        this.show = true;
        this.transparent = true;
        this.keySelectedItem = null;
        this.input.addClass("input-focus");
        this.showPlaceholder = this.label;
        this.label = "";
        setTimeout(() => {
            this.onWindowResize();
            this.transparent = false;
            this.correctScrollBar();
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.input, this.direction);
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.keySelectedItem = null;
        this.input.removeClass("input-focus");
        if (!this.label) {
            if (this.selectedItem) {
                this._data = this.selectedItem.data;
                this.label = this.selectedItem.label;
            }
            else {
                this.clear();
            }
        }
        else {
            let /** @type {?} */ clear = true;
            for (let /** @type {?} */ item of this.filterDataList) {
                if (item.label.trim() === this.label) {
                    this.selectedItem = item;
                    this._data = item.data;
                    this.label = item.label.trim();
                    clear = false;
                    break;
                }
            }
            for (let /** @type {?} */ item of this._fixedDataList) {
                if (item.label.trim() === this.label) {
                    this.selectedItem = item;
                    this._data = item.data;
                    this.label = item.label.trim();
                    clear = false;
                    break;
                }
            }
            if (clear) {
                this.clear();
            }
        }
        this.emitDataChange();
        this.showPlaceholder = this.placeholder;
        this.input.blur();
        this.customValidatorControl.trigger(this._data);
        this.filterDataList = [];
        this.searchService.clear(this.eventIdClass);
    }
    /**
     * @param {?=} viewHide
     * @return {?}
     */
    clear(viewHide = false) {
        this.selectedItem = null;
        this._data = null;
        this.label = "";
        this.emitDataChange();
        if (viewHide) {
            this.viewHide();
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectItem(item) {
        this.mouseEnter = false;
        this.selectedItem = item;
        this._data = item.data;
        this.label = item.label.trim();
        this.viewHide();
    }
    /**
     * @return {?}
     */
    correctScrollBar() {
        let /** @type {?} */ selectedItem = this.keySelectedItem ? this.keySelectedItem : this.selectedItem;
        let /** @type {?} */ index = this.filterDataList.indexOf(selectedItem);
        if (!selectedItem || this.filterDataList.length === 0 || index < 0) {
            return;
        }
        this.toolsService.correctScrollBar(this.box, this.boxHeight, this.lineHeight, index);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            if (!this.dataLoading && !this._data) {
                this.showPlaceholder = this.placeholder;
            }
            this.select = this.host.find(".search-select");
            this.input = this.host.find("input");
            this.box = this.host.find(".fixed-box");
            this.select.addClass(this.eventIdClass.replace(".", ""));
            this.init = true;
            if (this._data) {
                let /** @type {?} */ _data = this._data;
                this._data = null;
                this.data = _data;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
SearchSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-search-select',
                template: `<div class="search-select" [jyClass]="jyClass" (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_data" (jyCustomValidatorControl)="customValidatorControl = $event" [jyName]="jyName"
     [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection"
     [jyTitle]="selectedItem ? selectedItem.label : ''">
  <input type='text' class='form-control' [(ngModel)]="label" [disabled]="disabled" [placeholder]="showPlaceholder"
         (focus)="focus()" (blur)="blur($event)" (keydown)="keydown($event)" (input)="keyInput()"
         [readonly]="dataLoading">
  <div class="loading-box" [@fadeOnlyShow]="dataLoading ? 'show':'hide'">
    <span class="icon-spinner animation-icon-spin"></span>
  </div>
  <span class='icon-caret-down input-icon' [jyHidden]="!disabled && _data && (show || mouseEnter)"
        (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
  <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(!disabled && _data && (show || mouseEnter))"
        (click)="clear(true)"></span>
  <div class='fixed-box' [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}"
       [ngStyle]="{'width.px':width}">
    <div class="select-box" [@fadeOnlyShow]="searching ? 'hide':'show'">
      <div [@fadeOnlyShow]="filterDataList.length > 0 ? 'show':'hide'" class="select-item ellipsis"
           *ngFor="let item of filterDataList"
           [ngClass]="{'key-selected':keySelectedItem == item,selected:selectedItem === item}"
           (click)="selectItem(item)" [jyTitle]="item.label">
        {{item.label}}
      </div>
      <div class="none-box" [@fadeOnlyShow]="filterDataList.length === 0 ? 'show':'hide'">
        {{label ? '未查到数据':'请输入关键字查询'}}
      </div>
    </div>
    <div class="searching-box" [@fadeOnlyShow]="searching ? 'show':'hide'">
      <span class="icon-spinner animation-icon-spin"></span>
    </div>
    <div class="fixed-select-box" *ngIf="_fixedDataList && _fixedDataList.length > 0">
      <div class="select-item ellipsis" *ngFor="let item of _fixedDataList" [jyTitle]="item.label"
           (click)="selectItem(item)" [ngClass]="{selected:selectedItem === item}">
        {{item.label}}
      </div>
    </div>
  </div>
</div>
`,
                styles: [`.search-select{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.search-select .input-icon{font-size:.57142857rem}.search-select .icon-cancel-circle-solid{cursor:pointer;color:#679eda}.search-select .icon-cancel-circle-solid:hover{color:#2b6bb0}.search-select .loading-box{position:absolute;top:0;right:0;left:0;bottom:0;font-size:.64285714rem;line-height:1.07142857rem;text-align:center;color:gray}.search-select .form-control{padding-right:1.14285714rem}.search-select .fixed-box{padding:0}.search-select .fixed-box .fixed-select-box{border-top:.03571429rem solid #ccc}.search-select .fixed-box .select-box{height:6.75rem;overflow-y:auto}.search-select .fixed-box .select-box .none-box{color:#a9a9a9;line-height:6.75rem;text-align:center}.search-select .fixed-box .searching-box{height:6.75rem;text-align:center;line-height:6.75rem;color:gray}.search-select .fixed-box .searching-box .icon-spinner{font-size:2.85714286rem}.search-select .select-item{cursor:pointer;padding:.17857143rem;-webkit-transition:background-color .2s;transition:background-color .2s}.search-select .select-item:hover{background-color:#e2edf8}.search-select .selected{font-weight:800;background-color:#e6e6e6!important}.search-select .key-selected{font-weight:inherit!important;background-color:#e2edf8!important}`],
                animations: [fadeShow, fadeOnlyShow]
            },] },
];
/** @nocollapse */
SearchSelectComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
    { type: HttpService, },
    { type: SearchService, },
];
SearchSelectComponent.propDecorators = {
    "fixedDataList": [{ type: Input },],
    "data": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "jyClass": [{ type: Input },],
    "customItemFilter": [{ type: Input },],
    "customExecuteQuery": [{ type: Input },],
    "queryUrl": [{ type: Input },],
    "queryByIdUrl": [{ type: Input },],
    "executeQuery": [{ type: Output },],
    "itemFilter": [{ type: Output },],
    "dataChange": [{ type: Output },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 多选下拉框
 */
class MultipleSelectComponent {
    /**
     * @param {?} elementRef
     * @param {?} enumService
     * @param {?} toolsService
     */
    constructor(elementRef, enumService, toolsService) {
        this.elementRef = elementRef;
        this.enumService = enumService;
        this.toolsService = toolsService;
        this.rem = rem;
        this.boxHeight = 189;
        this.lineHeight = 27;
        this.init = false;
        this.dataListDataMap = {};
        this.dataListLabelMap = {};
        this._lastData = "[]";
        this._data = [];
        this.selectedItem = [];
        this.label = "";
        this.placeholder = "请选择";
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.jyClass = "";
        this.dataChange = new EventEmitter();
        this.eventIdClass = ".multiple-select" + (Math.random() + "").replace(".", "");
        this.mouseEnter = false;
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        this.host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(this.host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
        let /** @type {?} */ inlineFormControl = toolsService.jqNotNull(this.host.parent(".inline-form-control"));
        if (inlineFormControl) {
            inlineFormControl.addClass("vertical-align-top");
        }
    }
    /**
     * @param {?} dataList
     * @return {?}
     */
    set dataList(dataList) {
        this._dataList = dataList ? dataList : [];
        this.filterDataList = this._dataList;
        this.dataListDataMap = {};
        this.dataListLabelMap = {};
        if (this._dataList) {
            this._dataList.forEach(item => {
                this.dataListDataMap[item.data] = item;
                this.dataListLabelMap[item.label.trim()] = item;
            });
        }
        let /** @type {?} */ data = this._data;
        this._data = null;
        this.data = data;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        if (JSON.stringify(this._data) === JSON.stringify(data)) {
            return;
        }
        if (!this.init) {
            this._data = data;
            if (!this._data) {
                this._data = [];
            }
            return;
        }
        this._data = [];
        this.selectedItem.splice(0, this.selectedItem.length);
        if (data && data.length > 0) {
            for (let /** @type {?} */ item of data) {
                let /** @type {?} */ _item = this.dataListDataMap[item];
                if (_item) {
                    this.selectedItem.push(_item);
                    this._data.push(_item.data);
                }
            }
        }
        this.emitDataChange();
    }
    /**
     * @return {?}
     */
    emitDataChange() {
        setTimeout(() => {
            let /** @type {?} */ jsonData = JSON.stringify(this._data);
            if (this._lastData !== jsonData) {
                this._lastData = jsonData;
                this.dataChange.emit(JSON.parse(jsonData));
                this.customValidatorControl.trigger(jsonData);
            }
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (event.keyCode === 13) {
            if (this.keySelectedItem) {
                this.selectItem(this.keySelectedItem);
            }
            else if (this.filterDataList.length > 0) {
                this.selectItem(this.filterDataList[0]);
            }
        }
        else if (this.filterDataList.length > 0 && (event.keyCode === 38 || event.keyCode === 40)) {
            let /** @type {?} */ index = this.filterDataList.indexOf(this.keySelectedItem) + (event.keyCode === 38 ? -1 : 1);
            if (index < 0) {
                index = this.filterDataList.length - 1;
            }
            else if (index >= this.filterDataList.length) {
                index = 0;
            }
            this.keySelectedItem = this.filterDataList[index];
            this.correctScrollBar();
        }
    }
    /**
     * @return {?}
     */
    keyInput() {
        this.keySelectedItem = null;
        clearTimeout(this.keyupTimer);
        this.keyupTimer = setTimeout(() => {
            let /** @type {?} */ value = this.searchInput.val().trim().toLocaleLowerCase();
            if (!value) {
                this.filterDataList = this._dataList;
            }
            else {
                this.filterDataList = this._dataList.filter(item => {
                    return item.label.trim().toLocaleLowerCase().indexOf(value) > -1;
                });
            }
            setTimeout(() => {
                this.onWindowResize();
            });
        }, 50);
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.disabled || this.show) {
            return;
        }
        this.width = this.selectedBox.outerWidth();
        this.show = true;
        this.transparent = true;
        this.keySelectedItem = null;
        this.selectedBox.addClass("input-focus");
        this.filterDataList = this._dataList;
        this.label = "";
        setTimeout(() => {
            this.onWindowResize();
            this.searchInput.focus();
            this.transparent = false;
            this.correctScrollBar();
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.fixedBox, this.selectedBox, this.direction);
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.keySelectedItem = null;
        this.selectedBox.removeClass("input-focus");
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectItem(item) {
        let /** @type {?} */ index = this.selectedItem.indexOf(item);
        if (index > -1) {
            this.selectedItem.splice(index, 1);
        }
        else {
            this.selectedItem.push(item);
        }
        this._data = this.selectedItem.map(_item => _item.data);
        this.emitDataChange();
        setTimeout(() => {
            this.onWindowResize();
        });
    }
    /**
     * @return {?}
     */
    correctScrollBar() {
        let /** @type {?} */ selectedItem = null;
        if (!this.keySelectedItem && this.selectedItem.length > 0) {
            selectedItem = this.selectedItem[0];
        }
        else if (this.keySelectedItem) {
            selectedItem = this.keySelectedItem;
        }
        else {
            return;
        }
        let /** @type {?} */ index = this.filterDataList.indexOf(selectedItem);
        if (!selectedItem || this.filterDataList.length === 0 || index < 0) {
            return;
        }
        this.toolsService.correctScrollBar(this.selectBox, this.boxHeight, this.lineHeight, index);
    }
    /**
     * @return {?}
     */
    clear() {
        this.data = [];
        this.viewHide();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.select = this.host.find(".multiple-select");
            this.searchInput = this.host.find(".search-input");
            this.selectedBox = this.host.find(".selected-box");
            this.selectBox = this.host.find(".select-box");
            this.fixedBox = this.host.find(".fixed-box");
            this.select.addClass(this.eventIdClass.replace(".", ""));
            if (this.dataListId) {
                this._dataList = this.enumService.getEnumData(this.dataListId);
            }
            this.filterDataList = this._dataList;
            if (this._dataList) {
                this._dataList.forEach(item => {
                    this.dataListDataMap[item.data] = item;
                    this.dataListLabelMap[item.label.trim()] = item;
                });
            }
            this.init = true;
            if (this._data.length > 0) {
                let /** @type {?} */ _data = this._data;
                this._data = [];
                this.data = _data;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
MultipleSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-multiple-select',
                template: `<div class="multiple-select" [jyClass]="jyClass" (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_data" (jyCustomValidatorControl)="customValidatorControl = $event" [jyName]="jyName"
     [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection">
  <div class="form-control selected-box" (click)="focus()">
    <span class="selected-item" *ngFor="let item of selectedItem">
      {{item.label}}
      <i class='icon-cancel-circle-solid' (click)="selectItem(item)"></i>
    </span>
    <span class="select-placeholder" [jyHidden]="selectedItem.length > 0">{{placeholder}}</span>
  </div>
  <span class='icon-caret-down input-icon' [jyHidden]="!disabled && _data.length > 0 && (show || mouseEnter)"
        (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
  <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(!disabled && _data.length > 0 && (show || mouseEnter))"
        (click)="clear()"></span>
  <div class='fixed-box' [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}"
       [ngStyle]="{'width.px':width}">
    <div class="select-search-box">
      <input class="form-control search-input" type='text' [(ngModel)]="label"
             (keydown)="keydown($event)" (input)="keyInput()">
    </div>
    <div class="select-box">
      <div class="select-item ellipsis" *ngFor="let item of filterDataList"
           [ngClass]="{'key-selected':keySelectedItem == item,selected:selectedItem.indexOf(item) > -1}"
           (click)="selectItem(item)" [jyTitle]="item.label">
        {{item.label}}
      </div>
    </div>
  </div>
</div>
`,
                styles: [`.multiple-select{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.multiple-select .input-icon{font-size:.57142857rem}.multiple-select .icon-cancel-circle-solid.input-icon{cursor:pointer;color:#679eda}.multiple-select .icon-cancel-circle-solid.input-icon:hover{color:#2b6bb0}.multiple-select .selected-box{padding:0 .92857143rem 0 0;height:auto;min-height:1.21428571rem;max-height:3.57142857rem;overflow-y:auto}.multiple-select .selected-box .selected-item{display:inline-block;margin:.17857143rem 0 .17857143rem .17857143rem;padding:.07142857rem .17857143rem;font-size:.42857143rem;background:#679eda;border-radius:.14285714rem;color:#fff}.multiple-select .selected-box .selected-item .icon-cancel-circle-solid{cursor:pointer}.multiple-select .fixed-box{padding:0}.multiple-select .fixed-box .select-search-box{padding:.07142857rem}.multiple-select .fixed-box .select-search-box .search-input{padding:.17857143rem}.multiple-select .fixed-box .select-box{overflow-y:auto;max-height:6.75rem}.multiple-select .select-item{cursor:pointer;padding:.17857143rem;-webkit-transition:background-color .2s;transition:background-color .2s}.multiple-select .select-item:hover{background-color:#e2edf8}.multiple-select .selected{font-weight:800;background-color:#e6e6e6!important}.multiple-select .key-selected{font-weight:inherit!important;background-color:#e2edf8!important}.multiple-select .select-placeholder{padding:.21428571rem .42857143rem;display:inline-block}`],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
MultipleSelectComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: EnumService, },
    { type: ToolsService, },
];
MultipleSelectComponent.propDecorators = {
    "dataListId": [{ type: Input },],
    "dataList": [{ type: Input },],
    "data": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "jyClass": [{ type: Input },],
    "dataChange": [{ type: Output },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 多选下拉框
 */
class SearchMultipleSelectComponent {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     * @param {?} searchService
     * @param {?} httpService
     */
    constructor(elementRef, toolsService, searchService, httpService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.searchService = searchService;
        this.httpService = httpService;
        this.rem = rem;
        this.searching = false;
        this.boxHeight = 189;
        this.lineHeight = 27;
        this.dataLoading = false;
        this.init = false;
        this.filterDataList = [];
        this._lastData = "[]";
        this._data = [];
        this.selectedItem = [];
        this.label = "";
        this.placeholder = "请输入关键字查询";
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.jyClass = "";
        this.customItemFilter = false;
        this.customExecuteQuery = false;
        this.maxHeight = 100;
        this.executeQuery = new EventEmitter();
        this.itemFilter = new EventEmitter();
        this.dataChange = new EventEmitter();
        this.eventIdClass = ".multiple-select" + (Math.random() + "").replace(".", "");
        this.mouseEnter = false;
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        this.host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(this.host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
        let /** @type {?} */ inlineFormControl = toolsService.jqNotNull(this.host.parent(".inline-form-control"));
        if (inlineFormControl) {
            inlineFormControl.addClass("vertical-align-top");
        }
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        if (JSON.stringify(this._data) === JSON.stringify(data)) {
            return;
        }
        if (!this.init) {
            this._data = data;
            if (!this._data) {
                this._data = [];
            }
            return;
        }
        this.dataLoading = true;
        this._data = [];
        this.selectedItem.splice(0, this.selectedItem.length);
        if (data && data.length > 0) {
            this.httpService.get({
                preventRepetition: true,
                preventRepetitionId: "queryByIdListUrl" + this.eventIdClass,
                url: this.queryByIdListUrl,
                params: { ids: data.join(",") },
                success: (dataAndLabel) => {
                    if (!this.dataLoading) {
                        return;
                    }
                    this.dataLoading = false;
                    if (dataAndLabel.length > 0) {
                        dataAndLabel.forEach(item => {
                            this.selectedItem.push(item);
                            this._data.push(item.data);
                        });
                    }
                    else {
                        this.clear();
                        this.emitDataChange();
                    }
                }
            });
        }
        else {
            this.clear();
            this.emitDataChange();
            this.dataLoading = false;
        }
    }
    /**
     * @return {?}
     */
    emitDataChange() {
        setTimeout(() => {
            let /** @type {?} */ jsonData = JSON.stringify(this._data);
            if (this._lastData !== jsonData) {
                this._lastData = jsonData;
                this.dataChange.emit(JSON.parse(jsonData));
                this.customValidatorControl.trigger(jsonData);
            }
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    keydown(event) {
        if (event.keyCode === 13) {
            if (this.keySelectedItem) {
                this.selectItem(this.keySelectedItem);
            }
            else if (this.filterDataList.length > 0) {
                this.selectItem(this.filterDataList[0]);
            }
        }
        else if (this.filterDataList.length > 0 && (event.keyCode === 38 || event.keyCode === 40)) {
            let /** @type {?} */ index = this.filterDataList.indexOf(this.getFilterDataList(this.keySelectedItem.data)) + (event.keyCode === 38 ? -1 : 1);
            if (index < 0) {
                index = this.filterDataList.length - 1;
            }
            else if (index >= this.filterDataList.length) {
                index = 0;
            }
            this.keySelectedItem = this.filterDataList[index];
            this.correctScrollBar();
        }
    }
    /**
     * @return {?}
     */
    keyInput() {
        this.keySelectedItem = null;
        this.searching = true;
        this.searchService.search(this.eventIdClass, this.searchInput.val(), 1000, (key, callback) => {
            if (this.customExecuteQuery) {
                this.executeQuery.emit({
                    key: key,
                    callback: callback
                });
            }
            else {
                this.httpService.get({
                    url: this.queryUrl,
                    preventRepetition: true,
                    preventRepetitionId: "queryUrl" + this.eventIdClass,
                    params: {
                        key: key
                    },
                    success: (dataList) => {
                        callback(dataList);
                    }
                });
            }
        }, (key, item, callback) => {
            if (this.customItemFilter) {
                this.itemFilter.emit({
                    key: key,
                    item: item,
                    callback: callback
                });
            }
            else {
                callback(item.label.trim().toLocaleLowerCase().indexOf(key) > -1);
            }
        }, (filterDataList) => {
            if (filterDataList) {
                this.filterDataList = filterDataList;
            }
            this.searching = false;
            setTimeout(() => {
                this.onWindowResize();
            });
        });
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.dataLoading || this.disabled || this.show) {
            return;
        }
        this.width = this.selectedBox.outerWidth();
        this.show = true;
        this.transparent = true;
        this.keySelectedItem = null;
        this.selectedBox.addClass("input-focus");
        this.filterDataList = [];
        this.label = "";
        setTimeout(() => {
            this.onWindowResize();
            this.searchInput.focus();
            this.transparent = false;
            this.correctScrollBar();
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.fixedBox, this.selectedBox, this.direction);
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.keySelectedItem = null;
        this.selectedBox.removeClass("input-focus");
        this.searchService.clear(this.eventIdClass);
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectItem(item) {
        let /** @type {?} */ insert = true;
        for (let /** @type {?} */ _item of this.selectedItem) {
            if (_item.data === item.data) {
                this.selectedItem.splice(this.selectedItem.indexOf(_item), 1);
                insert = false;
                break;
            }
        }
        if (insert) {
            this.selectedItem.push(item);
        }
        this._data = this.selectedItem.map(_item => _item.data);
        this.emitDataChange();
        setTimeout(() => {
            this.onWindowResize();
        });
    }
    /**
     * @param {?} item
     * @return {?}
     */
    isSelected(item) {
        return this.getSelectedItem(item.data) !== null;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    getSelectedItem(data) {
        for (let /** @type {?} */ _item of this.selectedItem) {
            if (_item.data === data) {
                return _item;
            }
        }
        return null;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    getFilterDataList(data) {
        for (let /** @type {?} */ _item of this.filterDataList) {
            if (_item.data === data) {
                return _item;
            }
        }
        return null;
    }
    /**
     * @return {?}
     */
    correctScrollBar() {
        let /** @type {?} */ selectedItem = null;
        if (!this.keySelectedItem && this.selectedItem.length > 0) {
            selectedItem = this.selectedItem[0];
        }
        else if (this.keySelectedItem) {
            selectedItem = this.keySelectedItem;
        }
        else {
            return;
        }
        let /** @type {?} */ index = this.filterDataList.indexOf(this.getFilterDataList(selectedItem.data));
        if (!selectedItem || this.filterDataList.length === 0 || index < 0) {
            return;
        }
        this.toolsService.correctScrollBar(this.selectBox, this.boxHeight, this.lineHeight, index);
    }
    /**
     * @return {?}
     */
    clear() {
        this.selectedItem.splice(0, this.selectedItem.length);
        this._data.splice(0, this._data.length);
        this.emitDataChange();
        this.viewHide();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.select = this.host.find(".search-multiple-select");
            this.searchInput = this.host.find(".search-input");
            this.selectedBox = this.host.find(".selected-box");
            this.selectedBox.css("max-height", this.maxHeight / rem + "rem");
            this.selectBox = this.host.find(".select-box");
            this.fixedBox = this.host.find(".fixed-box");
            this.select.addClass(this.eventIdClass.replace(".", ""));
            this.init = true;
            if (this._data.length > 0) {
                let /** @type {?} */ _data = this._data;
                this._data = [];
                this.data = _data;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
SearchMultipleSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-search-multiple-select',
                template: `<div class="search-multiple-select" [jyClass]="jyClass" (mouseenter)="mouseEnter = true"
     (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_data" (jyCustomValidatorControl)="customValidatorControl = $event" [jyName]="jyName"
     [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection">
  <div class="form-control selected-box" (click)="focus()">
    <span class="selected-item" *ngFor="let item of selectedItem" [@fadeOnlyShow]="!dataLoading ? 'show':'hide'">
      {{item.label}}
      <i class='icon-cancel-circle-solid' (click)="selectItem(item)"></i>
    </span>
    <span class="select-placeholder"
          [@fadeOnlyShow]="!dataLoading && selectedItem.length === 0 ? 'show':'hide'">{{placeholder}}</span>
  </div>
  <div class="loading-box" [@fadeOnlyShow]="dataLoading ? 'show':'hide'">
    <span class="icon-spinner animation-icon-spin"></span>
  </div>
  <span class='icon-caret-down input-icon' [jyHidden]="!disabled && _data.length > 0 && (show || mouseEnter)"
        (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
  <span class='icon-cancel-circle-solid input-icon' [jyHidden]="!(!disabled && _data.length > 0 && (show || mouseEnter))"
        (click)="clear()"></span>
  <div class='fixed-box' [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}"
       [ngStyle]="{'width.px':width}">
    <div class="select-search-box">
      <input class="form-control search-input" type='text' [(ngModel)]="label"
             (keydown)="keydown($event)" (input)="keyInput()">
    </div>
    <div class="select-box" [@fadeOnlyShow]="!searching && filterDataList.length > 0 ? 'show':'hide'">
      <div class="select-item ellipsis"
           *ngFor="let item of filterDataList"
           [ngClass]="{'key-selected':keySelectedItem == item,selected:isSelected(item)}"
           (click)="selectItem(item)" [jyTitle]="item.label">
        {{item.label}}
      </div>
    </div>
    <div class="none-box" [@fadeOnlyShow]="!searching && filterDataList.length === 0 ? 'show':'hide'">
      {{label ? '未查到数据':'请输入关键字查询'}}
    </div>
    <div class="searching-box" [@fadeOnlyShow]="searching ? 'show':'hide'">
      <span class="icon-spinner animation-icon-spin"></span>
    </div>
  </div>
</div>
`,
                styles: [`.search-multiple-select{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.search-multiple-select .input-icon{font-size:.57142857rem}.search-multiple-select .icon-cancel-circle-solid.input-icon{cursor:pointer;color:#679eda}.search-multiple-select .icon-cancel-circle-solid.input-icon:hover{color:#2b6bb0}.search-multiple-select .select-placeholder{padding:.21428571rem .42857143rem;display:inline-block}.search-multiple-select .loading-box{position:absolute;top:0;right:0;left:0;bottom:0;font-size:.64285714rem;line-height:1.07142857rem;text-align:center;color:gray}.search-multiple-select .selected-box{padding:0 .92857143rem 0 0;height:auto;min-height:1.21428571rem;overflow-y:auto}.search-multiple-select .selected-box .selected-item{display:inline-block;margin:.17857143rem 0 .17857143rem .17857143rem;padding:.07142857rem .17857143rem;font-size:.42857143rem;background:#679eda;border-radius:.14285714rem;color:#fff}.search-multiple-select .selected-box .selected-item .icon-cancel-circle-solid{cursor:pointer}.search-multiple-select .fixed-box{padding:0}.search-multiple-select .fixed-box .select-search-box{padding:.07142857rem}.search-multiple-select .fixed-box .select-search-box .search-input{padding:.17857143rem}.search-multiple-select .fixed-box .select-box{overflow-y:auto;height:6.75rem}.search-multiple-select .fixed-box .none-box{color:#a9a9a9;line-height:5.78571429rem;text-align:center;height:6.75rem}.search-multiple-select .fixed-box .searching-box{text-align:center;line-height:5.78571429rem;height:6.75rem;color:gray}.search-multiple-select .fixed-box .searching-box .icon-spinner{font-size:2.85714286rem}.search-multiple-select .select-item{cursor:pointer;padding:.17857143rem;-webkit-transition:background-color .2s;transition:background-color .2s}.search-multiple-select .select-item:hover{background-color:#e2edf8}.search-multiple-select .selected{font-weight:800;background-color:#e6e6e6!important}.search-multiple-select .key-selected{font-weight:inherit!important;background-color:#e2edf8!important}`],
                animations: [fadeShow, fadeOnlyShow]
            },] },
];
/** @nocollapse */
SearchMultipleSelectComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
    { type: SearchService, },
    { type: HttpService, },
];
SearchMultipleSelectComponent.propDecorators = {
    "data": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "jyClass": [{ type: Input },],
    "customItemFilter": [{ type: Input },],
    "customExecuteQuery": [{ type: Input },],
    "queryUrl": [{ type: Input },],
    "queryByIdListUrl": [{ type: Input },],
    "maxHeight": [{ type: Input },],
    "executeQuery": [{ type: Output },],
    "itemFilter": [{ type: Output },],
    "dataChange": [{ type: Output },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 禁用遮挡层
 */
class DisabledMaskDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.first = true;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} jyDisabledMask
     * @return {?}
     */
    set jyDisabledMask(jyDisabledMask) {
        this._jyDisabledMask = jyDisabledMask;
        this.execute();
    }
    /**
     * @return {?}
     */
    execute() {
        if (!this.mask) {
            setTimeout(() => {
                let /** @type {?} */ position = this.host.css("position");
                if (position !== "absolute" && position !== "fixed") {
                    this.host.css("position", "relative");
                }
                this.mask = $(`<div class="disabled-mask animated"></div>`);
                this.mask.hide();
                this.host.append(this.mask);
                this.execute();
            }, 200);
        }
        else {
            if (this._jyDisabledMask) {
                this.mask.html(this._jyDisabledMask);
                this.mask.show();
                this.mask.removeClass("fade-out").addClass("fade-in");
            }
            else {
                this.mask.removeClass("fade-in").addClass("fade-out");
                setTimeout(() => {
                    if (this.mask.hasClass("fade-out")) {
                        this.mask.hide();
                    }
                }, 500);
            }
            this.first = false;
        }
    }
}
DisabledMaskDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyDisabledMask]"
            },] },
];
/** @nocollapse */
DisabledMaskDirective.ctorParameters = () => [
    { type: ElementRef, },
];
DisabledMaskDirective.propDecorators = {
    "jyDisabledMask": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 省市区
 */
class ProvinceCityAreaComponent {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     * @param {?} provinceCityAreaService
     */
    constructor(elementRef, toolsService, provinceCityAreaService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.provinceCityAreaService = provinceCityAreaService;
        this.boxHeight = 189;
        this.lineHeight = 27;
        this.provinceCodeChange = new EventEmitter();
        this.cityCodeChange = new EventEmitter();
        this.areaCodeChange = new EventEmitter();
        this.codeParentListMap = {};
        this.codeMap = {};
        this.nameMap = {};
        this.allCity = [];
        this.allArea = [];
        this.isCustomProvinceList = false;
        this._provinceList = [];
        this.cityList = [];
        this.areaList = [];
        this.label = "";
        this.showPlaceholder = "";
        this.placeholder = "请选择";
        this.disabled = false;
        this.direction = "bottom";
        this.jyTooltipDirection = "right";
        this.jyName = "";
        this.jyRequired = false;
        this.jyValidate = true;
        this.jyClass = "";
        this.eventIdClass = ".province-city-area" + (Math.random() + "").replace(".", "");
        this.mouseEnter = false;
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        this.host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(this.host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
        this._provinceList = provinceCityAreaService.getProvinceCityAreaData();
    }
    /**
     * @param {?} provinceCode
     * @return {?}
     */
    set provinceCode(provinceCode) {
        if (this._provinceCode === provinceCode) {
            return;
        }
        this._provinceCode = provinceCode;
        this.emitDataChange();
    }
    /**
     * @param {?} cityCode
     * @return {?}
     */
    set cityCode(cityCode) {
        if (this._cityCode === cityCode) {
            return;
        }
        this._cityCode = cityCode;
        this.emitDataChange();
    }
    /**
     * @param {?} areaCode
     * @return {?}
     */
    set areaCode(areaCode) {
        if (this._areaCode === areaCode) {
            return;
        }
        this._areaCode = areaCode;
        this.emitDataChange();
    }
    /**
     * @param {?} provinceList
     * @return {?}
     */
    set provinceList(provinceList) {
        if (!provinceList || !provinceList.length) {
            return;
        }
        this.isCustomProvinceList = true;
        this._provinceList = provinceList;
        this.getAllCodeAndName(this._provinceList, null, 1);
    }
    /**
     * @param {?} provinceCityAreaList
     * @param {?} parent
     * @param {?} index
     * @return {?}
     */
    getAllCodeAndName(provinceCityAreaList, parent, index) {
        if (!provinceCityAreaList || provinceCityAreaList.length === 0) {
            return;
        }
        for (let /** @type {?} */ provinceCityArea of provinceCityAreaList) {
            provinceCityArea.parent = parent;
            this.codeMap[provinceCityArea.code] = provinceCityArea;
            this.nameMap[provinceCityArea.name] = provinceCityArea;
            this.codeParentListMap[provinceCityArea.code] = provinceCityAreaList;
            this.getAllCodeAndName(provinceCityArea.children, provinceCityArea, index + 1);
            if (index === 2) {
                this.allCity.push(provinceCityArea);
            }
            else if (index === 3) {
                this.allArea.push(provinceCityArea);
            }
        }
    }
    /**
     * @return {?}
     */
    emitDataChange() {
        this.label = "";
        if (this._provinceCode) {
            this.label += this.isCustomProvinceList ? this.getNameByCode(this._provinceCode) : this.provinceCityAreaService.getNameByCode(this._provinceCode);
            if (this._cityCode) {
                this.label += this.isCustomProvinceList ? this.getNameByCode(this._cityCode) : this.provinceCityAreaService.getNameByCode(this._cityCode);
                if (this._areaCode) {
                    this.label += this.isCustomProvinceList ? this.getNameByCode(this._areaCode) : this.provinceCityAreaService.getNameByCode(this._areaCode);
                }
            }
        }
        clearTimeout(this.timer);
        this.timer = setTimeout(() => {
            if (this._lastProvinceCode !== this._provinceCode) {
                this._lastProvinceCode = this._provinceCode;
                this.provinceCodeChange.emit(this._provinceCode);
            }
            if (this._lastCityCode !== this._cityCode) {
                this._lastCityCode = this._cityCode;
                this.cityCodeChange.emit(this._cityCode);
            }
            if (this._lastAreaCode !== this._areaCode) {
                this._lastAreaCode = this._areaCode;
                this.areaCodeChange.emit(this._areaCode);
            }
        }, 20);
    }
    /**
     * @return {?}
     */
    keyInput() {
        clearTimeout(this.keyInputTimer);
        this.keyInputTimer = setTimeout(() => {
            let /** @type {?} */ value = this.input.val().trim().toLocaleLowerCase();
            if (!value) {
                this.resetListData();
            }
            else {
                if (this.isCustomProvinceList) {
                    this._provinceList = this.getProvinceCityAreaData().filter(item => {
                        return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                    });
                    this.cityList = this.getAllCity().filter(item => {
                        return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                    });
                    this.areaList = this.getAllArea().filter(item => {
                        return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                    });
                    return;
                }
                this._provinceList = this.provinceCityAreaService.getProvinceCityAreaData().filter(item => {
                    return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                });
                this.cityList = this.provinceCityAreaService.getAllCity().filter(item => {
                    return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                });
                this.areaList = this.provinceCityAreaService.getAllArea().filter(item => {
                    return item.name.trim().toLocaleLowerCase().indexOf(value) > -1;
                });
            }
        }, 50);
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.disabled || this.show) {
            return;
        }
        this.resetListData();
        this.showPlaceholder = this.label;
        this.label = "";
        this.show = true;
        this.transparent = true;
        this.input.addClass("input-focus");
        setTimeout(() => {
            this.onWindowResize();
            this.transparent = false;
        });
        this.clickHandler = (event) => {
            if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                this.viewHide();
            }
        };
        document.addEventListener("click", this.clickHandler);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    blur(event) {
        if (event.relatedTarget && !this.toolsService.jqNotNull($(event.relatedTarget).closest(this.eventIdClass))) {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.input, this.direction);
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
        this.showPlaceholder = this.placeholder;
        this.input.removeClass("input-focus");
        this.emitDataChange();
        this.input.blur();
    }
    /**
     * @return {?}
     */
    clear() {
        this._provinceCode = "";
        this._cityCode = "";
        this._areaCode = "";
        this.cityList = [];
        this.areaList = [];
        this.emitDataChange();
        this.viewHide();
    }
    /**
     * @return {?}
     */
    resetListData() {
        this._provinceList = this.isCustomProvinceList ? this.getProvinceCityAreaData() : this.provinceCityAreaService.getProvinceCityAreaData();
        if (this._provinceCode) {
            this.cityList = this.isCustomProvinceList ? this.getChildrenByCode(this._provinceCode) : this.provinceCityAreaService.getChildrenByCode(this._provinceCode);
            if (this._cityCode) {
                this.areaList = this.isCustomProvinceList ? this.getChildrenByCode(this._cityCode) : this.provinceCityAreaService.getChildrenByCode(this._cityCode);
            }
            else {
                this.areaList = [];
            }
        }
        else {
            this.cityList = [];
            this.areaList = [];
        }
        this.correctScrollBar();
    }
    /**
     * @param {?} item
     * @param {?} type
     * @return {?}
     */
    selectItem(item, type) {
        if (type === "province") {
            if (this._provinceCode === item.code) {
                return;
            }
            this.provinceCode = item.code;
            this.cityCode = "";
            this.areaCode = "";
            this.cityList = item.children;
            this.areaList = [];
        }
        else if (type === "city") {
            if (this._cityCode === item.code) {
                return;
            }
            this.provinceCode = item.parent.code;
            this.cityCode = item.code;
            this.areaCode = "";
            this.areaList = item.children;
        }
        else if (type === "area") {
            if (this._areaCode === item.code) {
                return;
            }
            this.provinceCode = item.parent.parent.code;
            this.cityCode = item.parent.code;
            this.areaCode = item.code;
            this.viewHide();
        }
        this.resetListData();
    }
    /**
     * @return {?}
     */
    correctScrollBar() {
        if (this._provinceList && this._provinceList.length > 0 && this._provinceCode) {
            for (let /** @type {?} */ i = 0; i < this._provinceList.length; i++) {
                if (this._provinceCode === this._provinceList[i].code) {
                    setTimeout(() => {
                        this.toolsService.correctScrollBar(this.provinceBox, this.boxHeight, this.lineHeight, i);
                    });
                    break;
                }
            }
            if (this.cityList && this.cityList.length > 0 && this._cityCode) {
                for (let /** @type {?} */ i = 0; i < this.cityList.length; i++) {
                    if (this._cityCode === this.cityList[i].code) {
                        setTimeout(() => {
                            this.toolsService.correctScrollBar(this.cityBox, this.boxHeight, this.lineHeight, i);
                        });
                        break;
                    }
                }
                if (this.areaList && this.areaList.length > 0 && this._areaCode) {
                    for (let /** @type {?} */ i = 0; i < this.areaList.length; i++) {
                        if (this._areaCode === this.areaList[i].code) {
                            setTimeout(() => {
                                this.toolsService.correctScrollBar(this.areaBox, this.boxHeight, this.lineHeight, i);
                            });
                            break;
                        }
                    }
                }
            }
        }
    }
    /**
     * @param {?} code
     * @return {?}
     */
    getNameByCode(code) {
        return this.codeMap[code] ? this.codeMap[code].name : "";
    }
    /**
     * @return {?}
     */
    getProvinceCityAreaData() {
        return this._provinceList;
    }
    /**
     * @return {?}
     */
    getAllCity() {
        return this.allCity;
    }
    /**
     * @return {?}
     */
    getAllArea() {
        return this.allArea;
    }
    /**
     * @param {?} code
     * @return {?}
     */
    getChildrenByCode(code) {
        return this.codeMap[code] ? this.codeMap[code].children : [];
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout(() => {
            this.provinceCityArea = this.host.find(".province-city-area");
            this.input = this.host.find("input");
            this.box = this.host.find(".fixed-box");
            this.provinceBox = this.host.find(".province-box");
            this.cityBox = this.host.find(".city-box");
            this.areaBox = this.host.find(".area-box");
            this.provinceCityArea.addClass(this.eventIdClass.replace(".", ""));
            this.showPlaceholder = this.placeholder;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
ProvinceCityAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-province-city-area',
                template: `<div class="province-city-area" [jyClass]="jyClass" (mouseenter)="mouseEnter = true" (mouseleave)="mouseEnter = false"
     [jyCustomValidator]="_areaCode" (jyCustomValidatorControl)="customValidatorControl = $event" [jyName]="jyName"
     [jyRequired]="jyRequired" [jyValidate]="jyValidate" [jyTooltipDirection]="jyTooltipDirection"
     [jyTitle]="label">
  <input type='text' class='form-control' [(ngModel)]="label" [disabled]="disabled" [placeholder]="showPlaceholder"
         (focus)="focus()" (blur)="blur($event)" (input)="keyInput()">
  <span class='icon-caret-down input-icon'
        [jyHidden]="!disabled && (_provinceCode || _cityCode || _areaCode) && (show || mouseEnter)"
        (click)="focus()" [ngStyle]="{cursor:disabled ? 'no-drop':'pinter'}"></span>
  <span class='icon-cancel-circle-solid input-icon'
        [jyHidden]="!(!disabled && (_provinceCode || _cityCode || _areaCode) && (show || mouseEnter))"
        (click)="clear()"></span>
  <div class='fixed-box' [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}">
    <div class="select-box province-box">
      <div class="select-item ellipsis" *ngFor="let item of _provinceList" (click)="selectItem(item,'province')"
           [ngClass]="{selected:_provinceCode === item.code}">
        {{item.name}}
      </div>
    </div>
    <div class="select-box city-box">
      <div class="select-item ellipsis" *ngFor="let item of cityList" (click)="selectItem(item,'city')"
           [ngClass]="{selected:_cityCode === item.code}">
        {{item.name}}
      </div>
    </div>
    <div class="select-box area-box">
      <div class="select-item ellipsis" *ngFor="let item of areaList" (click)="selectItem(item,'area')"
           [ngClass]="{selected:_areaCode === item.code}">
        {{item.name}}
      </div>
    </div>
  </div>
</div>
`,
                styles: [`.province-city-area{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.province-city-area .input-icon{font-size:.57142857rem}.province-city-area .icon-cancel-circle-solid{cursor:pointer;color:#679eda}.province-city-area .icon-cancel-circle-solid:hover{color:#2b6bb0}.province-city-area .form-control{padding-right:1.14285714rem}.province-city-area .fixed-box{width:11.14285714rem;height:6.85714286rem;padding:0}.province-city-area .fixed-box .select-box{width:3.57142857rem;display:inline-block;height:6.75rem;overflow-y:auto}.province-city-area .fixed-box .select-box .select-item{cursor:pointer;padding:.17857143rem;-webkit-transition:background-color .2s;transition:background-color .2s}.province-city-area .fixed-box .select-box .select-item:hover{background-color:#e2edf8}.province-city-area .fixed-box .select-box .select-item.selected{font-weight:800;background-color:#e6e6e6!important}`],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
ProvinceCityAreaComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
    { type: ProvinceCityAreaService, },
];
ProvinceCityAreaComponent.propDecorators = {
    "provinceCode": [{ type: Input },],
    "cityCode": [{ type: Input },],
    "areaCode": [{ type: Input },],
    "provinceCodeChange": [{ type: Output },],
    "cityCodeChange": [{ type: Output },],
    "areaCodeChange": [{ type: Output },],
    "provinceList": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "disabled": [{ type: Input },],
    "direction": [{ type: Input },],
    "jyTooltipDirection": [{ type: Input },],
    "jyName": [{ type: Input },],
    "jyRequired": [{ type: Input },],
    "jyValidate": [{ type: Input },],
    "jyClass": [{ type: Input },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ProvinceCityAreaPipe {
    /**
     * @param {?} provinceCityAreaService
     */
    constructor(provinceCityAreaService) {
        this.provinceCityAreaService = provinceCityAreaService;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    transform(value) {
        if (value === null || isUndefined(value) || value.toString().trim() === "") {
            return "";
        }
        return this.provinceCityAreaService.getNameByCode(value);
    }
}
ProvinceCityAreaPipe.decorators = [
    { type: Pipe, args: [{
                name: 'jyProvinceCityArea'
            },] },
];
/** @nocollapse */
ProvinceCityAreaPipe.ctorParameters = () => [
    { type: ProvinceCityAreaService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BaiduMapService {
    constructor() {
    }
    /**
     * @param {?} container
     * @param {?=} opts
     * @return {?}
     */
    Map(container, opts) {
        return new (/** @type {?} */ (window))["BMap"].Map(container, opts);
    }
    /**
     * @param {?} lng
     * @param {?} lat
     * @return {?}
     */
    Point(lng, lat) {
        return new (/** @type {?} */ (window))["BMap"].Point(lng, lat);
    }
    /**
     * @param {?} Point
     * @param {?=} opts
     * @return {?}
     */
    Marker(Point, opts) {
        return new (/** @type {?} */ (window))["BMap"].Marker(Point, opts);
    }
    /**
     * @param {?} content
     * @param {?=} opts
     * @return {?}
     */
    InfoWindow(content, opts) {
        return new (/** @type {?} */ (window))["BMap"].InfoWindow(content, opts);
    }
    /**
     * @param {?} opts
     * @return {?}
     */
    NavigationControl(opts) {
        return new (/** @type {?} */ (window))["BMap"].NavigationControl(opts);
    }
    /**
     * @param {?} opts
     * @return {?}
     */
    ScaleControl(opts) {
        return new (/** @type {?} */ (window))["BMap"].ScaleControl(opts);
    }
    /**
     * @param {?} map
     * @param {?} markers
     * @return {?}
     */
    MarkerClusterer(map, markers) {
        return new (/** @type {?} */ (window))["BMapLib"].MarkerClusterer(map, markers);
    }
}
BaiduMapService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
BaiduMapService.ctorParameters = () => [];
/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LodopService {
    constructor() {
        this._lodop = null;
        this.CreatedOKLodop7766 = null;
        this.getCLodopJS();
    }
    /**
     * @return {?}
     */
    get lodop() {
        if (!this._lodop) {
            this._lodop = this.getLodop();
        }
        return this._lodop;
    }
    /**
     * @return {?}
     */
    getLodop() {
        return this._getLodop();
    }
    /**
     * @return {?}
     */
    getCLodopJS() {
        // ====页面引用CLodop云打印必须的JS文件：====
        if (this.needCLodop()) {
            let /** @type {?} */ head = document.head || document.getElementsByTagName("head")[0] || document.documentElement;
            let /** @type {?} */ oscript = document.createElement("script");
            oscript.src = "http://localhost:8000/CLodopfuncs.js?priority=1";
            head.insertBefore(oscript, head.firstChild);
            // 引用双端口(8000和18000）避免其中某个被占用：
            oscript = document.createElement("script");
            oscript.src = "http://localhost:18000/CLodopfuncs.js?priority=0";
            head.insertBefore(oscript, head.firstChild);
        }
    }
    /**
     * @return {?}
     */
    needCLodop() {
        try {
            let /** @type {?} */ ua = navigator.userAgent;
            if (ua.match(/Windows\sPhone/i) !== null) {
                return true;
            }
            if (ua.match(/iPhone|iPod/i) !== null) {
                return true;
            }
            if (ua.match(/Android/i) !== null) {
                return true;
            }
            if (ua.match(/Edge\D?\d+/i) !== null) {
                return true;
            }
            let /** @type {?} */ verTrident = ua.match(/Trident\D?\d+/i);
            let /** @type {?} */ verIE = ua.match(/MSIE\D?\d+/i);
            let /** @type {?} */ verOPR = ua.match(/OPR\D?\d+/i);
            let /** @type {?} */ verFF = ua.match(/Firefox\D?\d+/i);
            let /** @type {?} */ x64 = ua.match(/x64/i);
            if ((verTrident === null) && (verIE === null) && (x64 !== null)) {
                return true;
            }
            else if (verFF !== null) {
                verFF = verFF[0].match(/\d+/);
                if ((verFF[0] >= '42') || (x64 !== null)) {
                    return true;
                }
            }
            else if (verOPR !== null) {
                verOPR = verOPR[0].match(/\d+/);
                if (verOPR[0] >= '32') {
                    return true;
                }
            }
            else if ((verTrident === null) && (verIE === null)) {
                let /** @type {?} */ verChrome = ua.match(/Chrome\D?\d+/i);
                if (verChrome !== null) {
                    verChrome = verChrome[0].match(/\d+/);
                    if (verChrome[0] >= '42') {
                        return true;
                    }
                }
            }
            return false;
        }
        catch (/** @type {?} */ err) {
            return true;
        }
    }
    /**
     * @param {?=} oOBJECT
     * @param {?=} oEMBED
     * @return {?}
     */
    _getLodop(oOBJECT, oEMBED) {
        let /** @type {?} */ strCLodopInstall = "<br><span style='color:#FF00FF'>CLodop云打印服务(localhost本地)未安装启动!点击这里<a href='CLodop_Setup_for_Win32NT.exe' target='_self'>执行安装</a>,安装后请刷新页面。</span>";
        let /** @type {?} */ strCLodopUpdate = "<br><span style='color:#FF00FF'>CLodop云打印服务需升级!点击这里<a href='CLodop_Setup_for_Win32NT.exe' target='_self'>执行升级</a>,升级后请刷新页面。</span>";
        let /** @type {?} */ LODOP;
        try {
            let /** @type {?} */ isIE = (navigator.userAgent.indexOf('MSIE') >= 0) || (navigator.userAgent.indexOf('Trident') >= 0);
            let /** @type {?} */ is64IE = isIE && (navigator.userAgent.indexOf('x64') >= 0);
            if (this.needCLodop()) {
                try {
                    LODOP = (/** @type {?} */ (window)).getCLodop();
                }
                catch (/** @type {?} */ err) {
                }
                if (!LODOP && document.readyState !== "complete") {
                    alert("C-Lodop没准备好，请稍后再试！");
                    return;
                }
                if (!LODOP) {
                    if (isIE) {
                        document.write(strCLodopInstall);
                    }
                    else {
                        // document.documentElement.innerHTML = strCLodopInstall + document.documentElement.innerHTML;
                        return;
                    }
                }
                else {
                    if ((/** @type {?} */ (window)).CLODOP.CVERSION < "2.1.0.2") {
                        if (isIE) {
                            document.write(strCLodopUpdate);
                        }
                    }
                    if (oEMBED && oEMBED.parentNode) {
                        oEMBED.parentNode.removeChild(oEMBED);
                    }
                    if (oOBJECT && oOBJECT.parentNode) {
                        oOBJECT.parentNode.removeChild(oOBJECT);
                    }
                }
            }
            else {
                // =====如果页面有Lodop就直接使用，没有则新建:==========
                if (oOBJECT !== undefined || oEMBED !== undefined) {
                    if (isIE) {
                        LODOP = oOBJECT;
                    }
                    else {
                        LODOP = oEMBED;
                    }
                }
                else if (this.CreatedOKLodop7766 === null) {
                    LODOP = document.createElement("object");
                    LODOP.setAttribute("width", 0);
                    LODOP.setAttribute("height", 0);
                    LODOP.setAttribute("style", "position:absolute;left:0px;top:-100px;width:0px;height:0px;");
                    if (isIE) {
                        LODOP.setAttribute("classid", "clsid:2105C259-1E0C-4534-8141-A753534CB4CA");
                    }
                    else {
                        LODOP.setAttribute("type", "application/x-print-lodop");
                    }
                    document.documentElement.appendChild(LODOP);
                    this.CreatedOKLodop7766 = LODOP;
                }
                else {
                    LODOP = this.CreatedOKLodop7766;
                }
                // =====Lodop插件未安装时提示下载地址:==========
                if ((LODOP === null) || (typeof (LODOP.VERSION) === "undefined")) {
                    if (navigator.userAgent.indexOf('Chrome') >= 0) {
                        // document.documentElement.innerHTML = strHtmChrome + document.documentElement.innerHTML;
                    }
                    if (navigator.userAgent.indexOf('Firefox') >= 0) {
                        // document.documentElement.innerHTML = strHtmFireFox + document.documentElement.innerHTML;
                    }
                    return LODOP;
                }
            }
            if (LODOP.VERSION < "6.2.1.7") {
                if (this.needCLodop()) {
                    // document.documentElement.innerHTML = strCLodopUpdate + document.documentElement.innerHTML;
                }
                else if (is64IE) {
                    // document.write(strHtm64_Update);
                }
                else if (isIE) {
                    // document.write(strHtmUpdate);
                }
                else {
                    // document.documentElement.innerHTML = strHtmUpdate + document.documentElement.innerHTML;
                }
                return LODOP;
            }
            // ===如下空白位置适合调用统一功能(如注册语句、语言选择等):===
            // ===========================================================
            return LODOP;
        }
        catch (/** @type {?} */ err) {
            alert("getLodop出错:" + err);
        }
    }
}
LodopService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
LodopService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 年月日 日期控件
 */
class ButtonGroupComponent {
    /**
     * @param {?} elementRef
     * @param {?} toolsService
     */
    constructor(elementRef, toolsService) {
        this.elementRef = elementRef;
        this.toolsService = toolsService;
        this.rem = rem;
        this.buttonClass = "btn-primary";
        this.buttonName = "操作";
        this.buttonBoxWidth = 150;
        this.direction = "bottom";
        this.eventIdClass = ".button-group" + (Math.random() + "").replace(".", "");
        this.show = false;
        this.transparent = true;
        this.clickHandler = null;
        let /** @type {?} */ host = $(elementRef.nativeElement);
        let /** @type {?} */ td = toolsService.jqNotNull(host.parent("td"));
        if (td) {
            td.addClass("hidden-restrictions");
        }
    }
    /**
     * @param {?} buttonGroupList
     * @return {?}
     */
    set _buttonGroupList(buttonGroupList) {
        this.buttonGroupList = buttonGroupList;
    }
    ;
    /**
     * @param {?} buttonGroup
     * @return {?}
     */
    set _buttonGroup(buttonGroup) {
        this.buttonGroup = $(buttonGroup.nativeElement);
        this.buttonGroup.addClass(this.eventIdClass.replace(".", ""));
    }
    ;
    /**
     * @param {?} button
     * @return {?}
     */
    set _button(button) {
        this.button = $(button.nativeElement);
    }
    ;
    /**
     * @param {?} box
     * @return {?}
     */
    set _box(box) {
        this.box = $(box.nativeElement);
    }
    ;
    /**
     * @return {?}
     */
    click() {
        let /** @type {?} */ show = false;
        if (this.buttonGroupList) {
            for (let /** @type {?} */ buttonGroupItem of this.buttonGroupList) {
                if (!buttonGroupItem.hide) {
                    show = true;
                }
            }
        }
        if (!show) {
            this.show = false;
            return;
        }
        if (!this.show) {
            this.show = true;
            this.transparent = true;
            setTimeout(() => {
                this.onWindowResize();
                this.transparent = false;
            });
            this.clickHandler = (event) => {
                if (!this.toolsService.jqNotNull($(event.target).closest(this.eventIdClass))) {
                    this.viewHide();
                }
            };
            document.addEventListener("click", this.clickHandler);
        }
        else {
            this.viewHide();
        }
    }
    /**
     * @return {?}
     */
    viewHide() {
        if (!this.show) {
            return;
        }
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
            this.clickHandler = null;
        }
        this.show = false;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    itemClick(item) {
        if (item.disabled) {
            return;
        }
        if (item.click(this.button, this.clickData) === false) {
            return;
        }
        this.viewHide();
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        this.toolsService.positionFixedBoxInput(this.box, this.button, this.direction);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.clickHandler) {
            document.removeEventListener("click", this.clickHandler);
        }
    }
}
ButtonGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-button-group',
                template: `<div class="button-group" #buttonGroup>
  <button #button class="btn button-group-btn" [jyClass]="buttonClass" (click)="click()"
          [ngClass]="{'active':show}">
    {{buttonName}}
    <i class="icon-caret-down"></i>
  </button>
  <div class='fixed-box button-group-box' #box [@fadeShow]="show ? 'show':'hide'" [ngClass]="{transparent: transparent}"
       [ngStyle]="{'width.rem':buttonBoxWidth/rem}">
    <div class="button-item ellipsis" *ngFor="let item of buttonGroupList"
         [jyHidden]="item.hide" (click)="itemClick(item)"
         [ngClass]="{disabled:item.disabled}">
      {{item.label}}
    </div>
  </div>
</div>
`,
                styles: [`.button-group{display:inline-block;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;position:relative}.button-group .button-group-btn{padding-right:.64285714rem}.button-group .icon-caret-down{position:absolute;right:.03571429rem;top:.28571429rem}.button-group .button-group-box{padding:.17857143rem 0}.button-group .button-group-box .button-item{display:block;padding:.17857143rem .35714286rem}.button-group .button-group-box .button-item:hover{background-color:#e2edf8;cursor:pointer}.button-group .button-group-box .disabled{color:#a9a9a9}.button-group .button-group-box .disabled:hover{background-color:#fff!important;cursor:not-allowed}`],
                animations: [fadeShow]
            },] },
];
/** @nocollapse */
ButtonGroupComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: ToolsService, },
];
ButtonGroupComponent.propDecorators = {
    "buttonClass": [{ type: Input },],
    "buttonName": [{ type: Input },],
    "buttonBoxWidth": [{ type: Input },],
    "direction": [{ type: Input },],
    "clickData": [{ type: Input },],
    "_buttonGroupList": [{ type: Input, args: ["buttonGroupList",] },],
    "_buttonGroup": [{ type: ViewChild, args: ["buttonGroup",] },],
    "_button": [{ type: ViewChild, args: ["button",] },],
    "_box": [{ type: ViewChild, args: ["box",] },],
    "onWindowResize": [{ type: HostListener, args: ['window:resize',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 滑动组件
 */
class SliderComponent {
    /**
     * @param {?} elementRef
     * @param {?} remService
     */
    constructor(elementRef, remService) {
        this.elementRef = elementRef;
        this.remService = remService;
        this.rem = rem;
        this.left = 0;
        this.stepDecimal = null;
        this.width = 300;
        this.dataChange = new EventEmitter();
        this._lastData = null;
        this.move = false;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} data
     * @return {?}
     */
    set data(data) {
        if (isString(data)) {
            data = parseFloat(data.toString());
        }
        if (this.stepDecimal !== null) {
            data = parseFloat(data.toFixed(this.stepDecimal));
        }
        if (data < this.min) {
            data = this.min;
        }
        else if (data > this.max) {
            data = this.max;
        }
        if (this._lastData === null) {
            this._lastData = data;
        }
        this._data = data;
        this.emitDateChange();
    }
    /**
     * @return {?}
     */
    get data() {
        return this._data;
    }
    /**
     * @return {?}
     */
    emitDateChange() {
        setTimeout(() => {
            this.dataChangeDot();
            if (!this.move && this._lastData !== this._data) {
                this.dataChange.emit(this._data);
                this._lastData = this._data;
            }
        });
    }
    /**
     * @return {?}
     */
    dataChangeDot() {
        if (this._data === null || isUndefined(this._data)) {
            this.left = 0;
            return;
        }
        this.left = ((this._data - this.min) / (this.max - this.min)) * (this.width - 17.5);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    click(event) {
        this.data = this.min + (((event.clientX - this.remService.realPx(8.25) - this.sliderLine.offset().left) / (this.remService.realPx(this.width) - this.remService.realPx(16.5)))
            * (this.max - this.min));
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mousedown(event) {
        this.move = true;
        let /** @type {?} */ mousemoveHandler = (_event) => {
            let /** @type {?} */ clientX = _event.clientX;
            let /** @type {?} */ min = this.sliderLine.offset().left;
            let /** @type {?} */ max = this.sliderLine.offset().left + this.remService.realPx(this.width);
            if (clientX < min) {
                clientX = min;
            }
            else if (clientX > max) {
                clientX = max;
            }
            this.data = this.min + (((clientX - this.remService.realPx(8.25) - this.sliderLine.offset().left) / (this.remService.realPx(this.width) - this.remService.realPx(16.5)))
                * (this.max - this.min));
        };
        let /** @type {?} */ mouseupHandler = (_event) => {
            document.removeEventListener("mousemove", mousemoveHandler);
            document.removeEventListener("mouseup", mouseupHandler);
            this.move = false;
            this.emitDateChange();
        };
        document.addEventListener("mousemove", mousemoveHandler);
        document.addEventListener("mouseup", mouseupHandler);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.sliderLine = this.host.find(".slider-line");
        this.sliderDot = this.host.find(".slider-dot");
        if (this.step.toString().indexOf(".") > -1) {
            this.stepDecimal = this.step.toString().split(".")[1].length;
        }
    }
}
SliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'jy-slider',
                template: `<div class="slider" [ngStyle]="{'width.rem':width/rem}">
  <div class="slider-line" (click)="click($event)" (mousedown)="mousedown($event)">
    <div class="slider-dot" [ngStyle]="{'left.rem':left/rem}"></div>
  </div>
</div>
`,
                styles: [`.slider{cursor:pointer;display:inline-block;height:1.25rem;vertical-align:top}.slider .slider-line{width:100%;margin-top:.3125rem;height:.625rem;border:1px solid #ccc;border-radius:.3125rem;position:relative}.slider .slider-line .slider-dot{position:absolute;top:0;bottom:0;display:block;width:.55357143rem;border:1px solid #679eda;border-radius:.3125rem;background-color:#679eda}`]
            },] },
];
/** @nocollapse */
SliderComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: RemService, },
];
SliderComponent.propDecorators = {
    "width": [{ type: Input },],
    "step": [{ type: Input },],
    "min": [{ type: Input },],
    "max": [{ type: Input },],
    "data": [{ type: Input },],
    "dataChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * none
 */
class NoneDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyNone(value) {
        this.host.empty();
        if (value !== 0 && value) {
            this.host.removeClass('none');
            this.host.append(value);
        }
        else {
            this.host.addClass('none');
            this.host.append('暂无');
        }
    }
}
NoneDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyNone]"
            },] },
];
/** @nocollapse */
NoneDirective.ctorParameters = () => [
    { type: ElementRef, },
];
NoneDirective.propDecorators = {
    "jyNone": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NoneOnlyClassDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.host = $(elementRef.nativeElement);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set jyNoneOnlyClass(value) {
        if (value !== 0 && value) {
            this.host.removeClass('none');
        }
        else {
            this.host.addClass('none');
        }
    }
}
NoneOnlyClassDirective.decorators = [
    { type: Directive, args: [{
                selector: "[jyNoneOnlyClass]"
            },] },
];
/** @nocollapse */
NoneOnlyClassDirective.ctorParameters = () => [
    { type: ElementRef, },
];
NoneOnlyClassDirective.propDecorators = {
    "jyNoneOnlyClass": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * 核心模块 对外引用请参考./core.module.e.ts
 * Created by Jannsen on 2017/1/6.
 */
const CORE_SERVICE_LIST = [
    InitService,
    AlertService,
    BrowserService,
    DateService,
    DatetimePickerService,
    HttpService,
    IdCardService,
    Md5Service,
    ModalService,
    ToolsService,
    TooltipService,
    ValidatorService,
    DynamicComponentService,
    RightClickMenuService,
    DisabledService,
    StorageService,
    TimerService,
    GlobalEventsService,
    FileUploadService,
    ToastService,
    EnumService,
    NotificationService,
    RippleService,
    CheckboxService,
    LessService,
    SearchService,
    TableBoxService,
    ProvinceCityAreaService,
    BaiduMapService,
    LodopService,
    RemService,
];
const CORE_PIPE_LIST = [
    AmountPipe,
    DatePipe,
    EnumPipe,
    ProvinceCityAreaPipe,
    NoneDirective,
    NoneOnlyClassDirective,
];
const CORE_COMPONENT_LIST = [
    DynamicComponentComponent,
    RightClickMenuComponent,
    ModalComponent,
    AlertComponent,
    YmdComponent,
    PageableComponent,
    SortComponent,
    ImageUploadComponent,
    ImagePreviewComponent,
    YmdHmComponent,
    ToastComponent,
    FileImportComponent,
    SelectComponent,
    NotificationComponent,
    NotificationSimpleComponent,
    AttachmentComponent,
    CheckboxComponent,
    RadioComponent,
    LessComponent,
    SearchSelectComponent,
    MultipleSelectComponent,
    SearchMultipleSelectComponent,
    ProvinceCityAreaComponent,
    ButtonGroupComponent,
    SliderComponent,
    SubmitRemarkModalComponent,
];
const CORE_DIRECTIVE_LIST = [
    RightClickMenuDirective,
    MouseWhellDirective,
    EqualslengthDirective,
    MaxlengthDirective,
    MaxnumberDirective,
    MinlengthDirective,
    MinnumberDirective,
    NameDirective,
    PatternDirective,
    PatternMessageDirective,
    RequiredDirective,
    RequiredMessageDirective,
    ValidateDirective,
    ValidateTypeDirective,
    TableBoxDirective,
    ClassDirective,
    TitleDirective,
    ValueDirective,
    ValidatorDirective,
    EnterDirective,
    FocusDirective,
    SrcDirective,
    AcceptDirective,
    HiddenDirective,
    SelectDataDirective,
    CustomValidatorDirective,
    TooltipDirectionDirective,
    DisabledMaskDirective,
];
class CoreModule {
    constructor() {
        document.documentElement.style.fontSize = window.screen.width / 1920 * 28 + "px";
    }
}
CoreModule.decorators = [
    { type: NgModule, args: [{
                id: "core",
                imports: [
                    BrowserModule,
                    FormsModule,
                    BrowserAnimationsModule,
                    HttpClientModule,
                ],
                declarations: [CORE_COMPONENT_LIST, CORE_DIRECTIVE_LIST, CORE_PIPE_LIST],
                exports: [CORE_COMPONENT_LIST, CORE_DIRECTIVE_LIST, CORE_PIPE_LIST],
                entryComponents: [CORE_COMPONENT_LIST],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] },
];
/** @nocollapse */
CoreModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { CoreModule, CORE_SERVICE_LIST, CORE_COMPONENT_LIST, InitService, ToolsService, HttpService, ModalService, AlertService, DateService, BrowserService, Md5Service, TooltipService, IdCardService, ValidatorService, DynamicComponentService, RightClickMenuService, DatetimePickerService, DisabledService, StorageService, TimerService, GlobalEventsService, FileUploadService, ToastService, EnumService, NotificationService, RippleService, LessService, SearchService, TableBoxService, ProvinceCityAreaService, RemService, LodopService, ImagePreviewComponent, fadeShow, fadeOnlyShow, slideInUp, slideUpDown, arrowsSwitch, upDownSwitch, TooltipLevel, VALIDATOR_CHANGE_EVENT_NAME, HandlerType, INPUT, SELECT, TEXTAREA, CUSTOM_VALIDATOR, JY_CUSTOM_VALIDATOR_VALUE, CUSTOM_VALIDATOR_VALUE_CHANGE, VALIDATOR_SELECTOR_ARRAY, JY_VALIDATE, JY_VALIDATE_TYPE, VALIDATE_TYPE_INTEGER, VALIDATE_TYPE_DOUBLE, VALIDATE_TYPE_MOBILE, VALIDATE_TYPE_EMAIL, VALIDATE_TYPE_ID_CARD, JY_REQUIRED, JY_REQUIRED_MESSAGE, JY_PATTERN, JY_PATTERN_MESSAGE, JY_EQUALSLENGTH, JY_MINLENGTH, JY_MAXLENGTH, JY_MINNUMBER, JY_MAXNUMBER, JY_TOOLTIP_DIRECTION, VALIDATE, VALIDATE_TYPE, CUSTOM, LENGTH, REQUIRED, PATTERN, NUMBER_SIZE, CHECK_IN, ERROR_MESSAGE_REQUIRED, ERROR_MESSAGE_EQUALSLENGTH, ERROR_MESSAGE_MINLENGTH, ERROR_MESSAGE_MAXLENGTH, ERROR_MESSAGE_MINNUMBER, ERROR_MESSAGE_MAXNUMBER, ERROR_MESSAGE_ONLY_INTEGER, ERROR_MESSAGE_INTEGER_OR_DECIMAL, ERROR_MESSAGE_EMAIL, ERROR_MESSAGE_ID_CARD, ERROR_MESSAGE_MOBILE, SORT_EVENT, DefaultPageData, DefaultQueryParams, RIGHT_CLICK_MENU, rem, second, minute, hour, day, Icon, LessAttribute, AlertComponent as ɵf, ButtonGroupComponent as ɵz, CheckboxComponent as ɵr, CheckboxService as ɵs, YmdHmComponent as ɵk, YmdComponent as ɵg, DynamicComponentComponent as ɵc, AttachmentComponent as ɵq, FileImportComponent as ɵm, ImageUploadComponent as ɵj, LessComponent as ɵu, SubmitRemarkModalComponent as ɵbb, ModalComponent as ɵe, NotificationComponent as ɵo, NotificationSimpleComponent as ɵp, ProvinceCityAreaComponent as ɵy, RadioComponent as ɵt, MultipleSelectComponent as ɵw, SearchMultipleSelectComponent as ɵx, SearchSelectComponent as ɵv, SelectComponent as ɵn, SliderComponent as ɵba, PageableComponent as ɵh, SortComponent as ɵi, ToastComponent as ɵl, CORE_DIRECTIVE_LIST as ɵb, CORE_PIPE_LIST as ɵa, AcceptDirective as ɵby, ClassDirective as ɵbr, EnterDirective as ɵbv, FocusDirective as ɵbw, HiddenDirective as ɵbz, NameDirective as ɵbj, SrcDirective as ɵbx, TitleDirective as ɵbs, ValueDirective as ɵbt, DisabledMaskDirective as ɵcd, MouseWhellDirective as ɵbd, NoneOnlyClassDirective as ɵcj, NoneDirective as ɵci, RightClickMenuComponent as ɵd, RightClickMenuDirective as ɵbc, SelectDataDirective as ɵca, TableBoxDirective as ɵbq, CustomValidatorDirective as ɵcb, EqualslengthDirective as ɵbe, MaxlengthDirective as ɵbf, MaxnumberDirective as ɵbg, MinlengthDirective as ɵbh, MinnumberDirective as ɵbi, PatternMessageDirective as ɵbl, PatternDirective as ɵbk, RequiredMessageDirective as ɵbn, RequiredDirective as ɵbm, TooltipDirectionDirective as ɵcc, ValidateTypeDirective as ɵbp, ValidateDirective as ɵbo, ValidatorDirective as ɵbu, AmountPipe as ɵce, DatePipe as ɵcf, EnumPipe as ɵcg, ProvinceCityAreaPipe as ɵch, BaiduMapService as ɵck };
//# sourceMappingURL=jy-web-core.js.map
